(* J.Gewein, 1.4.94 *)

MODULE FWrite;
  
  IMPORT SYSTEM, Types, Errors, Files, Script, TextUtils, SANE:=SANE1, StdIO;
  
  VAR
    Done*: BOOLEAN;

  (* The following external procedures are written in C and are *)
  (* part of the runtime library. *)
  PROCEDURE MakeResolvedFSSpec(VAR leafIsAlias, hadAlias, isFolder: BOOLEAN;
                               spec: Files.FSSpecPtr; path: SYSTEM.PTR;
                               directory: LONGINT; volume: INTEGER): Types.OSErr;
    EXTERNAL;

  (* The following procedure corrects the stack after calling a C *)
  (* procedure. *)
  (*$Parameter Pop(D0) *)
  PROCEDURE Pop(amount: LONGINT);
    INLINE $DFC0; (* Add.L D0,A7 *)

  (* The following procedures implement the interface of this *)
  (* module by using the external routines defined above. *)
  PROCEDURE Open*(name: ARRAY OF CHAR): StdIO.File;
    VAR
      file: StdIO.File;
      error: Types.OSErr;
      spec: Files.FSSpec;
      leafIsAlias, hadAlias, isFolder: BOOLEAN;
      info: Files.FInfo;
      path: Types.Str255;
  BEGIN
    COPY(name, path); TextUtils.C2PStrProc(SYSTEM.ADR(path));
    error:=MakeResolvedFSSpec(leafIsAlias, hadAlias, isFolder, SYSTEM.ADR(spec),
                              SYSTEM.ADR(path), 0, 0); Pop(6*4+2);
    IF error=Errors.fnfErr THEN
      error:=Files.FSpCreate(spec, LONG("MPS "), LONG("TEXT"),
                             Script.smSystemScript)
    ELSIF error=Types.noErr THEN
      error:=Files.FSpGetFInfo(spec, info);
      IF error=Types.noErr THEN
        info.fdCreator:=LONG("MPS "); info.fdType:=LONG("TEXT");
        error:=Files.FSpSetFInfo(spec, info)
      END
    ELSE
      file:=NIL
    END;
    IF error=Types.noErr THEN
      file:=StdIO.Open(name, "w+")
    END;
    Done:=fileNIL; RETURN file
  END Open;

  PROCEDURE Close*(file: StdIO.File);
  BEGIN
    Done:=StdIO.Close(file)=0
  END Close;

  PROCEDURE Char*(file: StdIO.File; ch: CHAR);
  BEGIN
    Done:=StdIO.PutChar(file, ch)=0
  END Char;

  PROCEDURE Int*(file: StdIO.File; n: LONGINT; width: INTEGER);
    VAR
      i: INTEGER;
      data: POINTER TO ARRAY OF CHAR;
      s: Types.Str255;
  BEGIN
    TextUtils.NumToString(n, s); data:=SYSTEM.ADR(s[1]);
    FOR i:=1 TO width-ORD(s[0]) DO Char(file, " ") END;
    Done:=StdIO.Write(file, ORD(s[0]), 1, data)=0
  END Int;

  PROCEDURE _Real(file: StdIO.File; x: LONGREAL; f: SANE.DecForm;
                  n: INTEGER);
    VAR
      i: INTEGER;
      data: POINTER TO ARRAY OF CHAR;
      s: SANE.DecStr;
  BEGIN
    SANE.Num2Str(f, x, s); data:=SYSTEM.ADR(s[1]);
    FOR i:=1 TO n-ORD(s[0]) DO Char(file, " ") END;
    Done:=StdIO.Write(file, ORD(s[0]), 1, data)=0
  END _Real;

  PROCEDURE Real*(file: StdIO.File; x: LONGREAL; n: INTEGER);
    VAR
      form: SANE.DecForm;
      log10: INTEGER;
  BEGIN
    form.style:=SANE.FloatDecimal; form.digits:=n-4;
    log10:=SHORT(ENTIER(ABS(SANE.Ln(x))/SANE.Ln(10)));
    REPEAT
      DEC(form.digits); log10:=log10 DIV 10
    UNTIL log10=0;
    IF form.digits>17 THEN form.digits:=17 END;
    _Real(file, x, form, n)
  END Real;

  PROCEDURE RealFix*(file: StdIO.File; x: LONGREAL; n, k: INTEGER);
    VAR
      form: SANE.DecForm;
  BEGIN
    form.style:=SANE.FixedDecimal; form.digits:=k;
    _Real(file, x, form, n)
  END RealFix;

  PROCEDURE String*(file: StdIO.File; s: ARRAY OF CHAR);
  BEGIN
    Done:=StdIO.FPutString(file, s)=0
  END String;
  
  PROCEDURE OSType*(file: StdIO.File; n: LONGINT);
    VAR
      s: ARRAY 5 OF CHAR;
      i: INTEGER;
  BEGIN
    FOR i:=3 TO 0 BY -1 DO
      s[i]:=CHR(n); n:=ASH(n, -8)
    END;
    s[4]:=0X; String(file, s)
  END OSType;

  PROCEDURE Ln*(file: StdIO.File);
  BEGIN
    String(file, "\$0D")
  END Ln;

  PROCEDURE Bytes*(file: StdIO.File; amount: LONGINT;
                   data: ARRAY OF BYTE): LONGINT;
  BEGIN
    amount:=StdIO.Write(file, amount, 1, SYSTEM.ADR(data));
    Done:=amount>=0; RETURN amount
  END Bytes;

  PROCEDURE Text*(f: StdIO.File; text: ARRAY OF CHAR; len: INTEGER);
    VAR
      i: INTEGER;
  BEGIN
    i:=0;
    WHILE (i<LEN(text)) & (text[i]0X) & (i<len) DO
      Char(f, text[i]); INC(i)
    END;
    WHILE i<len DO
      Char(f, " "); INC(i)
    END
  END Text;

  PROCEDURE At*(file: StdIO.File; offset: LONGINT);
  BEGIN
    offset:=StdIO.Seek(file, offset, StdIO.SeekSet);
    Done:=StdIO.Error(file)
  END At;

  PROCEDURE Length*(file: StdIO.File): LONGINT;
  (* Identical to FRead.mod*)
    VAR
      len, pos: LONGINT;
      dummy: BOOLEAN;
  BEGIN
    len:=0; Done:=FALSE;
    IF StdIO.GetPos(file, pos) THEN
      IF StdIO.Seek(file, 0, StdIO.SeekEnd)=0 THEN
        len:=StdIO.Tell(file); Done:=TRUE
      END;
      dummy:=StdIO.SetPos(file, pos)
    END;
    RETURN len
  END Length;

BEGIN
  Done:=FALSE
END FWrite.
