(*
	File:		Sane.mod

	Desc:		Interface between MPW-Oberon and SANE
	
	Author:		Oliver Schirpf, Jrgen Gewein
	
	Date:		06.07.1994
	
	
*)

MODULE SANE1;

  IMPORT Types, SYSTEM;

  CONST
    DecStrLen* = 255;
    SigDigLen = 20; (*for 68K; use 28 in 6502 SANE*)
  TYPE
    DecimalKind* = SHORTINT;
  CONST
    FloatDecimal* = 0; FixedDecimal* = 1;
  TYPE
    DecStr* = ARRAY DecStrLen+1 OF CHAR;
    DecForm* = RECORD
      style*: DecimalKind;
      digits*: INTEGER;
    END;
	Decimal* = RECORD
	  sgn*: SHORTINT; (* 0..1 *)
	  exp*: INTEGER;
	  sig*: ARRAY SigDigLen+1 OF CHAR
	END;

  PROCEDURE StrToNum*(str: ARRAY OF CHAR; VAR okay: BOOLEAN):LONGREAL;
    VAR
	  rec: Decimal;
	  i: INTEGER;
	  x: LONGREAL;

	PROCEDURE strtorec(VAR cstring: Types.Str255; VAR i:INTEGER;
	                   VAR r: Decimal; VAR x:BOOLEAN);
	  INLINE PASCAL $3F3C, $0004, $A9EE;
	
	PROCEDURE rectonum(VAR rec: Decimal; VAR no: LONGREAL);
	  INLINE PASCAL $3F3C, $0009, $A9EB;

  BEGIN
	i:=0;
	strtorec(SYSTEM.VAL(Types.Str255, str), i, rec, okay);
	rectonum(rec, x);
	RETURN x
  END StrToNum;

  PROCEDURE ATan*(x: LONGREAL): LONGREAL;
	
	PROCEDURE DoATan(VAR x: LONGREAL);
	  INLINE $3F3C, $001E, $A9EC;
	
  BEGIN
	DoATan(x); RETURN x
  END ATan;

  PROCEDURE Cos*(x: LONGREAL): LONGREAL;
	
	PROCEDURE DoCos(VAR x: LONGREAL);
	  INLINE $3F3C, $001A, $A9EC;
	
  BEGIN
	DoCos(x); RETURN x
  END Cos;

  PROCEDURE Exp*(x: LONGREAL): LONGREAL; (* e^x *)
	
	PROCEDURE DoExp(VAR x: LONGREAL);
	  INLINE $3F3C, $0008, $A9EC;
	
  BEGIN
	DoExp(x); RETURN x
  END Exp;

  PROCEDURE ExpM1*(x: LONGREAL): LONGREAL; (* e^(x-1) *)
	
	PROCEDURE DoExpM1(VAR x: LONGREAL);
	  INLINE $3F3C, $000C, $A9EC;
	
  BEGIN
	DoExpM1(x); RETURN x
  END ExpM1;

  PROCEDURE Ln*(x: LONGREAL): LONGREAL; (* ln x *)
	
	PROCEDURE DoLn(VAR x: LONGREAL);
	  INLINE $3F3C, $0000, $A9EC;
	
  BEGIN
	DoLn(x); RETURN x
  END Ln;

  PROCEDURE LnP1*(x: LONGREAL): LONGREAL; (* ln (x+1) *)
	
	PROCEDURE DoLnP1(VAR x: LONGREAL);
	  INLINE $3F3C, $0004, $A9EC;
	
  BEGIN
	DoLnP1(x); RETURN x
  END LnP1;

  PROCEDURE Log2*(x: LONGREAL): LONGREAL; (* log(2) x *)
	
	PROCEDURE DoLog2(VAR x: LONGREAL);
	  INLINE $3F3C, $0002, $A9EC;
	
  BEGIN
	DoLog2(x); RETURN x
  END Log2;

  PROCEDURE Power2*(x: LONGREAL): LONGREAL;  (* 2^x *)
	
	PROCEDURE DoPower2(VAR x: LONGREAL);
	  INLINE $3F3C, $000A, $A9EC;
	
  BEGIN
	DoPower2(x); RETURN x
  END Power2;

  PROCEDURE Scale*(x: LONGREAL; y: INTEGER): LONGREAL; (* x*(2^y) *)
	
	PROCEDURE DoScale(VAR x: INTEGER; VAR y: LONGREAL);
	  INLINE PASCAL $3F3C, $2018, $A9EB;
	
  BEGIN
	DoScale(y, x); RETURN x
  END Scale;

  PROCEDURE Sin*(x: LONGREAL): LONGREAL;
	
	PROCEDURE DoSin(VAR x: LONGREAL);
	  INLINE $3F3C, $0018, $A9EC;
	
  BEGIN
	DoSin(x); RETURN x
  END Sin;

  PROCEDURE Sqrt*(x: LONGREAL): LONGREAL;
	
	PROCEDURE DoSqrt(VAR x: LONGREAL);
	  INLINE $3F3C, $0012, $A9EB;
	
  BEGIN
	DoSqrt(x); RETURN x
  END Sqrt;


  PROCEDURE Tan*(x: LONGREAL): LONGREAL;
	
	PROCEDURE DoTan(VAR x: LONGREAL);
	  INLINE $3F3C, $001C, $A9EC;
	
  BEGIN
	DoTan(x); RETURN x
  END Tan;

  PROCEDURE XpwrI*(x: LONGREAL; i:INTEGER): LONGREAL; (* x^i *)
	
	PROCEDURE DoXpwrI(VAR i:INTEGER; VAR x: LONGREAL);
	  INLINE $3F3C, $8010, $A9EC;
	
  BEGIN
	DoXpwrI(i, x); RETURN x
  END XpwrI;

  PROCEDURE XpwrY*(x: LONGREAL; y: LONGREAL): LONGREAL; (* x^y *)
	
	PROCEDURE DoXpwrY(VAR y: LONGREAL; VAR x: LONGREAL);
	  INLINE $3F3C, $0012, $A9EC;
	
  BEGIN
	DoXpwrY(y, x); RETURN x
  END XpwrY;

  PROCEDURE Num2Dec*(f: DecForm; x: LONGREAL; VAR d: Decimal);
    EXTERNAL;

  PROCEDURE Dec2Str*(f: DecForm; d: Decimal; VAR s: DecStr);
    EXTERNAL;

  PROCEDURE Num2Str*(f: DecForm; x: LONGREAL; VAR s: DecStr);
    VAR
      d: Decimal;
  BEGIN
    Num2Dec(f, x, d); Dec2Str(f, d, s)
  END Num2Str;

END SANE1.