(*$TAGS- C does not use tags*)
MODULE StdIO;

  IMPORT SYSTEM;

  CONST
    (* Default file buffer sizes used by setbuf() and setvbuf(). *)
    BUFSIZ* = 1024;    (* default file buffer size *)
    _LBFSIZ* = 100;    (* Line buffer size *)
    (* L_tmpnam is the size of char array long enough to hold a *)
    (* temporary file name generated by tmpnam(), including the *)
    (* trailing null byte. The name is in the form tmp.AAAXXXXXX, *)
    (* where AAA is a sequence of lower case letters ("aaa", *)
    (* "baa", ... "zzz" on successive calls), and XXXXXX is a lower *)
    (* case letter followed by a sequence of digits, all determined *)
    (* at runtime. TMP_MAX is the number of distinct file names that *)
    (* tmpnam() can generate. *)
    L_tmpnam* = 14;
    TMP_MAX* = 17576;
    FOPEN_MAX* = 12;
    FILENAME_MAX* = 32;
    (* positioning modes for Seek *)
    SeekSet* = 0;      (* relative to start of file *)
    SeekCur* = 1;      (* relative to current position *)
    SeekEnd* = 2;      (* relative to end of file *)
    (* These constants define the meanings of the bits in File._flags. *)
    (* SetVBuf takes one of _IOFBF, _IOLBF, or _IONBF as its third *)
    (* argument. *)
    _IOFBF* = 0;       (* Pseudo-flag, default buffering style *)
    _IOREAD* = 1;      (* Current mode is for reading *)
    _IOWRT* = 2;       (* Current mode is for writing *)
    _IONBF* = 4;       (* no buffering *)
    _IOMYBUF* = 8;     (* buffer was allocated by stdio *)
    _IOEOF* = 16;
    _IOERR* = 32;
    _IOLBF* = 64;      (* flush buffer when a \n is written *)
    _IORW* = 128;      (* Enable read/write access *)
    _IOSYNC* = 256;    (* Input triggers fflush() to output fp's *)
    _IOBINARY* = 512;  (* Binary stream *)
  TYPE
    CharPtr* = POINTER TO ARRAY OF CHAR;
    File* = POINTER TO FileRec;
    FileRec* = RECORD
      _cnt: LONGINT;
      _ptr: CharPtr;
      _base: CharPtr;
      _end: CharPtr;
      _size: INTEGER; (* unsigned *)
      _flag: INTEGER; (* unsigned *)
      _file: INTEGER; (* unsigned *)
    END;
  VAR
    stdin*, stdout*, stderr*: File;
    (*$J+*)
    _iob: ARRAY 20 OF FileRec;
    errno*: LONGINT;
    MacOSErr*: INTEGER;
    (*$J-*)

  (* The following external procedures are written in C and are *)
  (* part of the StdIO library provided with MPW C. The declaration *)
  (* in C is given for each routine. *)
  (* For a detailed description of the routines provided by this unit *)
  (* see the document MPW C Reference. *)

  (* int remove(const char *filename); *)
  PROCEDURE remove(name: CharPtr): LONGINT;
    EXTERNAL;

  (* int rename(const char *old, const char *new); *)
  PROCEDURE rename(new, old: CharPtr): LONGINT;
    EXTERNAL;

  (* FILE *tmpfile(void); *)
  PROCEDURE tmpfile(): File;
    EXTERNAL;

  (* char *tmpnam(char *s); *)
  PROCEDURE tmpnam(s: CharPtr): CharPtr;
    EXTERNAL;

  (* int fclose(FILE *stream); *)
  PROCEDURE fclose(stream: File): LONGINT;
    EXTERNAL;

  (* int fflush(FILE *stream); *)
  PROCEDURE fflush(stream: File): LONGINT;
    EXTERNAL;

  (* FILE *fopen(const char *filename, const char *mode); *)
  PROCEDURE fopen(mode, filename: CharPtr): File;
    EXTERNAL;

  (* FILE *freopen(const char *filename, const char *mode, FILE *stream); *)
  PROCEDURE freopen(stream: File; mode, filename: CharPtr): File;
    EXTERNAL;

  (* void setbuf (FILE *stream, char *buf); *)
  PROCEDURE setbuf(buf: CharPtr; stream: File);
    EXTERNAL;

  (* int setvbuf(FILE *stream, char *buf, int mode, size_t size); *)
  PROCEDURE setvbuf(size, mode: LONGINT; buf: CharPtr; stream: File): LONGINT;
    EXTERNAL;

  (* int fgetc (FILE *stream); *)
  PROCEDURE fgetc(stream: File): LONGINT;
    EXTERNAL;

  (* char *gets( char *s) *)
  PROCEDURE gets(s: CharPtr): CharPtr;
    EXTERNAL;

  (* char *fgets( char *s, int n, FILE *stream); *)
  PROCEDURE fgets(stream: File; n: LONGINT; s: CharPtr): CharPtr;
    EXTERNAL;

  (* int fputc(int c, FILE *stream); *)
  PROCEDURE fputc(stream: File; c: LONGINT): LONGINT;
    EXTERNAL;

  (* int puts(const char *s); *)
  PROCEDURE puts(s: CharPtr): LONGINT;
    EXTERNAL;

  (* int fputs(const char *s, FILE *stream); *)
  PROCEDURE fputs(stream: File; s: CharPtr): LONGINT;
    EXTERNAL;

  (* int ungetc (int c, FILE *stream); *)
  PROCEDURE ungetc(stream: File; c: LONGINT): LONGINT;
    EXTERNAL;

  (* size_t fread( void *ptr, size_t size, size_t nmemb, FILE *stream); *)
  PROCEDURE fread(stream: File; nmemb, size: LONGINT; ptr: SYSTEM.PTR): LONGINT;
    EXTERNAL;

  (* int fwrite(const  void *ptr, size_t size, size_t nmemb, FILE *stream); *)
  PROCEDURE fwrite(stream: File; nmemb, size: LONGINT; ptr: SYSTEM.PTR): LONGINT;
    EXTERNAL;

  (* int fseek(FILE *stream, long int offset, int whence); *)
  PROCEDURE fseek(whence, offset: LONGINT; stream: File): LONGINT;
    EXTERNAL;

  (* long int ftell(FILE *stream); *)
  PROCEDURE ftell(stream: File): LONGINT;
    EXTERNAL;

  (* int fgetpos(FILE *stream, fpos_t *pos); *)
  PROCEDURE fgetpos(VAR pos: LONGINT; stream: File): LONGINT;
    EXTERNAL;

  (* int fsetpos(FILE *stream, const fpos_t *pos); *)
  PROCEDURE fsetpos(VAR pos: LONGINT; stream: File): LONGINT;
    EXTERNAL;

  (* void perror(const char *s); *)
  PROCEDURE perror(s: CharPtr);
    EXTERNAL;

  (* The following procedure is used to correct the stack after *)
  (* calling a C procedure. The C calling convention requires the *)
  (* caller to get rid of any parameters. *)
  (*$Parameter Pop(D0) *)
  PROCEDURE Pop(amount: LONGINT);
    INLINE $DFC0; (* Add.L A0,A7 *)

  (* The following procedures implement the interface of this module *)
  (* by using the external interfaces defined above. *)
  PROCEDURE Remove*(name: ARRAY OF CHAR): BOOLEAN;
    VAR
      res: LONGINT;
  BEGIN
    res:=remove(SYSTEM.ADR(name)); Pop(4);
    RETURN res=0
  END Remove;

  PROCEDURE Rename*(old, new: ARRAY OF CHAR): BOOLEAN;
    VAR
      res: LONGINT;
  BEGIN
    res:=rename(SYSTEM.ADR(new), SYSTEM.ADR(old)); Pop(8);
    RETURN res=0
  END Rename;

  PROCEDURE TemporaryFile*(): File;
  BEGIN
    RETURN tmpfile()
  END TemporaryFile;

  PROCEDURE TemporaryName*(VAR s: ARRAY OF CHAR);
    VAR
      tempname: ARRAY TMP_MAX OF CHAR;
      dummy: CharPtr;
  BEGIN
    dummy:=tmpnam(SYSTEM.ADR(tempname)); COPY(tempname, s)
  END TemporaryName;

  PROCEDURE Close*(stream: File): LONGINT;
    VAR
      result: LONGINT;
  BEGIN
    result:=fclose(stream); Pop(4); RETURN result
  END Close;

  PROCEDURE Flush*(stream: File): LONGINT;
    VAR
      result: LONGINT;
  BEGIN
    result:=fflush(stream); Pop(4); RETURN result
  END Flush;

  PROCEDURE Open*(name, mode: ARRAY OF CHAR): File;
    VAR
      res: File;
  BEGIN
    res:=fopen(SYSTEM.ADR(mode), SYSTEM.ADR(name)); Pop(8);
    RETURN res
  END Open;

  PROCEDURE Reopen*(stream: File; name, mode: ARRAY OF CHAR): File;
    VAR
      res: File;
  BEGIN
    res:=freopen(stream, SYSTEM.ADR(mode), SYSTEM.ADR(name)); Pop(12);
    RETURN res
  END Reopen;

  PROCEDURE SetBuf*(stream: File; VAR buf: ARRAY OF SYSTEM.BYTE);
  BEGIN
    setbuf(SYSTEM.ADR(buf), stream); Pop(8)
  END SetBuf;

  PROCEDURE SetVBuf*(stream: File; mode: INTEGER; VAR buf: ARRAY OF SYSTEM.BYTE);
    VAR
      dummy: LONGINT;
  BEGIN
    dummy:=setvbuf(LEN(buf), mode, SYSTEM.ADR(buf), stream); Pop(16)
  END SetVBuf;

  PROCEDURE GetChar*(stream: File): CHAR;
    VAR
      res: LONGINT;
  BEGIN
    res:=fgetc(stream); Pop(4); RETURN CHR(res)
  END GetChar;

  PROCEDURE GetString*(VAR s: ARRAY OF CHAR): BOOLEAN;
    VAR
      res: CharPtr;
  BEGIN
    res:=gets(SYSTEM.ADR(s)); Pop(4); RETURN resNIL
  END GetString;

  PROCEDURE FGetString*(stream: File; VAR s: ARRAY OF CHAR): BOOLEAN;
    VAR
      res: CharPtr;
  BEGIN
    res:=fgets(stream, LEN(s), SYSTEM.ADR(s)); Pop(12);
    RETURN resNIL
  END FGetString;

  PROCEDURE PutChar*(stream: File; c: CHAR): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=fputc(stream, ORD(c)); Pop(8); RETURN res
  END PutChar;

  PROCEDURE PutString*(s: ARRAY OF CHAR): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=puts(SYSTEM.ADR(s)); Pop(4); RETURN res
  END PutString;

  PROCEDURE FPutString*(stream: File; s: ARRAY OF CHAR): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=fputs(stream, SYSTEM.ADR(s)); Pop(8); RETURN res
  END FPutString;

  PROCEDURE Unget*(stream: File; c: CHAR): BOOLEAN;
    VAR
      res: LONGINT;
  BEGIN
    res:=ungetc(stream, ORD(c)); Pop(8); RETURN res#-1
  END Unget;

  PROCEDURE Read*(stream: File; nmemb, size: LONGINT;
                  data: SYSTEM.PTR): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=fread(stream, nmemb, size, data); Pop(16);
    RETURN res
  END Read;

  PROCEDURE Write*(stream: File; nmemb, size: LONGINT;
                   data: SYSTEM.PTR): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=fwrite(stream, nmemb, size, data); Pop(16);
    RETURN res
  END Write;

  PROCEDURE Seek*(stream: File; offset, whence: LONGINT): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=fseek(whence, offset, stream); Pop(12);
    RETURN res
  END Seek;

  PROCEDURE Rewind*(stream: File);
    VAR
      dummy: LONGINT;
  BEGIN
    dummy:=fseek(0, 0, stream); Pop(12)
  END Rewind;

  PROCEDURE Tell*(stream: File): LONGINT;
    VAR
      res: LONGINT;
  BEGIN
    res:=ftell(stream); Pop(4); RETURN res
  END Tell;

  PROCEDURE GetPos*(stream: File; VAR pos: LONGINT): BOOLEAN;
    VAR
      res: LONGINT;
  BEGIN
    res:=fgetpos(pos, stream); Pop(8); RETURN res=0
  END GetPos;

  PROCEDURE SetPos*(stream: File; VAR pos: LONGINT): BOOLEAN;
    VAR
      res: LONGINT;
  BEGIN
    res:=fsetpos(pos, stream); Pop(8); RETURN res=0
  END SetPos;

  PROCEDURE EOF*(stream: File): BOOLEAN;
  BEGIN
    (* #define feof(p) ((p)->_flag & _IOEOF) *)
    RETURN BAND(stream._flag, _IOEOF)0
  END EOF;

  PROCEDURE Error*(stream: File): BOOLEAN;
  BEGIN
    (* #define ferror(p) ((p)->_flag & _IOERR) *)
    RETURN BAND(stream._flag, _IOERR)0
  END Error;

  PROCEDURE ClearError*(stream: File);
  BEGIN
    (* #define clearerr(p) ((void)((p)->_flag &= ~(_IOERR | _IOEOF))) *)
    stream._flag:=BAND(stream._flag, BNOT(BOR(_IOERR, _IOEOF)))
  END ClearError;

  PROCEDURE PrintError*(s: ARRAY OF CHAR);
  BEGIN
    perror(SYSTEM.ADR(s)); Pop(4)
  END PrintError;

BEGIN
  stdin:=SYSTEM.ADR(_iob[0]);
  stdout:=SYSTEM.ADR(_iob[1]);
  stderr:=SYSTEM.ADR(_iob[2]);
END StdIO.
