PROGRAM Hennessy;

USES  Events, Types, Memory;

CONST
	bubblebase = 1.61;
	dnfbase = 3.5;
	permbase = 1.75;
	queensbase = 1.83;
	towersbase = 2.39;
	quickbase = 1.92;
	intmmbase = 1.46;
	treebase =  2.5;
	mmbase = 0.0 (* 0.73 *);
	fpmmbase = 2.92;
	puzzlebase = 0.5;
	fftbase = 0.0 (* 1.11 *);
	fpfftbase = 4.44;

	(* Towers *)
	maxcells = 18;
	stackrange = (*0..*) 3;

	(* Intmm, Mm *)
	rowsize = 40;

	(* Puzzle *)
	sizepuzzle = 511;
	classmax = 3;
	typemax = 12;
	d = 8;

	(* Bubble, Quick *)
	sortelements = 5000;
	srtelements = 500;

	(* fft *)
	fftsize = 256;
	fftsize2 = 129;

	(* Perm *)
	permrange = (*0 ..*)10;
    (* Towers *)

TYPE
	(* tree *)
	node = ^nodeDesc;
	nodeDesc = RECORD
		left, right: node;
		val: LONGINT;
	END;
	
	element = RECORD
		discsize: LONGINT;
		next: LONGINT;
	END ;
	
    (* FFT *)
	complex = RECORD
		rp, ip: DOUBLE
	END;
    carray = ARRAY [0..fftsize] OF complex ;
    c2array = ARRAY [0..fftsize2] OF complex ;
	
VAR
    (* global *)
	seed: LONGINT;

    (* Perm *)
	permarray: ARRAY [0..permrange] OF LONGINT;
	pctr: LONGINT;

    (* tree *)
	tree: node;

	(* Towers *)
    stack: ARRAY [0..stackrange] OF LONGINT;
	cellspace: ARRAY [0..maxcells] OF element;
	freelist: LONGINT;
	movesdone: LONGINT;
TYPE
	intmatrix = ARRAY [0..rowsize] OF ARRAY [0..rowsize] OF LONGINT;
    DOUBLEmatrix = ARRAY [0..rowsize] OF ARRAY [0..rowsize] OF DOUBLE;
	intmatrixPtr = ^intmatrix;
	DOUBLEmatrixPtr = ^DOUBLEmatrix;
	
VAR

	(* Intmm, Mm *)
	ima, imb, imr: intmatrixPtr;
	rma, rmb, rmr: DOUBLEmatrixPtr;

	(* Puzzle *)
	piececount: ARRAY [0..classmax] OF LONGINT;
	class, piecemax: ARRAY [0..typemax] OF LONGINT;
	puzzl: ARRAY [0..sizepuzzle] OF BOOLEAN;
	p: ARRAY [0..typemax] OF ARRAY [0..sizepuzzle] OF BOOLEAN;
	n,
	kount: LONGINT;

	(* Bubble, Quick *)
	
TYPE Mysortlist= ARRAY [0..sortelements] OF LONGINT;
	 MySPtr = ^Mysortlist;
VAR
	
	sortlist: MySPtr;
    biggest, littlest,
    top: LONGINT;

    (* FFT *)
	z, w: carray;
    e: c2array;
	zr, zi: DOUBLE;

FUNCTION MyNewPtr(size:LONGINT):Ptr;
VAR p: Ptr;
BEGIN
	p:=NewPtr(size);
	IF p=NIL THEN Debugger;
	MyNewPtr:=p;
END;

PROCEDURE Initrand;
BEGIN seed := 74755
END;

FUNCTION Rand: LONGINT;
BEGIN
    seed := (seed * 1309 + 13849) MOD 65535;
    Rand:= (seed);
END;

	PROCEDURE Swap (VAR a,b: LONGINT);
		VAR t: LONGINT;
	BEGIN t := a;  a := b;  b := t;
	END ;
	
	PROCEDURE Initialize;
		VAR i: LONGINT;
	BEGIN i := 1;
		WHILE i <= 7 DO BEGIN
			permarray[i] := i-1;
			i:=i+1
		END
	END;
	
	PROCEDURE Permute (n: LONGINT);
		VAR k: LONGINT;
	BEGIN
		pctr := pctr + 1;
		IF ( n<>1 ) THEN BEGIN
			Permute(n-1);
			k := n-1;
			WHILE k >= 1 DO BEGIN
				Swap(permarray[n], permarray[k]);
				Permute(n-1);
				Swap(permarray[n], permarray[k]);
				k:=k-1
			END
       END
	END ;
	
PROCEDURE Perm;
	VAR i: LONGINT;
BEGIN
	pctr := 0; i := 1;
	WHILE i <= 5 DO BEGIN
		Initialize;
		Permute(7);
		i:=i+1
	END ;
END ;

	PROCEDURE Makenull (s: LONGINT);
	BEGIN stack[s] := 0
	END;

	FUNCTION Getelement: LONGINT;
		VAR temp: LONGINT;
	BEGIN
		IF ( freelist>0 ) THEN BEGIN
			temp := freelist;
			freelist := cellspace[freelist].next;
		END ;
		Getelement:= (temp);
	END ;
	
	PROCEDURE Push(i,s: LONGINT);
        VAR localel: LONGINT; errorfound: BOOLEAN;
	BEGIN
		errorfound := FALSE;
		IF ( stack[s] > 0 ) THEN
			IF ( cellspace[stack[s]].discsize<=i ) THEN
				errorfound := TRUE;
		IF ( NOT( errorfound )) THEN BEGIN
			localel := Getelement;
			cellspace[localel].next := stack[s];
			stack[s] := localel;
			cellspace[localel].discsize := i
		END
	END ;
	
	PROCEDURE Init (s,n: LONGINT);
		VAR discctr: LONGINT;
	BEGIN
		Makenull(s); discctr := n;
		WHILE discctr >= 1 DO BEGIN
			Push(discctr,s);
			discctr:=discctr-1
		END
	END;

	FUNCTION Pop (s: LONGINT): LONGINT;
		VAR temp, temp1: LONGINT;
	BEGIN
		IF ( stack[s] > 0 ) THEN BEGIN
			temp1 := cellspace[stack[s]].discsize;
			temp := cellspace[stack[s]].next;
			cellspace[stack[s]].next := freelist;
			freelist := stack[s];
			stack[s] := temp;
			Pop:= (temp1) END
		ELSE Pop:= 0
	END ;

	PROCEDURE MyMove (s1,s2: LONGINT);
	BEGIN
		Push(Pop(s1),s2);
		movesdone := movesdone+1;
	END ;

	PROCEDURE tower(i,j,k: LONGINT);
		VAR other: LONGINT;
	BEGIN
		IF ( k=1 ) THEN
			MyMove(i,j)
		ELSE BEGIN
			other := 6-i-j;
			tower(i,other,k-1);
			MyMove(i,j);
			tower(other,j,k-1)
		END
	END ;

PROCEDURE Towers ;
	VAR i: LONGINT;
BEGIN i := 1;
	WHILE i <= maxcells DO BEGIN  cellspace[i].next := i-1; i:=i+1 END ;
	freelist := maxcells;
	Init(1,14);
	Makenull(2);
	Makenull(3);
	movesdone := 0;
	tower(1,2,14);
END;

TYPE 
			{a: ARRAY 9 OF BOOLEAN;
			b: ARRAY 17 OF BOOLEAN;
			c: ARRAY 15 OF BOOLEAN;
			x: ARRAY 9 OF LONGINT;}

	aA = ARRAY [0..8] OF BOOLEAN;
	bB = ARRAY [0..16] OF BOOLEAN;
	cC = ARRAY [0..14] OF BOOLEAN;
	xX = ARRAY [0..8] OF LONGINT;


	PROCEDURE Try(i: LONGINT; VAR q: BOOLEAN; VAR a: bB; VAR b: aA;VAR  c: cC; VAR x: xX);
    	VAR j: LONGINT;
	BEGIN
		j := 0;
		q := FALSE;
		WHILE (NOT(q)) & (j <> 8) DO BEGIN
			j := j + 1;
			q := FALSE;
			IF b[j] & a[i+j] & c[i-j+7] THEN BEGIN
				x[i] := j;
				b[j] := FALSE;
				a[i+j] := FALSE;
				c[i-j+7] := FALSE;
				IF i < 8 THEN BEGIN
					Try(i+1,q,a,b,c,x);
					IF NOT(q) THEN BEGIN
						b[j] := TRUE;
						a[i+j] := TRUE;
						c[i-j+7] := TRUE
					END END
     	   		ELSE q := TRUE
			END
		END
	END;

	PROCEDURE Doit;
		VAR i: LONGINT; q: BOOLEAN;
			a: aA;
			b: bB;
			c: cC;
			x: xX;
	BEGIN
		i := 0 - 7;
		WHILE i <= 16 DO BEGIN
			IF (i >= 1) & (i <= 8) THEN a[i] := TRUE  ;
			IF i >= 2 THEN b[i] := TRUE  ;
			IF i <= 7 THEN c[i+7] := TRUE  ;
			i := i + 1;
		END ;
		Try(1, q, b, a, c, x);
	END ;

PROCEDURE Queens ;
	VAR i: LONGINT;
BEGIN i := 1;
	WHILE i <= 50 DO BEGIN Doit; i:=i+1 END
END ;

	PROCEDURE Initmatrix (VAR m: intmatrix);
		VAR temp, i, j: LONGINT;
	BEGIN i := 1;
		WHILE i <= rowsize DO BEGIN
			j := 1;
			WHILE j <= rowsize DO BEGIN
				temp := Rand;
				m[i][j] := temp - (temp DIV 120)*120 - 60;
				j:=j+1
			END ;
			i:=i+1
		END
	END;

	PROCEDURE Innerproduct(VAR result: LONGINT; VAR a,b: intmatrix; row,column: INTEGER);
		VAR i: INTEGER;
	BEGIN
		result := 0; i := 1;
		WHILE i <= rowsize DO BEGIN result := result+a[row][i]*b[i][column]; i:=i+1 END
	END;

PROCEDURE Intmm ;
	VAR i, j: INTEGER;
BEGIN
	ima:=intmatrixPtr(MyNewPtr(SIZEOF(intmatrix)));
	imb:=intmatrixPtr(MyNewPtr(SIZEOF(intmatrix)));
	imr:=intmatrixPtr(MyNewPtr(SIZEOF(intmatrix)));
	Initrand;
	Initmatrix (ima^);
	Initmatrix (imb^);
	i := 1;
	WHILE i <= rowsize DO BEGIN j := 1;
		WHILE j <= rowsize DO BEGIN Innerproduct(imr^[i][j],ima^,imb^,i,j); j:=j+1 END ;
		i:=i+1
	END;
	DisposePtr(Ptr(ima)); DisposePtr(Ptr(imb)); DisposePtr(Ptr(imr));
END ;

	PROCEDURE rInitmatrix (VAR m: DOUBLEmatrix);
		VAR temp, i, j: LONGINT;
	BEGIN i := 1;
		WHILE i <= rowsize DO BEGIN  j := 1;
			WHILE j <= rowsize DO BEGIN
				temp := Rand;
				m[i][j] := (temp - (temp DIV 120)*120 - 60) DIV 3;
				j:=j+1
			END ;
			i:=i+1
		END
	END ;

	PROCEDURE rInnerproduct(VAR result: DOUBLE; VAR a,b: DOUBLEmatrix; row,column: INTEGER);
		VAR i: INTEGER;
	BEGIN
		result := 0.0; i := 1;
		WHILE i<=rowsize DO BEGIN result := result+a[row][i]*b[i][column]; i:=i+1 END
	END;

PROCEDURE Mm;
	VAR i, j: INTEGER;
BEGIN
	
	Initrand;
	rInitmatrix (rma^);
	rInitmatrix (rmb^);
	i := 1;
	WHILE i <= rowsize DO BEGIN j := 1;
		WHILE j <= rowsize DO BEGIN rInnerproduct(rmr^[i][j],rma^,rmb^,i,j); j:=j+1 END ;
		i:=i+1
	END;
	
END;


    (* A compute-bound program from Forest Baskett. *)

	FUNCTION Fit (i, j: LONGINT): BOOLEAN;
		VAR k: LONGINT;
	BEGIN k := 0;
		Fit:=TRUE;
		WHILE k <= piecemax[i] DO BEGIN
			IF ( p[i][k] ) THEN IF ( puzzl[j+k] ) THEN BEGIN  Fit:= FALSE; Leave END ;
			k:=k+1
		END;
	END;
	
	FUNCTION Place (i, j: LONGINT): LONGINT;
		VAR k: LONGINT;
	BEGIN k := 0; Place:=0;
		WHILE k <= piecemax[i] DO BEGIN 
			IF ( p[i][k] ) THEN puzzl[j+k] := TRUE ;
			k:=k+1
		END;
		piececount[class[i]] := piececount[class[i]] - 1;
		k := j;
		WHILE k <= sizepuzzle DO BEGIN
			IF ( NOT( puzzl[k]) ) THEN BEGIN Place:=k; Leave; END;
			k:=k+1
		END ;
	END;
	
	PROCEDURE Remove (i, j: LONGINT);
		VAR k: LONGINT;
	BEGIN k := 0;
		WHILE k <= piecemax[i] DO BEGIN
			IF ( p[i][k] ) THEN puzzl[j+k] := FALSE ;
			k:=k+1
		END;
		piececount[class[i]] := piececount[class[i]] + 1
	END ;
	
	FUNCTION Trial (j: LONGINT): BOOLEAN;
		VAR i, k: LONGINT;
	BEGIN i := 0; Trial:=FALSE;
		kount := kount + 1;
		WHILE i <= typemax DO BEGIN
			IF ( piececount[class[i]] <> 0 ) THEN
				IF ( Fit (i, j) ) THEN BEGIN
					k := Place (i, j);
					IF Trial(k) OR (k = 0) THEN BEGIN Trial:=TRUE; Leave;END
					ELSE Remove (i, j);
				END;
			i:=i+1
		END;
	END ;
	
PROCEDURE Puzzle;
	VAR i, j, k, m: LONGINT;
BEGIN
	m := 0; WHILE m <= sizepuzzle DO BEGIN puzzl[m] := TRUE; m:=m+1 END ;
	i := 1;
	WHILE i <= 5 DO BEGIN j := 1;
		WHILE j <= 5 DO BEGIN k := 1;
			WHILE k <= 5 DO BEGIN
				puzzl[i+d*(j+d*k)] := FALSE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	
	i := 0; 
	WHILE i <= typemax DO BEGIN m := 0;
		WHILE m<= sizepuzzle DO BEGIN
			p[i][m] := FALSE; m:=m+1
		END;
		i:=i+1
	END;
	
	i := 0;
	WHILE i <= 3 DO BEGIN j := 0;
		WHILE j <= 1 DO BEGIN k := 0;
			WHILE k <= 0 DO BEGIN
				p[0][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[0] := 0;
	piecemax[0] := 3+d*1+d*d*0;
	
	i := 0;
	WHILE i <= 1 DO BEGIN j := 0;
		WHILE j <= 0 DO BEGIN k := 0;
			WHILE k <= 3 DO BEGIN
				p[1][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[1] := 0;
	piecemax[1] := 1+d*0+d*d*3;
	
	i := 0;
	WHILE i <= 0 DO BEGIN j := 0;
		WHILE j <= 3 DO BEGIN k := 0;
			WHILE k <= 1 DO BEGIN
				p[2][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[2] := 0;
	piecemax[2] := 0+d*3+d*d*1;
	
	i := 0;
	WHILE i <= 1 DO BEGIN j := 0;
		WHILE j <= 3 DO BEGIN k := 0;
			WHILE k <= 0 DO BEGIN
				p[3][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[3] := 0;
	piecemax[3] := 1+d*3+d*d*0;

	i := 0;
	WHILE i <= 3 DO BEGIN j := 0;
		WHILE j <= 0 DO BEGIN k := 0;
			WHILE k <= 1 DO BEGIN
				p[4][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[4] := 0;
	piecemax[4] := 3+d*0+d*d*1;
	
	i := 0;
	WHILE i <= 0 DO BEGIN j := 0;
		WHILE j <= 1 DO BEGIN k := 0;
			WHILE k <= 3 DO BEGIN
				p[5][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[5] := 0;
	piecemax[5] := 0+d*1+d*d*3;
	
	i := 0;
	WHILE i <= 2 DO BEGIN j := 0;
		WHILE j <= 0 DO BEGIN k := 0;
			WHILE k <= 0 DO BEGIN
				p[6][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[6] := 1;
	piecemax[6] := 2+d*0+d*d*0;
	
	i := 0;
	WHILE i <= 0 DO BEGIN j := 0;
		WHILE j <= 2 DO BEGIN k := 0;
			WHILE k <= 0 DO BEGIN
				p[7][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[7] := 1;
	piecemax[7] := 0+d*2+d*d*0;
	
	i := 0;
	WHILE i <= 0 DO BEGIN j := 0;
		WHILE j <= 0 DO BEGIN k := 0;
			WHILE k <= 2 DO BEGIN
				p[8][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[8] := 1;
    piecemax[8] := 0+d*0+d*d*2;
	
	i := 0;
	WHILE i <= 1 DO BEGIN j := 0;
		WHILE j <= 1 DO BEGIN k := 0;
			WHILE k <= 0 DO BEGIN
				p[9][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[9] := 2;
	piecemax[9] := 1+d*1+d*d*0;
	
	i := 0;
	WHILE i <= 1 DO BEGIN j := 0;
		WHILE j <= 0 DO BEGIN k := 0;
			WHILE k <= 1 DO BEGIN
				p[10][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[10] := 2;
	piecemax[10] := 1+d*0+d*d*1;
	
	i := 0;
	WHILE i <= 0 DO BEGIN j := 0;
		WHILE j <= 1 DO BEGIN k := 0;
			WHILE k <= 1 DO BEGIN
				p[11][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[11] := 2;
	piecemax[11] := 0+d*1+d*d*1;
	
	i := 0;
	WHILE i <= 1 DO BEGIN j := 0;
		WHILE j <= 1 DO BEGIN k := 0;
			WHILE k <= 1 DO BEGIN
				p[12][i+d*(j+d*k)] := TRUE; k:=k+1
			END;
			j:=j+1
		END;
		i:=i+1
	END;
	class[12] := 3;
	piecemax[12] := 1+d*1+d*d*1;
	
	piececount[0] := 13;
	piececount[1] := 3;
	piececount[2] := 1;
	piececount[3] := 1;
	m := 1+d*(1+d*1);
	kount := 0;
	IF Fit(0, m) THEN n := Place(0, m);
	IF NOT( Trial(n)) THEN Debugger
	ELSE IF kount <> 2005 THEN Debugger;

END ;

	PROCEDURE Initarr;
		VAR i, temp: LONGINT;
	BEGIN
		Initrand;
		biggest := 0; littlest := 0; i := 1;
		WHILE i <= sortelements DO BEGIN
			temp := Rand;
			sortlist^[i] := temp - (temp DIV 100000)*100000 - 50000;
			IF sortlist^[i] > biggest THEN biggest := sortlist^[i]
			ELSE IF sortlist^[i] < littlest THEN littlest := sortlist^[i];
			i:=i+1
		END
	END ;

	PROCEDURE Quicksort(VAR a: Mysortlist; l,r: LONGINT);
  (* quicksort the array A from start to finish *)
		VAR i,j,x,w: LONGINT;
	BEGIN
		i:=l; j:=r;
		x:=a[(l+r) DIV 2];
		REPEAT
			WHILE a[i]<x DO  i := i+1 ;
			WHILE x<a[j] DO  j := j-1 ;
			IF i<=j THEN BEGIN
				w := a[i];
				a[i] := a[j];
				a[j] := w;
				i := i+1;    j := j-1
			END ;
		UNTIL i > j;
		IF l<j THEN Quicksort(a,l,j) ;
		IF i<r THEN Quicksort(a,i,r) ;
	END ;

PROCEDURE Quick ;
BEGIN
	sortlist:=MySPtr(MyNewPtr(SIZEOF(Mysortlist)));
    Initarr;
    Quicksort(sortlist^,1,sortelements);
	DisposePtr(Ptr(sortlist))
END ;


    (* Sorts an array using bubblesort *)

	PROCEDURE bInitarr;
		VAR i, temp: LONGINT;
	BEGIN
		Initrand;
		biggest := 0; littlest := 0; i := 1;
		WHILE i <= srtelements DO BEGIN
			temp := Rand;
			sortlist^[i] := temp - (temp DIV 100000)*100000 - 50000;
			IF sortlist^[i] > biggest THEN biggest := sortlist^[i]
			ELSE IF sortlist^[i] < littlest THEN littlest := sortlist^[i] ;
			i:=i+1
		END
	END ;

PROCEDURE Bubble;
	VAR i, j: LONGINT;
BEGIN
	sortlist:=MySPtr(MyNewPtr(SIZEOF(Mysortlist)));
	bInitarr;
	top:=srtelements;
	WHILE top>1 DO BEGIN
		i:=1;
		WHILE i<top DO BEGIN
			IF sortlist^[i] > sortlist^[i+1] THEN BEGIN
				j := sortlist^[i];
				sortlist^[i] := sortlist^[i+1];
				sortlist^[i+1] := j;
			END ;
			i:=i+1;
		END;
		top:=top-1;
	END;
	DisposePtr(Ptr(sortlist))
END ;

    (* Sorts an array using treesort *)

	PROCEDURE tInitarr;
		VAR i, temp: LONGINT;
	BEGIN
		Initrand;
		biggest := 0; littlest := 0; i := 1;
		WHILE i <= sortelements DO BEGIN
			temp := Rand;
			sortlist^[i] := temp - (temp DIV 100000)*100000 - 50000;
			IF sortlist^[i] > biggest THEN biggest := sortlist^[i]
			ELSE IF sortlist^[i] < littlest THEN littlest := sortlist^[i];
			i:=i+1
		END
	END ;

	PROCEDURE CreateNode (VAR t: node; n: LONGINT);
	BEGIN
    	NEW(t);
		t^.left := NIL; t^.right := NIL;
		t^.val := n
	END ;

	PROCEDURE Insert(n: LONGINT; t: node);
	BEGIN
		IF n > t^.val THEN
			IF t^.left = NIL THEN CreateNode(t^.left,n)
			ELSE Insert(n,t^.left)
		ELSE IF n < t^.val THEN
			IF t^.right = NIL THEN CreateNode(t^.right,n)
			ELSE Insert(n,t^.right)
	END ;

	FUNCTION Checktree(p: node): BOOLEAN;
		VAR result: BOOLEAN;
	BEGIN
		result := TRUE;
		IF p^.left <> NIL THEN
			IF p^.left^.val <= p^.val THEN result := FALSE
			ELSE result := Checktree(p^.left) & result;
		IF  p^.right <> NIL THEN
			IF p^.right^.val >= p^.val THEN result := FALSE
			ELSE result := Checktree(p^.right) & result;
		Checktree:= result
	END ;

PROCEDURE Trees;
	VAR i: LONGINT;
BEGIN
	NEW(tree); sortlist:=MySPtr(MyNewPtr(SIZEOF(Mysortlist)));
	tInitarr;
	tree^.left := NIL; tree^.right:=NIL; tree^.val:=sortlist^[1];
	i := 2;
    WHILE i <= sortelements DO BEGIN
    	Insert(sortlist^[i],tree);
    	i:=i+1
    END;
	DISPOSE(tree); DisposePtr(Ptr(sortlist));
END ;


	FUNCTION Cos (x: DOUBLE): DOUBLE;
		VAR i, factor: LONGINT;
			result,power: DOUBLE;
	BEGIN
		result := 1.0; factor := 1;  power := x; i := 2;
		WHILE i <= 10 DO BEGIN
			factor := factor * i;  power := power*x;
			IF i MOD 2 = 0 THEN
				IF i MOD 4 = 0 THEN result := result + power/factor
				ELSE result := result - power/factor;
			i:=i+1
		END ;
		Cos:= result
	END ;
	
	FUNCTION Min0( arg1, arg2: LONGINT): LONGINT;
	BEGIN
		IF arg1 < arg2 THEN Min0:= arg1
		ELSE Min0:= arg2
	END ;

	PROCEDURE Uniform11(iy: LONGINT; yfl: DOUBLE);
	BEGIN
		iy := (4855*iy + 1731) MOD 8192;
		yfl := iy/8192.0;
	END ;

	PROCEDURE Exptab(n: LONGINT; VAR e: c2array);
		VAR theta, divisor: DOUBLE; h: ARRAY [0..25] OF DOUBLE;
			i, j, k, l, m: LONGINT;
	BEGIN
		theta := 3.1415926536;
		divisor := 4.0; i:=1;
		WHILE i <= 25 DO BEGIN
			h[i] := 1/(2*Cos( theta/divisor ));
			divisor := divisor + divisor;
			i:=i+1
		END;
		m := n DIV 2 ;
		l := m DIV 2 ;
		j := 1 ;
		e[1].rp := 1.0 ;
		e[1].ip := 0.0;
		e[l+1].rp := 0.0;
		e[l+1].ip := 1.0 ;
		e[m+1].rp := -1.0 ;
		e[m+1].ip := 0.0 ;
		REPEAT
			i := l DIV 2 ;
			k := i ;
			REPEAT
				e[k+1].rp := h[j]*(e[k+i+1].rp+e[k-i+1].rp) ;
				e[k+1].ip := h[j]*(e[k+i+1].ip+e[k-i+1].ip) ;
				k := k+l ;
			UNTIL ( k > m );
			j := Min0( j+1, 25);
			l := i ;
		UNTIL ( l <= 1 );
	END ;

	PROCEDURE Fft( n: LONGINT; VAR z, w: carray; VAR e: c2array; sqrinv: DOUBLE);
		VAR i, j, k, l, m, index: LONGINT; h: DOUBLE;
	BEGIN
		m := n DIV 2 ;
		l := 1 ;
		REPEAT
			k := 0 ;
			j := l ;
			i := 1 ;
			REPEAT
				REPEAT
					w[i+k].rp := z[i].rp+z[m+i].rp ;
					w[i+k].ip := z[i].ip+z[m+i].ip ;
					h := e[k+1].rp*(z[i].rp-z[i+m].rp);
					w[i+j].rp := h-e[k+1].ip*(z[i].ip-z[i+m].ip) ;
					h := e[k+1].rp*(z[i].ip-z[i+m].ip);
					w[i+j].ip := h+e[k+1].ip*(z[i].rp-z[i+m].rp) ;
					i := i+1 ;
				UNTIL ( i > j );
				k := j ;
				j := k+l ;
			UNTIL ( j > m );
			(*z := w ;*) index := 1;
			REPEAT
				z[index] := w[index];
				index := index+1;
			UNTIL ( index > n );
			l := l+l ;
		UNTIL ( l > m );
		i := 1;
		WHILE i <= n DO BEGIN
			z[i].rp := sqrinv*z[i].rp ;
			z[i].ip := -sqrinv*z[i].ip;
			i:=i+1
		END
	END ;
	
PROCEDURE Oscar ;
	VAR i: LONGINT;
BEGIN
	Exptab(fftsize,e) ;
	seed := 5767 ; i := 1;
	WHILE i <= fftsize DO BEGIN
		Uniform11( seed, zr );
		Uniform11( seed, zi );
		z[i].rp := 20.0*zr - 10.0;
		z[i].ip := 20.0*zi - 10.0;
		i:=i+1
	END ;
	i := 1;
	WHILE i <= 20 DO BEGIN Fft(fftsize,z,w,e,0.0625); i:=i+1 END;
END ;


PROCEDURE JustDoIt;
VAR time:LONGINT;
BEGIN
	rma:=DOUBLEmatrixPtr(MyNewPtr(SIZEOF(DOUBLEmatrix)));
	rmb:=DOUBLEmatrixPtr(MyNewPtr(SIZEOF(DOUBLEmatrix)));
	rmr:=DOUBLEmatrixPtr(MyNewPtr(SIZEOF(DOUBLEmatrix)));
	
	time:=TickCount;Write('Perm ');Perm; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Towers ');Towers; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Queens ');Queens; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Intmm ');Intmm; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Mm ');Mm; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Puzzle ');Puzzle; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Quick ');Quick; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Bubble ');Bubble; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('Tree ');Trees; time:=TickCount-time; WriteLn(time);
	time:=TickCount;Write('FFT ');Oscar; time:=TickCount-time; WriteLn(time);
END ;

BEGIN
	JustDoIt
END .
