(*
 	File:		ADSPSecure.mod
 
 	Contains:	Secure AppleTalk Data Stream Protocol Interfaces.
 
 	Version:	Technology:	AOCE Toolbox 1.02
 				Package:	Universal Interfaces 2.11 in MPW Prerelease on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE ADSPSecure;

IMPORT SYSTEM, Types, AppleTalk, OCE, OCEAuthDir;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	sdspOpen*					= 229;

(*
For secure connections, the eom field of ioParams contains two single-bit flags
(instead of a zero/non-zero byte). They are an encrypt flag (see below), and an
eom flag.  All other bits in that field should be zero.

To write an encrypted message, you must set an encrypt bit in the eom field of
the ioParams of your write call. Note*: this flag is only checked on the first
write of a message (the first write on a connection, or the first write following
a write with eom set.
*)
	dspEOMBit*					= 0;							(* set if EOM at end of write *)
	dspEncryptBit*				= 1;							(* set to encrypt message *)

	dspEOMMask*					= ASH(1,dspEOMBit);
	dspEncryptMask*				= ASH(1,dspEncryptBit);

	sdspWorkSize*				= 2048;


TYPE
	TRSecureParams* = RECORD
		localCID*:				INTEGER;								(* local connection id *)
		remoteCID*:				INTEGER;								(* remote connection id *)
		remoteAddress*:			AppleTalk.AddrBlock;								(* address of remote end *)
		filterAddress*:			AppleTalk.AddrBlock;								(* address filter *)
		sendSeq*:				LONGINT;								(* local send sequence number *)
		sendWindow*:				INTEGER;								(* send window size *)
		recvSeq*:				LONGINT;								(* receive sequence number *)
		attnSendSeq*:			LONGINT;								(* attention send sequence number *)
		attnRecvSeq*:			LONGINT;								(* attention receive sequence number *)
		ocMode*:					Types.SInt8; (* unsigned char *)				(* open connection mode *)
		ocInterval*:				Types.SInt8; (* unsigned char *)				(* open connection request retry interval *)
		ocMaximum*:				Types.SInt8; (* unsigned char *)				(* open connection request retry maximum *)
		secure*:					BOOLEAN;								(*  --> TRUE if session was authenticated *)
		sessionKey*:				OCEAuthDir.AuthKeyPtr;								(* <--> encryption key for session *)
		credentialsSize*:		LONGINT;								(*  --> length of credentials *)
		credentials*:			Types.Ptr;									(*  --> pointer to credentials *)
		workspace*:				Types.Ptr;									(*  --> pointer to workspace for connection
										   align on even boundary and length* = sdspWorkSize *)
		recipient*:				OCEAuthDir.AuthIdentity;							(*  --> identity of recipient (or initiator if active mode *)
		issueTime*:				OCE.UTCTime;								(*  --> when credentials were issued *)
		expiry*:					OCE.UTCTime;								(*  --> when credentials expiry *)
		initiator*:				OCE.RecordIDPtr;							(* <--  RecordID of initiator returned here.
											Must give appropriate Buffer to hold RecordID
											(Only for passive or accept mode) *)
		hasIntermediary*:		BOOLEAN;								(* <--  will be set if credentials has an intermediary *)
		filler1*:				BOOLEAN;
		intermediary*:			OCE.RecordIDPtr;							(* <--  RecordID of intermediary returned here.
											(If intermediary is found in credentials
											Must give appropriate Buffer to hold RecordID
											(Only for passive or accept mode) *)
	END;


(* $ALIGN RESET*)
(* $POP*)

 END ADSPSecure.
