(*
 	File:		ASDebugging.mod
 
 	Contains:	AppleScript Debugging Interfaces.
 
 	Version:	Technology:	AppleScript 1.1
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE ASDebugging;

IMPORT SYSTEM, Files, Components, AppleEvents, OSA;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
(* 	This mode flag can be passed to OSASetProperty or OSASetHandler
		and will prevent properties or handlers from being defined in a context
		that doesn't already have bindings for them. An error is returned if
		a current binding doesn't already exist. *)
	kOSAModeDontDefine*			= $0001;

(**************************************************************************
	Components.Component Selectors
**************************************************************************)
	kASSelectSetPropertyObsolete* = $1101;
	kASSelectGetPropertyObsolete* = $1101;
	kASSelectSetHandlerObsolete*	= $1103;
	kASSelectGetHandlerObsolete*	= $1104;
	kASSelectGetAppTerminologyObsolete* = $1105;
	kASSelectSetProperty*		= $1106;
	kASSelectGetProperty*		= $1107;
	kASSelectSetHandler*			= $1108;
	kASSelectGetHandler*			= $1109;
	kASSelectGetAppTerminology*	= $110A;
	kASSelectGetSysTerminology*	= $110B;
	kASSelectGetPropertyNames*	= $110C;
	kASSelectGetHandlerNames*	= $110D;

(**************************************************************************
	Context Accessors
**************************************************************************)

PROCEDURE OSASetProperty*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; contextID: OSA.OSAID; (*CONST*)VAR variableName: AppleEvents.AEDesc; scriptValueID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 16, $1106, $7000, $A82A;
	(*$END*)
PROCEDURE OSAGetProperty*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; contextID: OSA.OSAID; (*CONST*)VAR variableName: AppleEvents.AEDesc; VAR resultingScriptValueID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 16, $1107, $7000, $A82A;
	(*$END*)
PROCEDURE OSAGetPropertyNames*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; contextID: OSA.OSAID; VAR resultingPropertyNames: AppleEvents.AEDescList): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 12, $110C, $7000, $A82A;
	(*$END*)
PROCEDURE OSASetHandler*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; contextID: OSA.OSAID; (*CONST*)VAR handlerName: AppleEvents.AEDesc; compiledScriptID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 16, $1108, $7000, $A82A;
	(*$END*)
PROCEDURE OSAGetHandler*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; contextID: OSA.OSAID; (*CONST*)VAR handlerName: AppleEvents.AEDesc; VAR resultingCompiledScriptID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 16, $1109, $7000, $A82A;
	(*$END*)
PROCEDURE OSAGetHandlerNames*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; contextID: OSA.OSAID; VAR resultingHandlerNames: AppleEvents.AEDescList): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 12, $110D, $7000, $A82A;
	(*$END*)
PROCEDURE OSAGetAppTerminology*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; VAR fileSpec: Files.FSSpec; terminologyID: INTEGER; VAR didLaunch: BOOLEAN; VAR terminologyList: AppleEvents.AEDesc): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 18, $110A, $7000, $A82A;
	(*$END*)
(* Errors:
	   errOSASystemError		operation failed
	*)
PROCEDURE OSAGetSysTerminology*(scriptingComponent: Components.ComponentInstance; modeFlags: LONGINT; terminologyID: INTEGER; VAR terminologyList: AppleEvents.AEDesc): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 10, $110B, $7000, $A82A;
	(*$END*)
(* Errors:
	   errOSASystemError		operation failed
	*)
(* Notes on terminology AIFF.ID

	A terminology AIFF.ID is derived from script code and language code
	as follows;

		terminologyID* = ((scriptCode & 0x7F) << 8) | (langCode & 0xFF)
*)
(**************************************************************************
	Obsolete versions provided for backward compatibility:
*)
PROCEDURE ASSetProperty*(scriptingComponent: Components.ComponentInstance; contextID: OSA.OSAID; (*CONST*)VAR variableName: AppleEvents.AEDesc; scriptValueID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 12, $1101, $7000, $A82A;
	(*$END*)
PROCEDURE ASGetProperty*(scriptingComponent: Components.ComponentInstance; contextID: OSA.OSAID; (*CONST*)VAR variableName: AppleEvents.AEDesc; VAR resultingScriptValueID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 12, $1101, $7000, $A82A;
	(*$END*)
PROCEDURE ASSetHandler*(scriptingComponent: Components.ComponentInstance; contextID: OSA.OSAID; (*CONST*)VAR handlerName: AppleEvents.AEDesc; compiledScriptID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 12, $1103, $7000, $A82A;
	(*$END*)
PROCEDURE ASGetHandler*(scriptingComponent: Components.ComponentInstance; contextID: OSA.OSAID; (*CONST*)VAR handlerName: AppleEvents.AEDesc; VAR resultingCompiledScriptID: OSA.OSAID): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 12, $1104, $7000, $A82A;
	(*$END*)
PROCEDURE ASGetAppTerminology*(scriptingComponent: Components.ComponentInstance; VAR fileSpec: Files.FSSpec; terminologID: INTEGER; VAR didLaunch: BOOLEAN; VAR terminologyList: AppleEvents.AEDesc): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 14, $1105, $7000, $A82A;
	(*$END*)
(* Errors:
		errOSASystemError		operation failed
	*)
(**************************************************************************)

(* $ALIGN RESET*)
(* $POP*)

 END ASDebugging.
