(*
 	File:		Aliases.mod
 
 	Contains:	Alias Manager Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE Aliases;

IMPORT SYSTEM, Types, Files;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	rAliasType*					= LONG("alis");						(* Aliases are stored as resources of this type *)
(* define alias resolution action rules mask *)
	kARMMountVol*				= $00000001;					(* mount the volume automatically *)
	kARMNoUI*					= $00000002;					(* no user interface allowed during resolution *)
	kARMMultVols*				= $00000008;					(* search on multiple volumes *)
	kARMSearch*					= $00000100;					(* search quickly *)
	kARMSearchMore*				= $00000200;					(* search further *)
	kARMSearchRelFirst*			= $00000400;					(* search target on a relative path first *)
(* define alias record information types *)
	asiZoneName*					= -3;							(* get zone name *)
	asiServerName*				= -2;							(* get server name *)
	asiVolumeName*				= -1;							(* get volume name *)
	asiAliasName*				= 0;							(* get aliased file/folder/volume name *)
	asiParentName*				= 1;							(* get parent folder name *)

(* define the alias record that will be the blackbox for the caller *)

TYPE
	AliasRecord* = RECORD
		userType*:				Types.OSType;									(* appl stored type like creator type *)
		aliasSize*:				INTEGER;								(* alias record size in bytes, for appl usage *)
	END;

	AliasPtr* = POINTER TO AliasRecord;
	AliasHandle* = HANDLE TO AliasRecord (* POINTER TO AliasPtr*);

(* alias record information type *)
	AliasInfoType* = INTEGER;

	AliasFilterProcPtr* = (*Types.ProcPtr;*) PROCEDURE (cpbPtr: Files.CInfoPBPtr; VAR quitFlag: BOOLEAN; myDataPtr: Types.Ptr): BOOLEAN;
	AliasFilterUPP* = Types.UniversalProcPtr;

CONST
	uppAliasFilterProcInfo* = $00000FD0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param): 1 byte result; *)

PROCEDURE NewAliasFilterProc*(userRoutine: AliasFilterProcPtr): AliasFilterUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallAliasFilterProc*(cpbPtr: Files.CInfoPBPtr; VAR quitFlag: BOOLEAN; myDataPtr: Types.Ptr; userRoutine: AliasFilterUPP): BOOLEAN;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE NewAlias*(fromFile: Files.ConstFSSpecPtr; (*CONST*)VAR target: Files.FSSpec; VAR alias: AliasHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7002, $A823;
	(*$END*)
(* create a minimal new alias for a target and return alias record handle *)
PROCEDURE NewAliasMinimal*((*CONST*)VAR target: Files.FSSpec; VAR alias: AliasHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7008, $A823;
	(*$END*)
(* create a minimal new alias from a target fullpath (optional zone and server name) and return alias record handle  *)
PROCEDURE NewAliasMinimalFromFullPath*(fullPathLength: INTEGER; fullPath: (*UNIV*) Types.Ptr; zoneName: Types.ConstStr32Param; serverName: Types.ConstStr31Param; VAR alias: AliasHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7009, $A823;
	(*$END*)
(* given an alias handle and fromFile, resolve the alias, update the alias record and return aliased filename and wasChanged flag. *)
PROCEDURE ResolveAlias*(fromFile: Files.ConstFSSpecPtr; alias: AliasHandle; VAR target: Files.FSSpec; VAR wasChanged: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7003, $A823;
	(*$END*)
(* given an alias handle and an index specifying requested alias information type, return the information from alias record as a string. *)
PROCEDURE GetAliasInfo*(alias: AliasHandle; index: AliasInfoType; VAR theString: Types.Str63): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7007, $A823;
	(*$END*)
(* 
  Given a file spec, return target file spec if input file spec is an alias.
  It resolves the entire alias chain or one step of the chain.  It returns
  info about whether the target is a folder or file; and whether the input
  file spec was an alias or not. 
*)
PROCEDURE ResolveAliasFile*(VAR theSpec: Files.FSSpec; resolveAliasChains: BOOLEAN; VAR targetIsFolder: BOOLEAN; VAR wasAliased: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700C, $A823;
	(*$END*)
PROCEDURE FollowFinderAlias*(fromFile: Files.ConstFSSpecPtr; alias: AliasHandle; logon: BOOLEAN; VAR target: Files.FSSpec; VAR wasChanged: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700F, $A823;
	(*$END*)
(* 
   Low Level Routines 
 Given an alias handle and fromFile, match the alias and return aliased filename(s) and needsUpdate flag
*)
PROCEDURE MatchAlias*(fromFile: Files.ConstFSSpecPtr; rulesMask: LONGINT; alias: AliasHandle; VAR aliasCount: INTEGER; aliasList: Files.FSSpecArrayPtr; VAR needsUpdate: BOOLEAN; aliasFilter: AliasFilterUPP; yourDataPtr: (*UNIV*) Types.Ptr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7005, $A823;
	(*$END*)
(* given a fromFile-target pair and an alias handle, update the lias record pointed to by alias handle to represent target as the new alias. *)
PROCEDURE UpdateAlias*(fromFile: Files.ConstFSSpecPtr; (*CONST*)VAR target: Files.FSSpec; alias: AliasHandle; VAR wasChanged: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7006, $A823;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END Aliases.
