(*
 	File:		AppleGuide.mod
 
 	Contains:	Apple Guide Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE AppleGuide;

IMPORT SYSTEM, Types, Memory, Files, AppleEvents;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)
	
TYPE
	AGRefNum* = Types.UInt32;

	AGCoachRefNum* = Types.UInt32;

	AGContextRefNum* = Types.UInt32;

	AGAppInfo* = RECORD
		eventId*:				AppleEvents.AEEventID;
		refCon*:					LONGINT;
		contextObj*:				Types.Ptr;									(* private system field*)
	END;

	AGAppInfoPtr* = POINTER TO AGAppInfo;
	AGAppInfoHdl* = HANDLE TO AGAppInfo (* POINTER TO AGAppInfoPtr*);

	CoachReplyProcPtr* = (*Types.ProcPtr;*) PROCEDURE (VAR pRect: Types.Rect; name: Types.Ptr; refCon: LONGINT): Types.OSErr;
	ContextReplyProcPtr* = (*Types.ProcPtr;*) PROCEDURE (pInputData: Types.Ptr; inputDataSize: Memory.Size; VAR ppOutputData: Types.Ptr; VAR pOutputDataSize: Memory.Size; hAppInfo: AGAppInfoHdl): Types.OSErr;
	CoachReplyUPP* = Types.UniversalProcPtr;
	ContextReplyUPP* = Types.UniversalProcPtr;

CONST
	uppCoachReplyProcInfo* = $00000FE0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param): 2 byte result; *)
	uppContextReplyProcInfo* = $0000FFE0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param, 4 byte param, 4 byte param): 2 byte result; *)

PROCEDURE NewCoachReplyProc*(userRoutine: CoachReplyProcPtr): CoachReplyUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewContextReplyProc*(userRoutine: ContextReplyProcPtr): ContextReplyUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallCoachReplyProc*(VAR pRect: Types.Rect; name: Types.Ptr; refCon: LONGINT; userRoutine: CoachReplyUPP): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallContextReplyProc*(pInputData: Types.Ptr; inputDataSize: Memory.Size; VAR ppOutputData: Types.Ptr; VAR pOutputDataSize: Memory.Size; hAppInfo: AGAppInfoHdl; userRoutine: ContextReplyUPP): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

CONST
	gestaltAppleGuidePresent*	= 31;
	gestaltAppleGuideIsDebug*	= 30;
	kAGDefault*					= 0;
	kAGFrontDatabase*			= 1;
	kAGNoMixin*					= -1;

	kAGViewFullHowdy*			= 1;							(* Full-size Howdy*)
	kAGViewTopicAreas*			= 2;							(* Full-size Topic Areas*)
	kAGViewIndex*				= 3;							(* Full-size Index Terms*)
	kAGViewLookFor*				= 4;							(* Full-size Look-For (Search)*)
	kAGViewSingleHowdy*			= 5;							(* Single-list-size Howdy*)
	kAGViewSingleTopics*			= 6;							(* Single-list-size Topics*)

	kAGFileMain*					= LONG("poco");
	kAGFileMixin*				= LONG("mixn");

(* To test against AGGetAvailableDBTypes*)
	kAGDBTypeBitAny*				= $00000001;
	kAGDBTypeBitHelp*			= $00000002;
	kAGDBTypeBitTutorial*		= $00000004;
	kAGDBTypeBitShortcuts*		= $00000008;
	kAGDBTypeBitAbout*			= $00000010;
	kAGDBTypeBitOther*			= $00000080;

	
TYPE
	AGStatus* = Types.UInt16;

(* Returned by AGGetStatus*)

CONST
	kAGIsNotRunning*				= 0;
	kAGIsSleeping*				= 1;
	kAGIsActive*					= 2;

	
TYPE
	AGWindowKind* = Types.UInt16;

(* Returned by AGGetFrontWindowKind*)

CONST
	kAGNoWindow*					= 0;
	kAGAccessWindow*				= 1;
	kAGPresentationWindow*		= 2;

(* Error Codes*)
(* Not an enum, because other OSErrs are valid.*)
	
TYPE
	AGErr* = Types.SInt16;

(* Apple Guide error codes*)

CONST
(* -------------------- Apple event reply codes*)
	kAGErrUnknownEvent*			= -2900;
	kAGErrCantStartup*			= -2901;
	kAGErrNoAccWin*				= -2902;
	kAGErrNoPreWin*				= -2903;
	kAGErrNoSequence*			= -2904;
	kAGErrNotOopsSequence*		= -2905;
	kAGErrReserved06*			= -2906;
	kAGErrNoPanel*				= -2907;
	kAGErrContentNotFound*		= -2908;
	kAGErrMissingString*			= -2909;
	kAGErrInfoNotAvail*			= -2910;
	kAGErrEventNotAvailable*		= -2911;
	kAGErrCannotMakeCoach*		= -2912;
	kAGErrSessionIDsNotMatch*	= -2913;
	kAGErrMissingDatabaseSpec*	= -2914;
(* -------------------- Coach's Chalkboard reply codes*)
	kAGErrItemNotFound*			= -2925;
	kAGErrBalloonResourceNotFound* = -2926;
	kAGErrChalkResourceNotFound*	= -2927;
	kAGErrChdvResourceNotFound*	= -2928;
	kAGErrAlreadyShowing*		= -2929;
	kAGErrBalloonResourceSkip*	= -2930;
	kAGErrItemNotVisible*		= -2931;
	kAGErrReserved32*			= -2932;
	kAGErrNotFrontProcess*		= -2933;
	kAGErrMacroResourceNotFound*	= -2934;
(* -------------------- API reply codes*)
	kAGErrAppleGuideNotAvailable* = -2951;
	kAGErrCannotInitCoach*		= -2952;
	kAGErrCannotInitContext*		= -2953;
	kAGErrCannotOpenAliasFile*	= -2954;
	kAGErrNoAliasResource*		= -2955;
	kAGErrDatabaseNotAvailable*	= -2956;
	kAGErrDatabaseNotOpen*		= -2957;
	kAGErrMissingAppInfoHdl*		= -2958;
	kAGErrMissingContextObject*	= -2959;
	kAGErrInvalidRefNum*			= -2960;
	kAGErrDatabaseOpen*			= -2961;
	kAGErrInsufficientMemory*	= -2962;

(* Events*)
(* Not an enum because we want to make assignments.*)
	
TYPE
	AGEvent* = Types.UInt32;

(* Handy events for AGGeneral.*)

CONST
(* Panel actions (Require a presentation window).*)
	kAGEventDoCoach*				= LONG("doco");
	kAGEventDoHuh*				= LONG("dhuh");
	kAGEventGoNext*				= LONG("gonp");
	kAGEventGoPrev*				= LONG("gopp");
	kAGEventHidePanel*			= LONG("pahi");
	kAGEventReturnBack*			= LONG("gobk");
	kAGEventShowPanel*			= LONG("pash");
	kAGEventTogglePanel*			= LONG("patg");

(* Functions*)
(* AGClose*)
(* Close the database associated with the AGRefNum.*)

PROCEDURE AGClose*(VAR refNum: AGRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7011, $AA6E;
	(*$END*)
(* AGGeneral*)
(* Cause various events to happen.*)
PROCEDURE AGGeneral*(refNum: AGRefNum; theEvent: AGEvent): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700D, $AA6E;
	(*$END*)
(* AGGetAvailableDBTypes*)
(* Return the database types available for this application.*)
PROCEDURE AGGetAvailableDBTypes*(): Types.UInt32;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7008, $AA6E;
	(*$END*)
(* AGGetFrontWindowKind*)
(* Return the kind of the front window.*)
PROCEDURE AGGetFrontWindowKind*(refNum: AGRefNum): AGWindowKind;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700C, $AA6E;
	(*$END*)
(* AGGetFSSpec*)
(* Return the Files.FSSpec for the AGRefNum.*)
PROCEDURE AGGetFSSpec*(refNum: AGRefNum; VAR fileSpec: Files.FSSpec): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700F, $AA6E;
	(*$END*)
(* AGGetStatus*)
(* Return the status of Apple Guide.*)
PROCEDURE AGGetStatus*(): AGStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7009, $AA6E;
	(*$END*)
(* AGInstallCoachHandler*)
(* Install a Coach object location query handler.*)
PROCEDURE AGInstallCoachHandler*(coachReplyProc: CoachReplyUPP; refCon: LONGINT; VAR resultRefNum: AGCoachRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7012, $AA6E;
	(*$END*)
(* AGInstallContextHandler*)
(* Install a context check query handler.*)
PROCEDURE AGInstallContextHandler*(contextReplyProc: ContextReplyUPP; eventID: AppleEvents.AEEventID; refCon: LONGINT; VAR resultRefNum: AGContextRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7013, $AA6E;
	(*$END*)
(* AGIsDatabaseOpen*)
(* Return true if the database associated with the AGRefNum is open.*)
PROCEDURE AGIsDatabaseOpen*(refNum: AGRefNum): BOOLEAN;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7006, $AA6E;
	(*$END*)
(* AGOpen*)
(* Open a guide database.*)
PROCEDURE AGOpen*(VAR fileSpec: Files.FSSpec; flags: Types.UInt32; mixinControl: Types.Handle; VAR resultRefNum: AGRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7001, $AA6E;
	(*$END*)
(* AGOpenWithSearch*)
(* Open a guide database and preset a search string.*)
PROCEDURE AGOpenWithSearch*(VAR fileSpec: Files.FSSpec; flags: Types.UInt32; mixinControl: Types.Handle; searchString: Types.ConstStr255Param; VAR resultRefNum: AGRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7002, $AA6E;
	(*$END*)
(* AGOpenWithSequence*)
(* Open a guide database and display a presentation window sequence.*)
PROCEDURE AGOpenWithSequence*(VAR fileSpec: Files.FSSpec; flags: Types.UInt32; mixinControl: Types.Handle; sequenceID: INTEGER; VAR resultRefNum: AGRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7004, $AA6E;
	(*$END*)
(* AGOpenWithView*)
(* Open a guide database and override the default view.*)
PROCEDURE AGOpenWithView*(VAR fileSpec: Files.FSSpec; flags: Types.UInt32; mixinControl: Types.Handle; viewNum: INTEGER; VAR resultRefNum: AGRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7005, $AA6E;
	(*$END*)
(* AGQuit*)
(* Make Apple Guide quit.*)
PROCEDURE AGQuit*(): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7010, $AA6E;
	(*$END*)
(* AGRemoveCoachHandler*)
(* Remove the Coach object location query handler.*)
PROCEDURE AGRemoveCoachHandler*(VAR resultRefNum: AGCoachRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7014, $AA6E;
	(*$END*)
(* AGRemoveContextHandler*)
(* Remove the context check query handler.*)
PROCEDURE AGRemoveContextHandler*(VAR resultRefNum: AGContextRefNum): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7015, $AA6E;
	(*$END*)
(* AGStart*)
(* Start up Apple Guide in the background.*)
PROCEDURE AGStart*(): AGErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700A, $AA6E;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END AppleGuide.
