(*
 	File:		CMAcceleration.mod
 
 	Contains:	ColorSync 2.0 Acceleration Component Interfaces
 
 	Version:	Technology:	ColorSync 2.0
 				Package:	Universal Interfaces 2.11 in MPW Prerelease on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE CMAcceleration;

IMPORT SYSTEM, Types, Components, CMApplication;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	cmAccelerationInterfaceVersion* = 1;

(* Components.Component Type*)
	cmAccelerationComponentType*	= LONG("csac");

(* Required Components.Component function selectors*)
	cmLoadTables*				= 0;
	cmCalculateData*				= 1;

(* table data for acceleration component*)

TYPE
	CMAccelerationTableData* = RECORD
		inputLutEntryCount*:		LONGINT;								(* count of entries for input lut for one dimension*)
		inputLutWordSize*:		LONGINT;								(* count of bits of each entry ( e.g. 16 for WORD )*)
		inputLut*:				Types.Handle;									(* handle to input lut*)
		outputLutEntryCount*:	LONGINT;								(* count of entries for output lut for one dimension	*)
		outputLutWordSize*:		LONGINT;								(* count of bits of each entry ( e.g. 8 for BYTE )*)
		outputLut*:				Types.Handle;									(* handle to output lut*)
		colorLutInDim*:			LONGINT;								(* input dimension  ( e.g. 3 for LAB ; 4 for CMYK )*)
		colorLutOutDim*:			LONGINT;								(* output dimension ( e.g. 3 for LAB ; 4 for CMYK )*)
		colorLutGridPoints*:		LONGINT;								(* count of gridpoints for color lut ( for one Dimension )	*)
		colorLutWordSize*:		LONGINT;								(* count of bits of each entry ( e.g. 8 for BYTE )*)
		colorLut*:				Types.Handle;									(* handle to color lut*)
		inputColorSpace*:		CMApplication.CMBitmapColorSpace;						(* packing info for input*)
		outputColorSpace*:		CMApplication.CMBitmapColorSpace;						(* packing info for output*)
		userData*:				Types.Ptr;
		reserved1*:				LONGINT;
		reserved2*:				LONGINT;
		reserved3*:				LONGINT;
		reserved4*:				LONGINT;
		reserved5*:				LONGINT;
	END;

	CMAccelerationTableDataPtr* = POINTER TO CMAccelerationTableData;
	CMAccelerationTableDataHdl* = HANDLE TO CMAccelerationTableData (* POINTER TO CMAccelerationTableDataPtr*);

(* calc data for acceleration component*)
	CMAccelerationCalcData* = RECORD
		pixelCount*:				LONGINT;								(* count of input pixels*)
		inputData*:				Types.Ptr;									(* input array*)
		outputData*:				Types.Ptr;									(* output array*)
		reserved1*:				LONGINT;
		reserved2*:				LONGINT;
	END;

	CMAccelerationCalcDataPtr* = POINTER TO CMAccelerationCalcData;
	CMAccelerationCalcDataHdl* = HANDLE TO CMAccelerationCalcData (* POINTER TO CMAccelerationCalcDataPtr*);

(**)
(*				A c c e l e r a t i o n   C o m p o n e n t   I n t e r f a c e s*)
(**)

PROCEDURE CMAccelerationLoadTables*(CMSession: Components.ComponentInstance; tableData: CMAccelerationTableDataPtr): CMApplication.CMError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $0004, $0000, $7000, $A82A;
	(*$END*)
PROCEDURE CMAccelerationCalculateData*(CMSession: Components.ComponentInstance; calcData: CMAccelerationCalcDataPtr): CMApplication.CMError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $0004, $0001, $7000, $A82A;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END CMAcceleration.
