(*
 	File:		Connections.mod
 
 	Contains:	Communications Toolbox Connection Manager Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE Connections;

IMPORT SYSTEM, Types, OSUtils, Events, Dialogs;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
(*	current Connection Manager version	*)
	curCMVersion*				= 2;
(*	current Connection Manager Environment Record version 	*)
	curConnEnvRecVers*			= 0;
(* CMErr *)
	cmGenericError*				= -1;
	cmNoErr*						= 0;
	cmRejected*					= 1;
	cmFailed*					= 2;
	cmTimeOut*					= 3;
	cmNotOpen*					= 4;
	cmNotClosed*					= 5;
	cmNoRequestPending*			= 6;
	cmNotSupported*				= 7;
	cmNoTools*					= 8;
	cmUserCancel*				= 9;
	cmUnknownError*				= 11;

	
TYPE
	CMErr* = Types.OSErr;


CONST
	cmData*						= ASH(1,0);
	cmCntl*						= ASH(1,1);
	cmAttn*						= ASH(1,2);
	cmDataNoTimeout*				= ASH(1,4);
	cmCntlNoTimeout*				= ASH(1,5);
	cmAttnNoTimeout*				= ASH(1,6);
	cmDataClean*					= ASH(1,8);
	cmCntlClean*					= ASH(1,9);
	cmAttnClean*					= ASH(1,10);
(*		Only for CMRecFlags (not CMChannel) in the rest of this enum	*)
	cmNoMenus*					= ASH(1,16);
	cmQuiet*						= ASH(1,17);
	cmConfigChanged*				= ASH(1,18);

(* CMRecFlags and CMChannel		*)
(*		Low word of CMRecFlags is same as CMChannel	*)
	
TYPE
	CMRecFlags* = LONGINT;

	CMChannel* = INTEGER;


CONST
	cmStatusOpening*				= ASH(1,0);
	cmStatusOpen*				= ASH(1,1);
	cmStatusClosing*				= ASH(1,2);
	cmStatusDataAvail*			= ASH(1,3);
	cmStatusCntlAvail*			= ASH(1,4);
	cmStatusAttnAvail*			= ASH(1,5);
	cmStatusDRPend*				= ASH(1,6);					(* data read pending	*)
	cmStatusDWPend*				= ASH(1,7);					(* data write pending	*)
	cmStatusCRPend*				= ASH(1,8);					(* cntl read pending	*)
	cmStatusCWPend*				= ASH(1,9);					(* cntl write pending	*)
	cmStatusARPend*				= ASH(1,10);				(* attn read pending	*)
	cmStatusAWPend*				= ASH(1,11);				(* attn write pending	*)
	cmStatusBreakPend*			= ASH(1,12);
	cmStatusListenPend*			= ASH(1,13);
	cmStatusIncomingCallPresent*	= ASH(1,14);
	cmStatusReserved0*			= ASH(1,15);

	
TYPE
	CMStatFlags* = LONGINT;


CONST
	cmDataIn*					= 0;
	cmDataOut*					= 1;
	cmCntlIn*					= 2;
	cmCntlOut*					= 3;
	cmAttnIn*					= 4;
	cmAttnOut*					= 5;
	cmRsrvIn*					= 6;
	cmRsrvOut*					= 7;

	
TYPE
	CMBufFields* = INTEGER;

	CMBuffers* = ARRAY 8 (*[0..7]*) OF Types.Ptr;

	CMBufferSizes* = ARRAY 8 (*[0..7]*) OF LONGINT;


CONST
	cmSearchSevenBit*			= ASH(1,0);

	
TYPE
	CMSearchFlags* = INTEGER;


CONST
	cmFlagsEOM*					= ASH(1,0);

	
TYPE
	CMFlags* = INTEGER;

	ConnEnvironRec* = RECORD
		version*:				INTEGER;
		baudRate*:				LONGINT;
		dataBits*:				INTEGER;
		channels*:				CMChannel;
		swFlowControl*:			BOOLEAN;
		hwFlowControl*:			BOOLEAN;
		flags*:					CMFlags;
	END;

	ConnEnvironRecPtr* = POINTER TO ConnEnvironRec;

	ConnPtr* = POINTER TO ConnRecord;
	ConnHandle* = HANDLE TO ConnRecord (*POINTER TO ConnPtr*);

	ConnectionToolDefProcPtr* = (*Types.ProcPtr;*) PROCEDURE (hConn: ConnHandle; msg: INTEGER; p1: LONGINT; p2: LONGINT; p3: LONGINT): LONGINT;
	ConnectionSearchCallBackProcPtr* = (*Types.ProcPtr;*) PROCEDURE (hConn: ConnHandle; matchPtr: Types.Ptr; refNum: LONGINT);
	ConnectionCompletionProcPtr* = (*Types.ProcPtr;*) PROCEDURE (hConn: ConnHandle);
	ConnectionChooseIdleProcPtr* = (*Types.ProcPtr;*) PROCEDURE ;
	ConnectionToolDefUPP* = Types.UniversalProcPtr;
	ConnectionSearchCallBackUPP* = Types.UniversalProcPtr;
	ConnectionCompletionUPP* = Types.UniversalProcPtr;
	ConnectionChooseIdleUPP* = Types.UniversalProcPtr;

	ConnRecord* = RECORD
		procID*:					INTEGER;
		flags*:					CMRecFlags;
		errCode*:				CMErr;
		refCon*:					LONGINT;
		userData*:				LONGINT;
		defProc*:				ConnectionToolDefUPP;
		config*:					Types.Ptr;
		oldConfig*:				Types.Ptr;
		asyncEOM*:				LONGINT;
		reserved1*:				LONGINT;
		reserved2*:				LONGINT;
		cmPrivate*:				Types.Ptr;
		bufferArray*:			CMBuffers;
		bufSizes*:				CMBufferSizes;
		mluField*:				LONGINT;
		asyncCount*:				CMBufferSizes;
	END;


CONST
(* CMIOPB constants and structure *)
	cmIOPBQType*					= 10;
	cmIOPBversion*				= 0;


TYPE
	CMIOPB* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;								(* cmIOPBQType *)
		hConn*:					ConnHandle;
		theBuffer*:				Types.Ptr;
		count*:					LONGINT;
		flags*:					CMFlags;
		userCompletion*:			ConnectionCompletionUPP;
		timeout*:				LONGINT;
		errCode*:				CMErr;
		channel*:				CMChannel;
		asyncEOM*:				LONGINT;
		reserved1*:				LONGINT;
		reserved2*:				INTEGER;
		version*:				INTEGER;								(* cmIOPBversion *)
		refCon*:					LONGINT;								(* for application *)
		toolData1*:				LONGINT;								(* for tool *)
		toolData2*:				LONGINT;								(* for tool *)
	END;

	CMIOPBPtr* = POINTER TO CMIOPB;

CONST
	uppConnectionToolDefProcInfo* = $0000FEF0; (* PROCEDURE (4 byte param, 2 byte param, 4 byte param, 4 byte param, 4 byte param): 4 byte result; *)
	uppConnectionSearchCallBackProcInfo* = $00000FC0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param); *)
	uppConnectionCompletionProcInfo* = $000000C0; (* PROCEDURE (4 byte param); *)
	uppConnectionChooseIdleProcInfo* = $00000000; (* PROCEDURE ; *)

PROCEDURE CallConnectionToolDefProc*(hConn: ConnHandle; msg: INTEGER; p1: LONGINT; p2: LONGINT; p3: LONGINT; userRoutine: ConnectionToolDefUPP): LONGINT;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallConnectionSearchCallBackProc*(hConn: ConnHandle; matchPtr: Types.Ptr; refNum: LONGINT; userRoutine: ConnectionSearchCallBackUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallConnectionCompletionProc*(hConn: ConnHandle; userRoutine: ConnectionCompletionUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallConnectionChooseIdleProc*(userRoutine: ConnectionChooseIdleUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE NewConnectionToolDefProc*(userRoutine: ConnectionToolDefProcPtr): ConnectionToolDefUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewConnectionSearchCallBackProc*(userRoutine: ConnectionSearchCallBackProcPtr): ConnectionSearchCallBackUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewConnectionCompletionProc*(userRoutine: ConnectionCompletionProcPtr): ConnectionCompletionUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewConnectionChooseIdleProc*(userRoutine: ConnectionChooseIdleProcPtr): ConnectionChooseIdleUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE InitCM*(): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMGetVersion*(hConn: ConnHandle): Types.Handle;
	EXTERNAL PASCAL;
PROCEDURE CMGetCMVersion*(): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE CMNew*(procID: INTEGER; flags: CMRecFlags; VAR desiredSizes: CMBufferSizes; refCon: LONGINT; userData: LONGINT): ConnHandle;
	EXTERNAL PASCAL;
PROCEDURE CMDispose*(hConn: ConnHandle);
	EXTERNAL PASCAL;
PROCEDURE CMListen*(hConn: ConnHandle; async: BOOLEAN; completor: ConnectionCompletionUPP; timeout: LONGINT): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMAccept*(hConn: ConnHandle; accept: BOOLEAN): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMOpen*(hConn: ConnHandle; async: BOOLEAN; completor: ConnectionCompletionUPP; timeout: LONGINT): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMClose*(hConn: ConnHandle; async: BOOLEAN; completor: ConnectionCompletionUPP; timeout: LONGINT; now: BOOLEAN): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMAbort*(hConn: ConnHandle): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMStatus*(hConn: ConnHandle; VAR sizes: CMBufferSizes; VAR flags: CMStatFlags): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMIdle*(hConn: ConnHandle);
	EXTERNAL PASCAL;
PROCEDURE CMReset*(hConn: ConnHandle);
	EXTERNAL PASCAL;
PROCEDURE CMBreak*(hConn: ConnHandle; duration: LONGINT; async: BOOLEAN; completor: ConnectionCompletionUPP);
	EXTERNAL PASCAL;
PROCEDURE CMRead*(hConn: ConnHandle; theBuffer: (*UNIV*) Types.Ptr; VAR toRead: LONGINT; theChannel: CMChannel; async: BOOLEAN; completor: ConnectionCompletionUPP; timeout: LONGINT; VAR flags: CMFlags): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMWrite*(hConn: ConnHandle; theBuffer: (*UNIV*) Types.Ptr; VAR toWrite: LONGINT; theChannel: CMChannel; async: BOOLEAN; completor: ConnectionCompletionUPP; timeout: LONGINT; flags: CMFlags): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMIOKill*(hConn: ConnHandle; which: INTEGER): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMActivate*(hConn: ConnHandle; activate: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE CMResume*(hConn: ConnHandle; resume: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE CMMenu*(hConn: ConnHandle; menuID: INTEGER; item: INTEGER): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE CMValidate*(hConn: ConnHandle): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE CMDefault*(VAR theConfig: Types.Ptr; procID: INTEGER; allocate: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE CMSetupPreflight*(procID: INTEGER; VAR magicCookie: LONGINT): Types.Handle;
	EXTERNAL PASCAL;
PROCEDURE CMSetupFilter*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; VAR theEvent: Events.EventRecord; VAR theItem: INTEGER; VAR magicCookie: LONGINT): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE CMSetupSetup*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; VAR magicCookie: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE CMSetupItem*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; VAR theItem: INTEGER; VAR magicCookie: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE CMSetupXCleanup*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; OKed: BOOLEAN; VAR magicCookie: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE CMSetupPostflight*(procID: INTEGER);
	EXTERNAL PASCAL;
PROCEDURE CMGetConfig*(hConn: ConnHandle): Types.Ptr;
	EXTERNAL PASCAL;
PROCEDURE CMSetConfig*(hConn: ConnHandle; thePtr: (*UNIV*) Types.Ptr): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE CMIntlToEnglish*(hConn: ConnHandle; inputPtr: (*UNIV*) Types.Ptr; VAR outputPtr: Types.Ptr; language: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE CMEnglishToIntl*(hConn: ConnHandle; inputPtr: (*UNIV*) Types.Ptr; VAR outputPtr: Types.Ptr; language: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE CMAddSearch*(hConn: ConnHandle; theString: Types.ConstStr255Param; flags: CMSearchFlags; callBack: ConnectionSearchCallBackUPP): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE CMRemoveSearch*(hConn: ConnHandle; refnum: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE CMClearSearch*(hConn: ConnHandle);
	EXTERNAL PASCAL;
PROCEDURE CMGetConnEnvirons*(hConn: ConnHandle; VAR theEnvirons: ConnEnvironRec): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMChoose*(VAR hConn: ConnHandle; where: Types.Point; idle: ConnectionChooseIdleUPP): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE CMEvent*(hConn: ConnHandle; (*CONST*)VAR theEvent: Events.EventRecord);
	EXTERNAL PASCAL;
PROCEDURE CMGetToolName*(procID: INTEGER; VAR name: Types.Str255);
	EXTERNAL PASCAL;
PROCEDURE CMGetProcID*(name: Types.ConstStr255Param): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE CMSetRefCon*(hConn: ConnHandle; refCon: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE CMGetRefCon*(hConn: ConnHandle): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE CMGetUserData*(hConn: ConnHandle): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE CMSetUserData*(hConn: ConnHandle; userData: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE CMGetErrorString*(hConn: ConnHandle; id: INTEGER; VAR errMsg: Types.Str255);
	EXTERNAL PASCAL;
PROCEDURE CMNewIOPB*(hConn: ConnHandle; VAR theIOPB: CMIOPBPtr): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMDisposeIOPB*(hConn: ConnHandle; theIOPB: CMIOPBPtr): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMPBRead*(hConn: ConnHandle; theIOPB: CMIOPBPtr; async: BOOLEAN): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMPBWrite*(hConn: ConnHandle; theIOPB: CMIOPBPtr; async: BOOLEAN): CMErr;
	EXTERNAL PASCAL;
PROCEDURE CMPBIOKill*(hConn: ConnHandle; theIOPB: CMIOPBPtr): CMErr;
	EXTERNAL PASCAL;

(* $ALIGN RESET*)
(* $POP*)

 END Connections.
