(*
 	File:		Displays.mod
 
 	Contains:	Display Manager Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE Displays;

IMPORT SYSTEM, Types, Quickdraw, Components, Video, AppleEvents, Processes;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
(* AppleEvents Core Suite *)
	kAESystemConfigNotice*		= LONG("cnfg");
(* Core Suite types *)
	kAEDisplayNotice*			= LONG("dspl");
	kAEDisplaySummary*			= LONG("dsum");
	keyDMConfigVersion*			= LONG("dmcv");
	keyDMConfigFlags*			= LONG("dmcf");
	keyDMConfigReserved*			= LONG("dmcr");
	keyDisplayID*				= LONG("dmid");
	keyDisplayComponent*			= LONG("dmdc");
	keyDisplayDevice*			= LONG("dmdd");
	keyDisplayFlags*				= LONG("dmdf");
	keyDisplayMode*				= LONG("dmdm");
	keyDisplayModeReserved*		= LONG("dmmr");
	keyDisplayReserved*			= LONG("dmdr");
	keyDisplayMirroredId*		= LONG("dmmi");
	keyDeviceFlags*				= LONG("dddf");
	keyDeviceDepthMode*			= LONG("dddm");
	keyDeviceRect*				= LONG("dddr");
	keyPixMapRect*				= LONG("dpdr");
	keyPixMapHResolution*		= LONG("dphr");
	keyPixMapVResolution*		= LONG("dpvr");
	keyPixMapPixelType*			= LONG("dppt");
	keyPixMapPixelSize*			= LONG("dpps");
	keyPixMapCmpCount*			= LONG("dpcc");
	keyPixMapCmpSize*			= LONG("dpcs");
	keyPixMapAlignment*			= LONG("dppa");
	keyPixMapResReserved*		= LONG("dprr");
	keyPixMapReserved*			= LONG("dppr");
	keyPixMapColorTableSeed*		= LONG("dpct");
	keySummaryMenubar*			= LONG("dsmb");
	keySummaryChanges*			= LONG("dsch");
	keyDisplayOldConfig*			= LONG("dold");
	keyDisplayNewConfig*			= LONG("dnew");

	dmOnlyActiveDisplays*		= TRUE;
	dmAllDisplays*				= FALSE;

(* Switch Flags *)
	kNoSwitchConfirmBit*			= 0;							(* Flag indicating that there is no need to confirm a switch to this mode *)
	kDepthNotAvailableBit*		= 1;							(* Current depth not available in new mode *)
	kShowModeBit*				= 3;							(* Show this mode even though it requires a confirm. *)
	kModeNotResizeBit*			= 4;							(* Do not use this mode to resize display (for cards that mode drives a different connector). *)

(*	Summary Change Flags (sticky bits indicating an operation was performed)
	For example, moving a display then moving it back will still set the kMovedDisplayBit.
*)
	kBeginEndConfigureBit*		= 0;
	kMovedDisplayBit*			= 1;
	kSetMainDisplayBit*			= 2;
	kSetDisplayModeBit*			= 3;
	kAddDisplayBit*				= 4;
	kRemoveDisplayBit*			= 5;
	kNewDisplayBit*				= 6;
	kDisposeDisplayBit*			= 7;
	kEnabledDisplayBit*			= 8;
	kDisabledDisplayBit*			= 9;
	kMirrorDisplayBit*			= 10;
	kUnMirrorDisplayBit*			= 11;

(*	Power Mode constants for AVPowerStateRec.powerState.	*)
	kAVPowerOff*					= 0;
	kAVPowerStandby*				= 1;
	kAVPowerSuspend*				= 2;
	kAVPowerOn*					= 3;

(* Notification Messages for extended call back routines *)
	kDMNotifyInstalled*			= 1;							(* At install time *)
	kDMNotifyEvent*				= 2;							(* Post change time *)
	kDMNotifyRemoved*			= 3;							(* At remove time *)
	kDMNotifyPrep*				= 4;							(* Pre change time *)
	kDMNotifyExtendEvent*		= 5;							(* Allow registrees to extend apple event before it is sent *)
	kDMNotifyDependents*			= 6;							(* Minor notification check without full update *)
(* Notification Flags *)
	kExtendedNotificationProc*	= ASH(1,16);

(* types for notifyType *)
	kFullNotify*					= 0;							(* This is the appleevent whole nine yards notify *)
	kFullDependencyNotify*		= 1;							(* Only sends to those who want to know about interrelated functionality (used for updating UI) *)

(* DisplayID/DeviceID constants *)
	kDummyDeviceID*				= $0FF;							(* This is the AIFF.ID of the dummy display, used when the last real display is disabled.*)
	kInvalidDisplayID*			= $000;							(* This is the invalid AIFF.ID*)
	kFirstDisplayID*				= $100;

(* bits for panelListFlags *)
	kAllowDuplicatesBit*			= 0;

(* Constants for fidelity checks *)
	kNoFidelity*					= 0;
	kMinimumFidelity*			= 1;
	kDefaultFidelity*			= 500;							(* I'm just picking a number for Apple default panels and engines*)
	kDefaultManufacturerFidelity* = 1000;						(* I'm just picking a number for Manufacturer's panels and engines (overrides apple defaults)*)

	kAnyPanelType*				= 0;							(* Pass to DMNewEngineList for list of all panels (as opposed to specific types)*)
	kAnyEngineType*				= 0;							(* Pass to DMNewEngineList for list of all engines*)
	kAnyDeviceType*				= 0;							(* Pass to DMNewDeviceList for list of all devices*)
	kAnyPortType*				= 0;							(* Pass to DMNewDevicePortList for list of all devices*)

(* portListFlags for DM_NewDevicePortList *)
(* Should offline devices be put into the port list (such as dummy display) *)
	kPLIncludeOfflineDevicesBit*	= 0;

	
TYPE
	DMFidelityType* = LONGINT;

(* AVID is an AIFF.ID for ports and devices the old DisplayID type
	is carried on for compatibility
*)
	AVIDType* = LONGINT;

	DisplayIDType* = AVIDType;

	DMListType* = Types.Ptr;

	DMListIndexType* = LONGINT;

	AVPowerStateRec* = RECORD
		powerState*:				LONGINT;
		powerFlags*:				LONGINT;
		powerReserved1*:			LONGINT;
		powerReserved2*:			LONGINT;
	END;

	AVPowerStatePtr* = POINTER TO AVPowerStateRec;

	DMComponentListEntryRec* = RECORD
		itemID*:					DisplayIDType;							(* DisplayID Manager*)
		itemComponent*:			Components.Component;								(* Components.Component Manager*)
		itemDescription*:		Components.ComponentDescription;					(* We can always construct this if we use something beyond the compontent mgr.*)
		itemClass*:				Types.ResType;								(* Class of group to put this panel (eg geometry/color/etc for panels, brightness/contrast for engines, video out/sound/etc for devices)*)
		itemFidelity*:			DMFidelityType;							(* How good is this item for the specified search?*)
		itemFlags*:				LONGINT;								(* Set to 0 (future expansion)*)
		itemReserved*:			Types.ResType;								(* What kind of code does the itemReference point to  (right now - kPanelEntryTypeComponentMgr only)*)
		itemFuture*:				LONGINT;								(* Set to 0 (future expansion - probably an alternate code style)*)
	END;

	DMComponentListEntryPtr* = POINTER TO DMComponentListEntryRec;

(*  Move AVLocationRec to AVComponents.i AFTER AVComponents.i is created*)
	AVLocationRec* = RECORD
		locationConstant*:		LONGINT;								(* Set to 0 (future expansion - probably an alternate code style)*)
	END;

	AVLocationPtr* = POINTER TO AVLocationRec;

	DMDisplayModeListEntryRec* = RECORD
		displayModeFlags*:		LONGINT;
		displayModeSwitchInfo*:	Video.VDSwitchInfoPtr;
		displayModeResolutionInfo*: Video.VDResolutionInfoPtr;
		displayModeTimingInfo*:	Video.VDTimingInfoPtr;
		displayModeSmallestRect*: POINTER TO Types.Rect;									(* Smallest Mode Types.Rect*)
		displayModeLargestRect*:	POINTER TO Types.Rect;									(* Largest Mode Types.Rect*)
		displayModeName*:		POINTER TO Types.Str255;								(* Name of the timing mode*)
	END;

	DMDisplayModeListEntryPtr* = POINTER TO DMDisplayModeListEntryRec;

	DependentNotifyRec* = RECORD
		notifyType*:				Types.ResType;								(* What type was the engine that made the change (may be zero)*)
		notifyClass*:			Types.ResType;								(* What class was the change (eg geometry, color etc)*)
		notifyPortID*:			DisplayIDType;							(* Which device was touched (kInvalidDisplayID -> all or none)*)
		notifyComponent*:		Components.ComponentInstance;						(* What engine did it (may be 0)?*)
		notifyVersion*:			LONGINT;								(* Set to 0 (future expansion)*)
		notifyFlags*:			LONGINT;								(* Set to 0 (future expansion)*)
		notifyReserved*:			LONGINT;								(* Set to 0 (future expansion)*)
		notifyFuture*:			LONGINT;								(* Set to 0 (future expansion)*)
	END;

	DependentNotifyPtr* = POINTER TO DependentNotifyRec;

	DMNotificationProcPtr* = (*Types.ProcPtr;*) PROCEDURE (VAR theEvent: AppleEvents.AppleEvent);
	DMExtendedNotificationProcPtr* = (*Types.ProcPtr;*) PROCEDURE (userData: (*UNIV*) Types.Ptr; theMessage: INTEGER; notifyData: (*UNIV*) Types.Ptr);
	DMComponentListIteratorProcPtr* = (*Types.ProcPtr;*) PROCEDURE (userData: (*UNIV*) Types.Ptr; itemIndex: DMListIndexType; componentInfo: DMComponentListEntryPtr);
	DMDisplayModeListIteratorProcPtr* = (*Types.ProcPtr;*) PROCEDURE (userData: (*UNIV*) Types.Ptr; itemIndex: DMListIndexType; displaymodeInfo: DMDisplayModeListEntryPtr);
	DMNotificationUPP* = Types.UniversalProcPtr;
	DMExtendedNotificationUPP* = Types.UniversalProcPtr;
	DMComponentListIteratorUPP* = Types.UniversalProcPtr;
	DMDisplayModeListIteratorUPP* = Types.UniversalProcPtr;

CONST
	uppDMNotificationProcInfo* = $000000C0; (* PROCEDURE (4 byte param); *)
	uppDMExtendedNotificationProcInfo* = $00000EC0; (* PROCEDURE (4 byte param, 2 byte param, 4 byte param); *)
	uppDMComponentListIteratorProcInfo* = $00000FC0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param); *)
	uppDMDisplayModeListIteratorProcInfo* = $00000FC0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param); *)

PROCEDURE NewDMNotificationProc*(userRoutine: DMNotificationProcPtr): DMNotificationUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewDMExtendedNotificationProc*(userRoutine: DMExtendedNotificationProcPtr): DMExtendedNotificationUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewDMComponentListIteratorProc*(userRoutine: DMComponentListIteratorProcPtr): DMComponentListIteratorUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewDMDisplayModeListIteratorProc*(userRoutine: DMDisplayModeListIteratorProcPtr): DMDisplayModeListIteratorUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallDMNotificationProc*(VAR theEvent: AppleEvents.AppleEvent; userRoutine: DMNotificationUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallDMExtendedNotificationProc*(userData: (*UNIV*) Types.Ptr; theMessage: INTEGER; notifyData: (*UNIV*) Types.Ptr; userRoutine: DMExtendedNotificationUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallDMComponentListIteratorProc*(userData: (*UNIV*) Types.Ptr; itemIndex: DMListIndexType; componentInfo: DMComponentListEntryPtr; userRoutine: DMComponentListIteratorUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallDMDisplayModeListIteratorProc*(userData: (*UNIV*) Types.Ptr; itemIndex: DMListIndexType; displaymodeInfo: DMDisplayModeListEntryPtr; userRoutine: DMDisplayModeListIteratorUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE DMGetFirstScreenDevice*(activeOnly: BOOLEAN): Quickdraw.GDHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7000, $ABEB;
	(*$END*)
PROCEDURE DMGetNextScreenDevice*(theDevice: Quickdraw.GDHandle; activeOnly: BOOLEAN): Quickdraw.GDHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7001, $ABEB;
	(*$END*)
PROCEDURE DMDrawDesktopRect*(VAR globalRect: Types.Rect);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7002, $ABEB;
	(*$END*)
PROCEDURE DMDrawDesktopRegion*(globalRgn: Quickdraw.RgnHandle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7003, $ABEB;
	(*$END*)
PROCEDURE DMBeginConfigureDisplays*(VAR displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0206, $ABEB;
	(*$END*)
PROCEDURE DMEndConfigureDisplays*(displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0207, $ABEB;
	(*$END*)
PROCEDURE DMAddDisplay*(newDevice: Quickdraw.GDHandle; driver: INTEGER; mode: LONGINT; reserved: LONGINT; displayID: LONGINT; displayComponent: Components.Component; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0D08, $ABEB;
	(*$END*)
PROCEDURE DMMoveDisplay*(moveDevice: Quickdraw.GDHandle; x: INTEGER; y: INTEGER; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0609, $ABEB;
	(*$END*)
PROCEDURE DMDisableDisplay*(disableDevice: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $040A, $ABEB;
	(*$END*)
PROCEDURE DMEnableDisplay*(enableDevice: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $040B, $ABEB;
	(*$END*)
PROCEDURE DMRemoveDisplay*(removeDevice: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $040C, $ABEB;
	(*$END*)
PROCEDURE DMSetMainDisplay*(newMainDevice: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0410, $ABEB;
	(*$END*)
PROCEDURE DMSetDisplayMode*(theDevice: Quickdraw.GDHandle; mode: LONGINT; VAR depthMode: LONGINT; reserved: LONGINT; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A11, $ABEB;
	(*$END*)
PROCEDURE DMCheckDisplayMode*(theDevice: Quickdraw.GDHandle; mode: LONGINT; depthMode: LONGINT; VAR switchFlags: LONGINT; reserved: LONGINT; VAR modeOk: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0C12, $ABEB;
	(*$END*)
PROCEDURE DMGetDeskRegion*(VAR desktopRegion: Quickdraw.RgnHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0213, $ABEB;
	(*$END*)
PROCEDURE DMRegisterNotifyProc*(notificationProc: DMNotificationUPP; whichPSN: Processes.ProcessSerialNumberPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0414, $ABEB;
	(*$END*)
PROCEDURE DMRemoveNotifyProc*(notificationProc: DMNotificationUPP; whichPSN: Processes.ProcessSerialNumberPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0415, $ABEB;
	(*$END*)
PROCEDURE DMQDIsMirroringCapable*(VAR qdIsMirroringCapable: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0216, $ABEB;
	(*$END*)
PROCEDURE DMCanMirrorNow*(VAR canMirrorNow: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0217, $ABEB;
	(*$END*)
PROCEDURE DMIsMirroringOn*(VAR isMirroringOn: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0218, $ABEB;
	(*$END*)
PROCEDURE DMMirrorDevices*(gD1: Quickdraw.GDHandle; gD2: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0619, $ABEB;
	(*$END*)
PROCEDURE DMUnmirrorDevice*(gDevice: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $041A, $ABEB;
	(*$END*)
PROCEDURE DMGetNextMirroredDevice*(gDevice: Quickdraw.GDHandle; VAR mirroredDevice: Quickdraw.GDHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $041B, $ABEB;
	(*$END*)
PROCEDURE DMBlockMirroring*(): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $701C, $ABEB;
	(*$END*)
PROCEDURE DMUnblockMirroring*(): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $701D, $ABEB;
	(*$END*)
PROCEDURE DMGetDisplayMgrA5World*(VAR dmA5: Types.Ptr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $021E, $ABEB;
	(*$END*)
PROCEDURE DMGetDisplayIDByGDevice*(displayDevice: Quickdraw.GDHandle; VAR displayID: DisplayIDType; failToMain: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $051F, $ABEB;
	(*$END*)
PROCEDURE DMGetGDeviceByDisplayID*(displayID: DisplayIDType; VAR displayDevice: Quickdraw.GDHandle; failToMain: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0520, $ABEB;
	(*$END*)
PROCEDURE DMSetDisplayComponent*(theDevice: Quickdraw.GDHandle; displayComponent: Components.Component): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0421, $ABEB;
	(*$END*)
PROCEDURE DMGetDisplayComponent*(theDevice: Quickdraw.GDHandle; VAR displayComponent: Components.Component): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0422, $ABEB;
	(*$END*)
PROCEDURE DMNewDisplay*(VAR newDevice: Quickdraw.GDHandle; driverRefNum: INTEGER; mode: LONGINT; reserved: LONGINT; displayID: DisplayIDType; displayComponent: Components.Component; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0D23, $ABEB;
	(*$END*)
PROCEDURE DMDisposeDisplay*(disposeDevice: Quickdraw.GDHandle; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0424, $ABEB;
	(*$END*)
PROCEDURE DMResolveDisplayComponents*(): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7025, $ABEB;
	(*$END*)
PROCEDURE DMRegisterExtendedNotifyProc*(notifyProc: DMExtendedNotificationUPP; notifyUserData: (*UNIV*) Types.Ptr; nofifyOnFlags: INTEGER; whichPSN: Processes.ProcessSerialNumberPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $07EF, $ABEB;
	(*$END*)
PROCEDURE DMRemoveExtendedNotifyProc*(notifyProc: DMExtendedNotificationUPP; notifyUserData: (*UNIV*) Types.Ptr; whichPSN: Processes.ProcessSerialNumberPtr; removeFlags: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0726, $ABEB;
	(*$END*)
PROCEDURE DMNewAVPanelList*(displayID: DisplayIDType; panelType: Types.ResType; minimumFidelity: DMFidelityType; panelListFlags: LONGINT; reserved: LONGINT; VAR thePanelCount: DMListIndexType; VAR thePanelList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0C27, $ABEB;
	(*$END*)
PROCEDURE DMNewAVEngineList*(displayID: DisplayIDType; engineType: Types.ResType; minimumFidelity: DMFidelityType; engineListFlags: LONGINT; reserved: LONGINT; VAR engineCount: DMListIndexType; VAR engineList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0C28, $ABEB;
	(*$END*)
PROCEDURE DMNewAVDeviceList*(deviceType: Types.ResType; deviceListFlags: LONGINT; reserved: LONGINT; VAR deviceCount: DMListIndexType; VAR deviceList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A29, $ABEB;
	(*$END*)
PROCEDURE DMNewAVPortListByPortType*(subType: Types.ResType; portListFlags: LONGINT; reserved: LONGINT; VAR devicePortCount: DMListIndexType; VAR theDevicePortList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A2A, $ABEB;
	(*$END*)
PROCEDURE DMGetIndexedComponentFromList*(panelList: DMListType; itemIndex: DMListIndexType; reserved: LONGINT; listIterator: DMComponentListIteratorUPP; userData: (*UNIV*) Types.Ptr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A2B, $ABEB;
	(*$END*)
PROCEDURE DMDisposeList*(panelList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $022C, $ABEB;
	(*$END*)
PROCEDURE DMGetNameByAVID*(theID: AVIDType; VAR name: Types.Str255): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $042D, $ABEB;
	(*$END*)
PROCEDURE DMNewAVIDByPortComponent*(thePortComponent: Components.Component; portKind: Types.ResType; reserved: LONGINT; VAR newID: AVIDType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $082E, $ABEB;
	(*$END*)
PROCEDURE DMGetPortComponentByAVID*(thePortID: DisplayIDType; VAR thePortComponent: Components.Component; VAR theDesciption: Components.ComponentDescription; VAR thePortKind: Types.ResType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $082F, $ABEB;
	(*$END*)
PROCEDURE DMSendDependentNotification*(notifyType: Types.ResType; notifyClass: Types.ResType; displayID: AVIDType; notifyComponent: Components.ComponentInstance): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A30, $ABEB;
	(*$END*)
PROCEDURE DMDisposePortComponent*(thePortComponent: Components.Component): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0231, $ABEB;
	(*$END*)
PROCEDURE DMSaveScreenPrefs*(reserved1: LONGINT; saveFlags: LONGINT; reserved2: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0632, $ABEB;
	(*$END*)
PROCEDURE DMNewAVIDByDeviceComponent*(theDeviceComponent: Components.Component; portKind: Types.ResType; reserved: LONGINT; VAR newID: DisplayIDType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0833, $ABEB;
	(*$END*)
PROCEDURE DMNewAVPortListByDeviceAVID*(theID: AVIDType; minimumFidelity: DMFidelityType; portListFlags: LONGINT; reserved: LONGINT; VAR devicePortCount: DMListIndexType; VAR theDevicePortList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0C34, $ABEB;
	(*$END*)
PROCEDURE DMGetDeviceComponentByAVID*(theDeviceID: AVIDType; VAR theDeviceComponent: Components.Component; VAR theDesciption: Components.ComponentDescription; VAR theDeviceKind: Types.ResType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0835, $ABEB;
	(*$END*)
PROCEDURE DMNewDisplayModeList*(displayID: DisplayIDType; modeListFlags: LONGINT; reserved: LONGINT; VAR thePanelCount: DMListIndexType; VAR thePanelList: DMListType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A36, $ABEB;
	(*$END*)
PROCEDURE DMGetIndexedDisplayModeFromList*(panelList: DMListType; itemIndex: DMListIndexType; reserved: LONGINT; listIterator: DMDisplayModeListIteratorUPP; userData: (*UNIV*) Types.Ptr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A37, $ABEB;
	(*$END*)
PROCEDURE DMGetGraphicInfoByAVID*(theID: AVIDType; VAR theAVPcit: Quickdraw.PicHandle; VAR theAVIconSuite: Types.Handle; VAR theAVLocation: AVLocationRec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0838, $ABEB;
	(*$END*)
PROCEDURE DMGetAVPowerState*(theID: AVIDType; getPowerState: AVPowerStatePtr; reserved1: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0839, $ABEB;
	(*$END*)
PROCEDURE DMSetAVPowerState*(theID: AVIDType; setPowerState: AVPowerStatePtr; reserved1: LONGINT; displayState: Types.Handle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $083A, $ABEB;
	(*$END*)
PROCEDURE DMGetDeviceAVIDByPortAVID*(portAVID: AVIDType; VAR deviceAVID: AVIDType): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $043B, $ABEB;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END Displays.
