(*
 	File:		Files.mod
 
 	Contains:	File Manager (HFS and MFS) Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$IF UNDEFINED OLDROUTINENAMES*)
(*$SET OLDROUTINENAMES FALSE*)
(*$END*)
(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE Files;

IMPORT SYSTEM, Types, OSUtils;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
(* Finder Constants *)
	fsAtMark*					= 0;
	fOnDesk*						= 1;
	fsCurPerm*					= 0;
	fHasBundle*					= 8192;
	fsRdPerm*					= 1;
	fInvisible*					= 16384;
	fTrash*						= -3;
	fsWrPerm*					= 2;
	fDesktop*					= -2;
	fsRdWrPerm*					= 3;
	fDisk*						= 0;
	fsRdWrShPerm*				= 4;
	fsFromStart*					= 1;
	fsFromLEOF*					= 2;
	fsFromMark*					= 3;
	rdVerify*					= 64;
	ioMapBuffer*					= 4;
	ioModeReserved*				= 8;
	ioDirFlg*					= 3;							(* see IM IV-125 *)
	ioDirMask*					= $10;
	fsRtParID*					= 1;
	fsRtDirID*					= 2;

(* CatSearch SearchBits Constants *)
	fsSBPartialName*				= 1;
	fsSBFullName*				= 2;
	fsSBFlAttrib*				= 4;
	fsSBFlFndrInfo*				= 8;
	fsSBFlLgLen*					= 32;
	fsSBFlPyLen*					= 64;
	fsSBFlRLgLen*				= 128;
	fsSBFlRPyLen*				= 256;
	fsSBFlCrDat*					= 512;
	fsSBFlMdDat*					= 1024;
	fsSBFlBkDat*					= 2048;
	fsSBFlXFndrInfo*				= 4096;
	fsSBFlParID*					= 8192;
	fsSBNegate*					= 16384;
	fsSBDrUsrWds*				= 8;
	fsSBDrNmFls*					= 16;
	fsSBDrCrDat*					= 512;
	fsSBDrMdDat*					= 1024;
	fsSBDrBkDat*					= 2048;
	fsSBDrFndrInfo*				= 4096;

	fsSBDrParID*					= 8192;
(* vMAttrib (GetVolParms) bit position constants *)
	bLimitFCBs*					= 31;
	bLocalWList*					= 30;
	bNoMiniFndr*					= 29;
	bNoVNEdit*					= 28;
	bNoLclSync*					= 27;
	bTrshOffLine*				= 26;
	bNoSwitchTo*					= 25;
	bNoDeskItems*				= 20;
	bNoBootBlks*					= 19;
	bAccessCntl*					= 18;
	bNoSysDir*					= 17;
	bHasExtFSVol*				= 16;
	bHasOpenDeny*				= 15;
	bHasCopyFile*				= 14;
	bHasMoveRename*				= 13;
	bHasDesktopMgr*				= 12;
	bHasShortName*				= 11;
	bHasFolderLock*				= 10;
	bHasPersonalAccessPrivileges* = 9;

	bHasUserGroupList*			= 8;
	bHasCatSearch*				= 7;
	bHasFileIDs*					= 6;
	bHasBTreeMgr*				= 5;
	bHasBlankAccessPrivileges*	= 4;
(* Desktop Database icon Constants *)
	kLargeIcon*					= 1;
	kLarge4BitIcon*				= 2;
	kLarge8BitIcon*				= 3;
	kSmallIcon*					= 4;
	kSmall4BitIcon*				= 5;
	kSmall8BitIcon*				= 6;
	kLargeIconSize*				= 256;
	kLarge4BitIconSize*			= 512;
	kLarge8BitIconSize*			= 1024;
	kSmallIconSize*				= 64;
	kSmall4BitIconSize*			= 128;
	kSmall8BitIconSize*			= 256;
(* Foreign Privilege Model Identifiers *)
	fsUnixPriv*					= 1;
(* Version Release Stage Codes *)
	developStage*				= $20;
	alphaStage*					= $40;

	betaStage*					= $60;
	finalStage*					= $80;
(* Authentication Constants *)
	kNoUserAuthentication*		= 1;
	kPassword*					= 2;
	kEncryptPassword*			= 3;
	kTwoWayEncryptPassword*		= 6;

	hFileInfo*					= 0;
	dirInfo*						= 1;

	
TYPE
	CInfoType* = Types.SInt8;


CONST
(* mapping codes (ioObjType) for MapName & MapID *)
	kOwnerID2Name*				= 1;
	kGroupID2Name*				= 2;
	kOwnerName2ID*				= 3;
	kGroupName2ID*				= 4;
(* types of oj object to be returned (ioObjType) for _GetUGEntry *)
	kReturnNextUser*				= 1;
	kReturnNextGroup*			= 2;
	kReturnNextUG*				= 3;


TYPE
	FInfo* = RECORD
		fdType*:					Types.OSType;									(*the type of the file*)
		fdCreator*:				Types.OSType;									(*file's creator*)
		fdFlags*:				INTEGER;								(*flags ex. hasbundle,invisible,locked, etc.*)
		fdLocation*:				Types.Point;									(*file's location in folder*)
		fdFldr*:					INTEGER;								(*folder containing file*)
	END;

	FXInfo* = RECORD
		fdIconID*:				INTEGER;								(*Icon AIFF.ID*)
		fdUnused*:				ARRAY 3 (*[0..2]*) OF INTEGER;				(*unused but reserved 6 bytes*)
		fdScript*:				Types.SInt8;									(*Script flag and number*)
		fdXFlags*:				Types.SInt8;									(*More flag bits*)
		fdComment*:				INTEGER;								(*AIFF.Comment AIFF.ID*)
		fdPutAway*:				LONGINT;								(*Home Dir AIFF.ID*)
	END;

	DInfo* = RECORD
		frRect*:					Types.Rect;									(*folder rect*)
		frFlags*:				INTEGER;								(*Flags*)
		frLocation*:				Types.Point;									(*folder location*)
		frView*:					INTEGER;								(*folder view*)
	END;

	DXInfo* = RECORD
		frScroll*:				Types.Point;									(*scroll position*)
		frOpenChain*:			LONGINT;								(*DirID chain of open folders*)
		frScript*:				Types.SInt8;									(*Script flag and number*)
		frXFlags*:				Types.SInt8;									(*More flag bits*)
		frComment*:				INTEGER;								(*comment*)
		frPutAway*:				LONGINT;								(*DirID*)
	END;

	GetVolParmsInfoBuffer* = RECORD
		vMVersion*:				INTEGER;								(*version number*)
		vMAttrib*:				LONGINT;								(*bit vector of attributes (see vMAttrib constants)*)
		vMLocalHand*:			Types.Handle;									(*handle to private data*)
		vMServerAdr*:			LONGINT;								(*AppleTalk server address or zero*)
		vMVolumeGrade*:			LONGINT;								(*approx. speed rating or zero if unrated*)
		vMForeignPrivID*:		INTEGER;								(*foreign privilege model supported or zero if none*)
	END;

	ParmBlkPtr* = POINTER TO ParamBlockRec;

	(*
		IOCompletionProcPtr uses register based parameters on the 68k and cannot
		be written in or called from a high-level language without the help of
		mixed mode or assembly glue.

		In*:
		 => paramBlock  	A0.L
	*)
	IOCompletionProcPtr* = Types.Register68kProcPtr;  (* register PROCEDURE IOCompletion*(paramBlock: OSUtils.ParmBlkPtr); *)
	IOCompletionUPP* = Types.UniversalProcPtr;

	IOParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioRefNum*:				INTEGER;
		ioVersNum*:				Types.SInt8;
		ioPermssn*:				Types.SInt8;
		ioMisc*:					Types.Ptr;
		ioBuffer*:				Types.Ptr;
		ioReqCount*:				LONGINT;
		ioActCount*:				LONGINT;
		ioPosMode*:				INTEGER;
		ioPosOffset*:			LONGINT;
	END;

	IOParamPtr* = POINTER TO IOParam;

	FileParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioFRefNum*:				INTEGER;
		ioFVersNum*:				Types.SInt8;
		filler1*:				Types.SInt8;
		ioFDirIndex*:			INTEGER;
		ioFlAttrib*:				Types.SInt8;
		ioFlVersNum*:			Types.SInt8;
		ioFlFndrInfo*:			FInfo;
		ioFlNum*:				LONGINT;
		ioFlStBlk*:				INTEGER;
		ioFlLgLen*:				LONGINT;
		ioFlPyLen*:				LONGINT;
		ioFlRStBlk*:				INTEGER;
		ioFlRLgLen*:				LONGINT;
		ioFlRPyLen*:				LONGINT;
		ioFlCrDat*:				LONGINT;
		ioFlMdDat*:				LONGINT;
	END;

	FileParamPtr* = POINTER TO FileParam;

	VolumeParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler2*:				LONGINT;
		ioVolIndex*:				INTEGER;
		ioVCrDate*:				LONGINT;
		ioVLsBkUp*:				LONGINT;
		ioVAtrb*:				INTEGER;
		ioVNmFls*:				INTEGER;
		ioVDirSt*:				INTEGER;
		ioVBlLn*:				INTEGER;
		ioVNmAlBlks*:			INTEGER;
		ioVAlBlkSiz*:			LONGINT;
		ioVClpSiz*:				LONGINT;
		ioAlBlSt*:				INTEGER;
		ioVNxtFNum*:				LONGINT;
		ioVFrBlk*:				INTEGER;
	END;

	VolumeParamPtr* = POINTER TO VolumeParam;

	CntrlParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioCRefNum*:				INTEGER;
		csCode*:					INTEGER;
		csParam*:				ARRAY 11 (*[0..10]*) OF INTEGER;
	END;

	CntrlParamPtr* = POINTER TO CntrlParam;

	SlotDevParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioSRefNum*:				INTEGER;
		ioSVersNum*:				Types.SInt8;
		ioSPermssn*:				Types.SInt8;
		ioSMix*:					Types.Ptr;
		ioSFlags*:				INTEGER;
		ioSlot*:					Types.SInt8;
		ioID*:					Types.SInt8;
	END;

	SlotDevParamPtr* = POINTER TO SlotDevParam;

	MultiDevParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioMRefNum*:				INTEGER;
		ioMVersNum*:				Types.SInt8;
		ioMPermssn*:				Types.SInt8;
		ioMMix*:					Types.Ptr;
		ioMFlags*:				INTEGER;
		ioSEBlkPtr*:				Types.Ptr;
	END;

	MultiDevParamPtr* = POINTER TO MultiDevParam;

	ParamBlockRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		(*CASE INTEGER OF
		0: ( *)
	END;
	IOParamBlockRec* = RECORD(ParamBlockRec)
			ioRefNum*:					INTEGER;
			ioVersNum*:					Types.SInt8;
			ioPermssn*:					Types.SInt8;
			ioMisc*:						Types.Ptr;
			ioBuffer*:					Types.Ptr;
			ioReqCount*:					LONGINT;
			ioActCount*:					LONGINT;
			ioPosMode*:					INTEGER;
			ioPosOffset*:				LONGINT;
		   (* );
		1: ( *)
	END;
	FileParamBlockRec* = RECORD(ParamBlockRec)
			ioFRefNum*:					INTEGER;
			ioFVersNum*:					Types.SInt8;
			filler1*:					Types.SInt8;
			ioFDirIndex*:				INTEGER;
			ioFlAttrib*:					Types.SInt8;
			ioFlVersNum*:				Types.SInt8;
			ioFlFndrInfo*:				FInfo;
			ioFlNum*:					LONGINT;
			ioFlStBlk*:					INTEGER;
			ioFlLgLen*:					LONGINT;
			ioFlPyLen*:					LONGINT;
			ioFlRStBlk*:					INTEGER;
			ioFlRLgLen*:					LONGINT;
			ioFlRPyLen*:					LONGINT;
			ioFlCrDat*:					LONGINT;
			ioFlMdDat*:					LONGINT;
		   (* );
		2: ( *)
	END;
	VolumeParamBlockRec* = RECORD(ParamBlockRec)
			filler2*:					LONGINT;
			ioVolIndex*:					INTEGER;
			ioVCrDate*:					LONGINT;
			ioVLsBkUp*:					LONGINT;
			ioVAtrb*:					INTEGER;
			ioVNmFls*:					INTEGER;
			ioVDirSt*:					INTEGER;
			ioVBlLn*:					INTEGER;
			ioVNmAlBlks*:				INTEGER;
			ioVAlBlkSiz*:				LONGINT;
			ioVClpSiz*:					LONGINT;
			ioAlBlSt*:					INTEGER;
			ioVNxtFNum*:					LONGINT;
			ioVFrBlk*:					INTEGER;
		   (* );
		3: ( *)
	END;
	CntrlParamBlockRec* = RECORD(ParamBlockRec)
			ioCRefNum*:					INTEGER;
			csCode*:						INTEGER;
			csParam*:					ARRAY 11 (*[0..10]*) OF INTEGER;
		   (* );
		4: ( *)
	END;
	SlotDevParamBlockRec* = RECORD(ParamBlockRec)
			ioSRefNum*:					INTEGER;
			ioSVersNum*:					Types.SInt8;
			ioSPermssn*:					Types.SInt8;
			ioSMix*:						Types.Ptr;
			ioSFlags*:					INTEGER;
			ioSlot*:						Types.SInt8;
			ioID*:						Types.SInt8;
		   (* );
		5: ( *)
	END;
	MultiDevParamBlockRec* = RECORD(ParamBlockRec)
			ioMRefNum*:					INTEGER;
			ioMVersNum*:					Types.SInt8;
			ioMPermssn*:					Types.SInt8;
			ioMMix*:						Types.Ptr;
			ioMFlags*:					INTEGER;
			ioSEBlkPtr*:					Types.Ptr;
		   (* );*)
	END;

	CInfoPBRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioFRefNum*:				INTEGER;
		ioFVersNum*:				Types.SInt8;
		filler1*:				Types.SInt8;
		ioFDirIndex*:			INTEGER;
		ioFlAttrib*:				Types.SInt8;
		filler2*:				Types.SInt8;
		(* CASE INTEGER OF
		0: ( *)
	END;
	FileInfoPBRec* = RECORD(CInfoPBRec)
			ioFlFndrInfo*:				FInfo;
			ioDirID*:					LONGINT;
			ioFlStBlk*:					INTEGER;
			ioFlLgLen*:					LONGINT;
			ioFlPyLen*:					LONGINT;
			ioFlRStBlk*:					INTEGER;
			ioFlRLgLen*:					LONGINT;
			ioFlRPyLen*:					LONGINT;
			ioFlCrDat*:					LONGINT;
			ioFlMdDat*:					LONGINT;
			ioFlBkDat*:					LONGINT;
			ioFlXFndrInfo*:				FXInfo;
			ioFlParID*:					LONGINT;
			ioFlClpSiz*:					LONGINT;
		   (* );
		1: ( *)
	END;
	DirInfoPBRec* = RECORD(CInfoPBRec)
			ioDrUsrWds*:					DInfo;
			ioDrDirID*:					LONGINT;
			ioDrNmFls*:					INTEGER;
			filler3*:					ARRAY 9 (*[0..8]*) OF INTEGER;
			ioDrCrDat*:					LONGINT;
			ioDrMdDat*:					LONGINT;
			ioDrBkDat*:					LONGINT;
			ioDrFndrInfo*:				DXInfo;
			ioDrParID*:					LONGINT;
		   (* );*)
	END;

	CInfoPBPtr* = POINTER TO CInfoPBRec;

	CatPositionRec* = RECORD
		initialize*:				LONGINT;
		priv*:					ARRAY 6 (*[0..5]*) OF INTEGER;
	END;

	FSSpec* = RECORD
		vRefNum*:				INTEGER;
		parID*:					LONGINT;
		name*:					Types.Str63;
	END;

	FSSpecPtr* = POINTER TO FSSpec;
	FSSpecHandle* = HANDLE TO FSSpec (* POINTER TO FSSpecPtr*);

(* pointer to array of FSSpecs *)
	FSSpecArrayPtr* = FSSpecPtr;

(* The only difference between "const FSSpec*" and "ConstFSSpecPtr" is 
   that as a parameter, ConstFSSpecPtr is allowed to be NULL *)
	ConstFSSpecPtr* = POINTER TO FSSpec;

(* The following are structures to be filled out with the _GetVolMountInfo call
 and passed back into the _VolumeMount call for external file system mounts. *)
(* the "signature" of the file system *)
	VolumeType* = Types.OSType;


CONST
(* the signature for AppleShare *)
	AppleShareMediaType*			= LONG("afpm");


TYPE
	VolMountInfoHeader* = RECORD
		length*:					INTEGER;								(* length of location data (including self) *)
		media*:					VolumeType;								(* type of media.  Variable length data follows *)
	END;

	VolMountInfoPtr* = POINTER TO VolMountInfoHeader;

	AFPVolMountInfo* = RECORD
		length*:					INTEGER;								(* length of location data (including self) *)
		media*:					VolumeType;								(* type of media *)
		flags*:					INTEGER;								(* bits for no messages, no reconnect *)
		nbpInterval*:			Types.SInt8;									(* NBP Interval parameter (IM2, p.322) *)
		nbpCount*:				Types.SInt8;									(* NBP Interval parameter (IM2, p.322) *)
		uamType*:				INTEGER;								(* User Authentication Method *)
		zoneNameOffset*:			INTEGER;								(* short positive offset from start of struct to Memory.Zone Name *)
		serverNameOffset*:		INTEGER;								(* offset to pascal Server Name string *)
		volNameOffset*:			INTEGER;								(* offset to pascal Volume Name string *)
		userNameOffset*:			INTEGER;								(* offset to pascal User Name string *)
		userPasswordOffset*:		INTEGER;								(* offset to pascal User Password string *)
		volPasswordOffset*:		INTEGER;								(* offset to pascal Volume Password string *)
		AFPData*:				(*PACKED*) ARRAY 144 (*[0..143]*) OF CHAR;			(* variable length data may follow *)
	END;

	AFPVolMountInfoPtr* = POINTER TO AFPVolMountInfo;

	DTPBRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioDTRefNum*:				INTEGER;								(* desktop refnum *)
		ioIndex*:				INTEGER;
		ioTagInfo*:				LONGINT;
		ioDTBuffer*:				Types.Ptr;
		ioDTReqCount*:			LONGINT;
		ioDTActCount*:			LONGINT;
		ioFiller1*:				Types.SInt8;
		ioIconType*:				Types.SInt8;
		ioFiller2*:				INTEGER;
		ioDirID*:				LONGINT;
		ioFileCreator*:			Types.OSType;
		ioFileType*:				Types.OSType;
		ioFiller3*:				LONGINT;
		ioDTLgLen*:				LONGINT;
		ioDTPyLen*:				LONGINT;
		ioFiller4*:				ARRAY 14 (*[0..13]*) OF INTEGER;
		ioAPPLParID*:			LONGINT;
	END;

	DTPBPtr* = POINTER TO DTPBRec;

	HIOParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioRefNum*:				INTEGER;
		ioVersNum*:				Types.SInt8;
		ioPermssn*:				Types.SInt8;
		ioMisc*:					Types.Ptr;
		ioBuffer*:				Types.Ptr;
		ioReqCount*:				LONGINT;
		ioActCount*:				LONGINT;
		ioPosMode*:				INTEGER;
		ioPosOffset*:			LONGINT;
	END;

	HIOParamPtr* = POINTER TO HIOParam;

	HFileParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioFRefNum*:				INTEGER;
		ioFVersNum*:				Types.SInt8;
		filler1*:				Types.SInt8;
		ioFDirIndex*:			INTEGER;
		ioFlAttrib*:				Types.SInt8;
		ioFlVersNum*:			Types.SInt8;
		ioFlFndrInfo*:			FInfo;
		ioDirID*:				LONGINT;
		ioFlStBlk*:				INTEGER;
		ioFlLgLen*:				LONGINT;
		ioFlPyLen*:				LONGINT;
		ioFlRStBlk*:				INTEGER;
		ioFlRLgLen*:				LONGINT;
		ioFlRPyLen*:				LONGINT;
		ioFlCrDat*:				LONGINT;
		ioFlMdDat*:				LONGINT;
	END;

	HFileParamPtr* = POINTER TO HFileParam;

	HVolumeParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler2*:				LONGINT;
		ioVolIndex*:				INTEGER;
		ioVCrDate*:				LONGINT;
		ioVLsMod*:				LONGINT;
		ioVAtrb*:				INTEGER;
		ioVNmFls*:				INTEGER;
		ioVBitMap*:				INTEGER;
		ioAllocPtr*:				INTEGER;
		ioVNmAlBlks*:			INTEGER;
		ioVAlBlkSiz*:			LONGINT;
		ioVClpSiz*:				LONGINT;
		ioAlBlSt*:				INTEGER;
		ioVNxtCNID*:				LONGINT;
		ioVFrBlk*:				INTEGER;
		ioVSigWord*:				INTEGER;
		ioVDrvInfo*:				INTEGER;
		ioVDRefNum*:				INTEGER;
		ioVFSID*:				INTEGER;
		ioVBkUp*:				LONGINT;
		ioVSeqNum*:				INTEGER;
		ioVWrCnt*:				LONGINT;
		ioVFilCnt*:				LONGINT;
		ioVDirCnt*:				LONGINT;
		ioVFndrInfo*:			ARRAY 8 (*[0..7]*) OF LONGINT;
	END;

	HVolumeParamPtr* = POINTER TO HVolumeParam;

	AccessParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler3*:				INTEGER;
		ioDenyModes*:			INTEGER;
		filler4*:				INTEGER;
		filler5*:				Types.SInt8;
		ioACUser*:				Types.SInt8;
		filler6*:				LONGINT;
		ioACOwnerID*:			LONGINT;
		ioACGroupID*:			LONGINT;
		ioACAccess*:				LONGINT;
		ioDirID*:				LONGINT;
	END;

	AccessParamPtr* = POINTER TO AccessParam;

	ObjParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler7*:				INTEGER;
		ioObjType*:				INTEGER;
		ioObjNamePtr*:			Types.StringPtr;
		ioObjID*:				LONGINT;
	END;

	ObjParamPtr* = POINTER TO ObjParam;

	CopyParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioDstVRefNum*:			INTEGER;
		filler8*:				INTEGER;
		ioNewName*:				Types.StringPtr;
		ioCopyName*:				Types.StringPtr;
		ioNewDirID*:				LONGINT;
		filler14*:				LONGINT;
		filler15*:				LONGINT;
		ioDirID*:				LONGINT;
	END;

	CopyParamPtr* = POINTER TO CopyParam;

	WDParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler9*:				INTEGER;
		ioWDIndex*:				INTEGER;
		ioWDProcID*:				LONGINT;
		ioWDVRefNum*:			INTEGER;
		filler10*:				INTEGER;
		filler11*:				LONGINT;
		filler12*:				LONGINT;
		filler13*:				LONGINT;
		ioWDDirID*:				LONGINT;
	END;

	WDParamPtr* = POINTER TO WDParam;

	FIDParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler14*:				LONGINT;
		ioDestNamePtr*:			Types.StringPtr;
		filler15*:				LONGINT;
		ioDestDirID*:			LONGINT;
		filler16*:				LONGINT;
		filler17*:				LONGINT;
		ioSrcDirID*:				LONGINT;
		filler18*:				INTEGER;
		ioFileID*:				LONGINT;
	END;

	FIDParamPtr* = POINTER TO FIDParam;

	ForeignPrivParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioFiller21*:				LONGINT;
		ioFiller22*:				LONGINT;
		ioForeignPrivBuffer*:	Types.Ptr;
		ioForeignPrivActCount*:	LONGINT;
		ioForeignPrivReqCount*:	LONGINT;
		ioFiller23*:				LONGINT;
		ioForeignPrivDirID*:		LONGINT;
		ioForeignPrivInfo1*:		LONGINT;
		ioForeignPrivInfo2*:		LONGINT;
		ioForeignPrivInfo3*:		LONGINT;
		ioForeignPrivInfo4*:		LONGINT;
	END;

	ForeignPrivParamPtr* = POINTER TO ForeignPrivParam;

	CSParam* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioMatchPtr*:				FSSpecPtr;
		ioReqMatchCount*:		LONGINT;
		ioActMatchCount*:		LONGINT;
		ioSearchBits*:			LONGINT;
		ioSearchInfo1*:			CInfoPBPtr;
		ioSearchInfo2*:			CInfoPBPtr;
		ioSearchTime*:			LONGINT;
		ioCatPosition*:			CatPositionRec;
		ioOptBuffer*:			Types.Ptr;
		ioOptBufSize*:			LONGINT;
	END;

	CSParamPtr* = POINTER TO CSParam;

	HParamBlockRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		(* CASE INTEGER OF
		0: ( *)
	END;
	HIOParamBlockRec* = RECORD(HParamBlockRec)
			ioRefNum*:					INTEGER;
			ioVersNum*:					Types.SInt8;
			ioPermssn*:					Types.SInt8;
			ioMisc*:						Types.Ptr;
			ioBuffer*:					Types.Ptr;
			ioReqCount*:					LONGINT;
			ioActCount*:					LONGINT;
			ioPosMode*:					INTEGER;
			ioPosOffset*:				LONGINT;
		   (* );
		1: ( *)
	END;
	HFileParamBlockRec* = RECORD(HParamBlockRec)
			ioFRefNum*:					INTEGER;
			ioFVersNum*:					Types.SInt8;
			filler1*:					Types.SInt8;
			ioFDirIndex*:				INTEGER;
			ioFlAttrib*:					Types.SInt8;
			ioFlVersNum*:				Types.SInt8;
			ioFlFndrInfo*:				FInfo;
			ioDirID*:					LONGINT;
			ioFlStBlk*:					INTEGER;
			ioFlLgLen*:					LONGINT;
			ioFlPyLen*:					LONGINT;
			ioFlRStBlk*:					INTEGER;
			ioFlRLgLen*:					LONGINT;
			ioFlRPyLen*:					LONGINT;
			ioFlCrDat*:					LONGINT;
			ioFlMdDat*:					LONGINT;
		   (* );
		2: ( *)
	END;
	HVolumeParamBlockRec* = RECORD(HParamBlockRec)
			filler2*:					LONGINT;
			ioVolIndex*:					INTEGER;
			ioVCrDate*:					LONGINT;
			ioVLsMod*:					LONGINT;
			ioVAtrb*:					INTEGER;
			ioVNmFls*:					INTEGER;
			ioVBitMap*:					INTEGER;
			ioAllocPtr*:					INTEGER;
			ioVNmAlBlks*:				INTEGER;
			ioVAlBlkSiz*:				LONGINT;
			ioVClpSiz*:					LONGINT;
			ioAlBlSt*:					INTEGER;
			ioVNxtCNID*:					LONGINT;
			ioVFrBlk*:					INTEGER;
			ioVSigWord*:					INTEGER;
			ioVDrvInfo*:					INTEGER;
			ioVDRefNum*:					INTEGER;
			ioVFSID*:					INTEGER;
			ioVBkUp*:					LONGINT;
			ioVSeqNum*:					INTEGER;
			ioVWrCnt*:					LONGINT;
			ioVFilCnt*:					LONGINT;
			ioVDirCnt*:					LONGINT;
			ioVFndrInfo*:				ARRAY 8 (*[0..7]*) OF LONGINT;
		   (* );
		3: ( *)
	END;
	HAccessParamBlockRec* = RECORD(HParamBlockRec)
			filler3*:					INTEGER;
			ioDenyModes*:				INTEGER;
			filler4*:					INTEGER;
			filler5*:					Types.SInt8;
			ioACUser*:					Types.SInt8;
			filler6*:					LONGINT;
			ioACOwnerID*:				LONGINT;
			ioACGroupID*:				LONGINT;
			ioACAccess*:					LONGINT;
		   (* );
		4: ( *)
	END;
	HObjParamBlockRec* = RECORD(HParamBlockRec)
			filler7*:					INTEGER;
			ioObjType*:					INTEGER;
			ioObjNamePtr*:				Types.StringPtr;
			ioObjID*:					LONGINT;
		   (* );
		5: ( *)
	END;
	HCopyParamBlockRec* = RECORD(HParamBlockRec)
			ioDstVRefNum*:				INTEGER;
			filler8*:					INTEGER;
			ioNewName*:					Types.StringPtr;
			ioCopyName*:					Types.StringPtr;
			ioNewDirID*:					LONGINT;
		   (* );
		6: ( *)
	END;
	HWDParamBlockRec* = RECORD(HParamBlockRec)
			filler9*:					INTEGER;
			ioWDIndex*:					INTEGER;
			ioWDProcID*:					LONGINT;
			ioWDVRefNum*:				INTEGER;
			filler10*:					INTEGER;
			filler11*:					LONGINT;
			filler12*:					LONGINT;
			filler13*:					LONGINT;
			ioWDDirID*:					LONGINT;
		   (* );
		7: ( *)
	END;
	HFIDParamBlockRec* = RECORD(HParamBlockRec)
			filler14*:					LONGINT;
			ioDestNamePtr*:				Types.StringPtr;
			filler15*:					LONGINT;
			ioDestDirID*:				LONGINT;
			filler16*:					LONGINT;
			filler17*:					LONGINT;
			ioSrcDirID*:					LONGINT;
			filler18*:					INTEGER;
			ioFileID*:					LONGINT;
		   (* );
		8: ( *)
	END;
	HCSParamBlockRec* = RECORD(HParamBlockRec)
			ioMatchPtr*:					FSSpecPtr;
			ioReqMatchCount*:			LONGINT;
			ioActMatchCount*:			LONGINT;
			ioSearchBits*:				LONGINT;
			ioSearchInfo1*:				CInfoPBPtr;
			ioSearchInfo2*:				CInfoPBPtr;
			ioSearchTime*:				LONGINT;
			ioCatPosition*:				CatPositionRec;
			ioOptBuffer*:				Types.Ptr;
			ioOptBufSize*:				LONGINT;
		   (* );
		9: ( *)
	END;
	HForeignPrivParamBlockRec* = RECORD(HParamBlockRec)
			ioFiller21*:					LONGINT;
			ioFiller22*:					LONGINT;
			ioForeignPrivBuffer*:		Types.Ptr;
			ioForeignPrivActCount*:		LONGINT;
			ioForeignPrivReqCount*:		LONGINT;
			ioFiller23*:					LONGINT;
			ioForeignPrivDirID*:			LONGINT;
			ioForeignPrivInfo1*:			LONGINT;
			ioForeignPrivInfo2*:			LONGINT;
			ioForeignPrivInfo3*:			LONGINT;
			ioForeignPrivInfo4*:			LONGINT;
		   (* );*)
	END;

	HParmBlkPtr* = POINTER TO HParamBlockRec;

	CMovePBRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler1*:				LONGINT;
		ioNewName*:				Types.StringPtr;
		filler2*:				LONGINT;
		ioNewDirID*:				LONGINT;
		filler3*:				ARRAY 2 (*[0..1]*) OF LONGINT;
		ioDirID*:				LONGINT;
	END;

	CMovePBPtr* = POINTER TO CMovePBRec;

	WDPBRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		filler1*:				INTEGER;
		ioWDIndex*:				INTEGER;
		ioWDProcID*:				LONGINT;
		ioWDVRefNum*:			INTEGER;
		filler2*:				ARRAY 7 (*[0..6]*) OF INTEGER;
		ioWDDirID*:				LONGINT;
	END;

	WDPBPtr* = POINTER TO WDPBRec;

	FCBPBRec* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		ioTrap*:					INTEGER;
		ioCmdAddr*:				Types.Ptr;
		ioCompletion*:			IOCompletionUPP;
		ioResult*:				Types.OSErr;
		ioNamePtr*:				Types.StringPtr;
		ioVRefNum*:				INTEGER;
		ioRefNum*:				INTEGER;
		filler*:					INTEGER;
		ioFCBIndx*:				INTEGER;
		filler1*:				INTEGER;
		ioFCBFlNm*:				LONGINT;
		ioFCBFlags*:				INTEGER;
		ioFCBStBlk*:				INTEGER;
		ioFCBEOF*:				LONGINT;
		ioFCBPLen*:				LONGINT;
		ioFCBCrPs*:				LONGINT;
		ioFCBVRefNum*:			INTEGER;
		ioFCBClpSiz*:			LONGINT;
		ioFCBParID*:				LONGINT;
	END;

	FCBPBPtr* = POINTER TO FCBPBRec;

	VCB* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		vcbFlags*:				INTEGER;
		vcbSigWord*:				INTEGER;
		vcbCrDate*:				LONGINT;
		vcbLsMod*:				LONGINT;
		vcbAtrb*:				INTEGER;
		vcbNmFls*:				INTEGER;
		vcbVBMSt*:				INTEGER;
		vcbAllocPtr*:			INTEGER;
		vcbNmAlBlks*:			INTEGER;
		vcbAlBlkSiz*:			LONGINT;
		vcbClpSiz*:				LONGINT;
		vcbAlBlSt*:				INTEGER;
		vcbNxtCNID*:				LONGINT;
		vcbFreeBks*:				INTEGER;
		vcbVN*:					Types.Str27;
		vcbDrvNum*:				INTEGER;
		vcbDRefNum*:				INTEGER;
		vcbFSID*:				INTEGER;
		vcbVRefNum*:				INTEGER;
		vcbMAdr*:				Types.Ptr;
		vcbBufAdr*:				Types.Ptr;
		vcbMLen*:				INTEGER;
		vcbDirIndex*:			INTEGER;
		vcbDirBlk*:				INTEGER;
		vcbVolBkUp*:				LONGINT;
		vcbVSeqNum*:				INTEGER;
		vcbWrCnt*:				LONGINT;
		vcbXTClpSiz*:			LONGINT;
		vcbCTClpSiz*:			LONGINT;
		vcbNmRtDirs*:			INTEGER;
		vcbFilCnt*:				LONGINT;
		vcbDirCnt*:				LONGINT;
		vcbFndrInfo*:			ARRAY 8 (*[0..7]*) OF LONGINT;
		vcbVCSize*:				INTEGER;
		vcbVBMCSiz*:				INTEGER;
		vcbCtlCSiz*:				INTEGER;
		vcbXTAlBlks*:			INTEGER;
		vcbCTAlBlks*:			INTEGER;
		vcbXTRef*:				INTEGER;
		vcbCTRef*:				INTEGER;
		vcbCtlBuf*:				Types.Ptr;
		vcbDirIDM*:				LONGINT;
		vcbOffsM*:				INTEGER;
	END;

	DrvQEl* = RECORD
		qLink*:					OSUtils.QElemPtr;
		qType*:					INTEGER;
		dQDrive*:				INTEGER;
		dQRefNum*:				INTEGER;
		dQFSID*:					INTEGER;
		dQDrvSz*:				INTEGER;
		dQDrvSz2*:				INTEGER;
	END;

	DrvQElPtr* = POINTER TO DrvQEl;

CONST
	uppIOCompletionProcInfo* = $00009802; (* Register PROCEDURE (4 bytes in A0); *)

PROCEDURE NewIOCompletionProc*(userRoutine: IOCompletionProcPtr): IOCompletionUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallIOCompletionProc*(paramBlock: ParmBlkPtr; userRoutine: IOCompletionUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL ; (**)
	(*To be implemented*:  Glue to move parameters into registers.*)
	(*$END*)

PROCEDURE PBOpen*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBOpenSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A000, $3E80;
	(*$END*)
PROCEDURE PBOpenAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A400, $3E80;
	(*$END*)
PROCEDURE PBOpenImmed*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A200, $3E80;
	(*$END*)
PROCEDURE PBClose*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBCloseSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A001, $3E80;
	(*$END*)
PROCEDURE PBCloseAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A401, $3E80;
	(*$END*)
PROCEDURE PBCloseImmed*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A201, $3E80;
	(*$END*)
PROCEDURE PBRead*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBReadSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A002, $3E80;
	(*$END*)
PROCEDURE PBReadAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A402, $3E80;
	(*$END*)
PROCEDURE PBReadImmed*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A202, $3E80;
	(*$END*)
PROCEDURE PBWrite*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBWriteSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A003, $3E80;
	(*$END*)
PROCEDURE PBWriteAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A403, $3E80;
	(*$END*)
PROCEDURE PBWriteImmed*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A203, $3E80;
	(*$END*)
PROCEDURE PBGetVInfo*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetVInfoSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A007, $3E80;
	(*$END*)
PROCEDURE PBGetVInfoAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A407, $3E80;
	(*$END*)
PROCEDURE PBGetVol*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetVolSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A014, $3E80;
	(*$END*)
PROCEDURE PBGetVolAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A414, $3E80;
	(*$END*)
PROCEDURE PBSetVol*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetVolSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A015, $3E80;
	(*$END*)
PROCEDURE PBSetVolAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A415, $3E80;
	(*$END*)
PROCEDURE PBFlushVol*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBFlushVolSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A013, $3E80;
	(*$END*)
PROCEDURE PBFlushVolAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A413, $3E80;
	(*$END*)
PROCEDURE PBCreate*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBCreateSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A008, $3E80;
	(*$END*)
PROCEDURE PBCreateAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A408, $3E80;
	(*$END*)
PROCEDURE PBDelete*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDeleteSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A009, $3E80;
	(*$END*)
PROCEDURE PBDeleteAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A409, $3E80;
	(*$END*)
PROCEDURE PBOpenDF*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBOpenDFSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $701A, $A060, $3E80;
	(*$END*)
PROCEDURE PBOpenDFAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $701A, $A460, $3E80;
	(*$END*)
PROCEDURE PBOpenRF*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBOpenRFSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A00A, $3E80;
	(*$END*)
PROCEDURE PBOpenRFAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A40A, $3E80;
	(*$END*)
PROCEDURE PBRename*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBRenameSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A00B, $3E80;
	(*$END*)
PROCEDURE PBRenameAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A40B, $3E80;
	(*$END*)
PROCEDURE PBGetFInfo*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetFInfoSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A00C, $3E80;
	(*$END*)
PROCEDURE PBGetFInfoAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A40C, $3E80;
	(*$END*)
PROCEDURE PBSetFInfo*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetFInfoSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A00D, $3E80;
	(*$END*)
PROCEDURE PBSetFInfoAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A40D, $3E80;
	(*$END*)
PROCEDURE PBSetFLock*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetFLockSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A041, $3E80;
	(*$END*)
PROCEDURE PBSetFLockAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A441, $3E80;
	(*$END*)
PROCEDURE PBRstFLock*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBRstFLockSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A042, $3E80;
	(*$END*)
PROCEDURE PBRstFLockAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A442, $3E80;
	(*$END*)
PROCEDURE PBSetFVers*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetFVersSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A043, $3E80;
	(*$END*)
PROCEDURE PBSetFVersAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A443, $3E80;
	(*$END*)
PROCEDURE PBAllocate*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBAllocateSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A010, $3E80;
	(*$END*)
PROCEDURE PBAllocateAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A410, $3E80;
	(*$END*)
PROCEDURE PBGetEOF*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetEOFSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A011, $3E80;
	(*$END*)
PROCEDURE PBGetEOFAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A411, $3E80;
	(*$END*)
PROCEDURE PBSetEOF*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetEOFSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A012, $3E80;
	(*$END*)
PROCEDURE PBSetEOFAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A412, $3E80;
	(*$END*)
PROCEDURE PBGetFPos*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetFPosSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A018, $3E80;
	(*$END*)
PROCEDURE PBGetFPosAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A418, $3E80;
	(*$END*)
PROCEDURE PBSetFPos*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetFPosSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A044, $3E80;
	(*$END*)
PROCEDURE PBSetFPosAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A444, $3E80;
	(*$END*)
PROCEDURE PBFlushFile*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBFlushFileSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A045, $3E80;
	(*$END*)
PROCEDURE PBFlushFileAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A445, $3E80;
	(*$END*)
PROCEDURE PBMountVol*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A00F, $3E80;
	(*$END*)
PROCEDURE PBUnmountVol*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A00E, $3E80;
	(*$END*)
PROCEDURE PBEject*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A017, $3E80;
	(*$END*)
PROCEDURE PBOffLine*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A035, $3E80;
	(*$END*)
PROCEDURE PBCatSearch*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBCatSearchSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7018, $A260, $3E80;
	(*$END*)
PROCEDURE PBCatSearchAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7018, $A660, $3E80;
	(*$END*)
PROCEDURE SetVol*(volName: Types.StringPtr; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE UnmountVol*(volName: Types.StringPtr; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE Eject*(volName: Types.StringPtr; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE FlushVol*(volName: Types.StringPtr; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HSetVol*(volName: Types.StringPtr; vRefNum: INTEGER; dirID: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE AddDrive*(drvrRefNum: INTEGER; drvNum: INTEGER; qEl: DrvQElPtr);
	EXTERNAL PASCAL;
PROCEDURE FSOpen*(fileName: Types.ConstStr255Param; vRefNum: INTEGER; VAR refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE OpenDF*(fileName: Types.ConstStr255Param; vRefNum: INTEGER; VAR refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE FSClose*(refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE FSRead*(refNum: INTEGER; VAR count: LONGINT; buffPtr: (*UNIV*) Types.Ptr): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE FSWrite*(refNum: INTEGER; VAR count: LONGINT; buffPtr: (*UNIV*) Types.Ptr): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetVInfo*(drvNum: INTEGER; volName: Types.StringPtr; VAR vRefNum: INTEGER; VAR freeBytes: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetFInfo*(fileName: Types.ConstStr255Param; vRefNum: INTEGER; VAR fndrInfo: FInfo): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetVol*(volName: Types.StringPtr; VAR vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE Create*(fileName: Types.ConstStr255Param; vRefNum: INTEGER; creator: Types.OSType; fileType: Types.OSType): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE FSDelete*(fileName: Types.ConstStr255Param; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE OpenRF*(fileName: Types.ConstStr255Param; vRefNum: INTEGER; VAR refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE Rename*(oldName: Types.ConstStr255Param; vRefNum: INTEGER; newName: Types.ConstStr255Param): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE SetFInfo*(fileName: Types.ConstStr255Param; vRefNum: INTEGER; (*CONST*)VAR fndrInfo: FInfo): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE SetFLock*(fileName: Types.ConstStr255Param; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE RstFLock*(fileName: Types.ConstStr255Param; vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE Allocate*(refNum: INTEGER; VAR count: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetEOF*(refNum: INTEGER; VAR logEOF: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE SetEOF*(refNum: INTEGER; logEOF: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetFPos*(refNum: INTEGER; VAR filePos: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE SetFPos*(refNum: INTEGER; posMode: INTEGER; posOff: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetVRefNum*(fileRefNum: INTEGER; VAR vRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBOpenWD*(paramBlock: WDPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBOpenWDSync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7001, $A260, $3E80;
	(*$END*)
PROCEDURE PBOpenWDAsync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7001, $A660, $3E80;
	(*$END*)
PROCEDURE PBCloseWD*(paramBlock: WDPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBCloseWDSync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7002, $A260, $3E80;
	(*$END*)
PROCEDURE PBCloseWDAsync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7002, $A660, $3E80;
	(*$END*)
PROCEDURE PBHSetVol*(paramBlock: WDPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHSetVolSync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A215, $3E80;
	(*$END*)
PROCEDURE PBHSetVolAsync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A615, $3E80;
	(*$END*)
PROCEDURE PBHGetVol*(paramBlock: WDPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHGetVolSync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A214, $3E80;
	(*$END*)
PROCEDURE PBHGetVolAsync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A614, $3E80;
	(*$END*)
PROCEDURE PBCatMove*(paramBlock: CMovePBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBCatMoveSync*(paramBlock: CMovePBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7005, $A260, $3E80;
	(*$END*)
PROCEDURE PBCatMoveAsync*(paramBlock: CMovePBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7005, $A660, $3E80;
	(*$END*)
PROCEDURE PBDirCreate*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDirCreateSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7006, $A260, $3E80;
	(*$END*)
PROCEDURE PBDirCreateAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7006, $A660, $3E80;
	(*$END*)
PROCEDURE PBGetWDInfo*(paramBlock: WDPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetWDInfoSync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7007, $A260, $3E80;
	(*$END*)
PROCEDURE PBGetWDInfoAsync*(paramBlock: WDPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7007, $A660, $3E80;
	(*$END*)
PROCEDURE PBGetFCBInfo*(paramBlock: FCBPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetFCBInfoSync*(paramBlock: FCBPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7008, $A260, $3E80;
	(*$END*)
PROCEDURE PBGetFCBInfoAsync*(paramBlock: FCBPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7008, $A660, $3E80;
	(*$END*)
PROCEDURE PBGetCatInfo*(paramBlock: CInfoPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetCatInfoSync*(paramBlock: CInfoPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7009, $A260, $3E80;
	(*$END*)
PROCEDURE PBGetCatInfoAsync*(paramBlock: CInfoPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7009, $A660, $3E80;
	(*$END*)
PROCEDURE PBSetCatInfo*(paramBlock: CInfoPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetCatInfoSync*(paramBlock: CInfoPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $700A, $A260, $3E80;
	(*$END*)
PROCEDURE PBSetCatInfoAsync*(paramBlock: CInfoPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $700A, $A660, $3E80;
	(*$END*)
PROCEDURE PBAllocContig*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBAllocContigSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A210, $3E80;
	(*$END*)
PROCEDURE PBAllocContigAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A610, $3E80;
	(*$END*)
PROCEDURE PBLockRange*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBLockRangeSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7010, $A260, $3E80;
	(*$END*)
PROCEDURE PBLockRangeAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7010, $A660, $3E80;
	(*$END*)
PROCEDURE PBUnlockRange*(paramBlock: ParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBUnlockRangeSync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7011, $A260, $3E80;
	(*$END*)
PROCEDURE PBUnlockRangeAsync*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7011, $A660, $3E80;
	(*$END*)
PROCEDURE PBSetVInfo*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetVInfoSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $700B, $A260, $3E80;
	(*$END*)
PROCEDURE PBSetVInfoAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $700B, $A660, $3E80;
	(*$END*)
PROCEDURE PBHGetVInfo*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHGetVInfoSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A207, $3E80;
	(*$END*)
PROCEDURE PBHGetVInfoAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A607, $3E80;
	(*$END*)
PROCEDURE PBHOpen*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHOpenSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A200, $3E80;
	(*$END*)
PROCEDURE PBHOpenAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A600, $3E80;
	(*$END*)
PROCEDURE PBHOpenRF*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHOpenRFSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A20A, $3E80;
	(*$END*)
PROCEDURE PBHOpenRFAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A60A, $3E80;
	(*$END*)
PROCEDURE PBHOpenDF*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHOpenDFSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $701A, $A260, $3E80;
	(*$END*)
PROCEDURE PBHOpenDFAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $701A, $A660, $3E80;
	(*$END*)
PROCEDURE PBHCreate*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHCreateSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A208, $3E80;
	(*$END*)
PROCEDURE PBHCreateAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A608, $3E80;
	(*$END*)
PROCEDURE PBHDelete*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHDeleteSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A209, $3E80;
	(*$END*)
PROCEDURE PBHDeleteAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A609, $3E80;
	(*$END*)
PROCEDURE PBHRename*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHRenameSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A20B, $3E80;
	(*$END*)
PROCEDURE PBHRenameAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A60B, $3E80;
	(*$END*)
PROCEDURE PBHRstFLock*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHRstFLockSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A242, $3E80;
	(*$END*)
PROCEDURE PBHRstFLockAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A642, $3E80;
	(*$END*)
PROCEDURE PBHSetFLock*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHSetFLockSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A241, $3E80;
	(*$END*)
PROCEDURE PBHSetFLockAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A641, $3E80;
	(*$END*)
PROCEDURE PBHGetFInfo*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHGetFInfoSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A20C, $3E80;
	(*$END*)
PROCEDURE PBHGetFInfoAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A60C, $3E80;
	(*$END*)
PROCEDURE PBHSetFInfo*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHSetFInfoSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A20D, $3E80;
	(*$END*)
PROCEDURE PBHSetFInfoAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $A60D, $3E80;
	(*$END*)
PROCEDURE PBMakeFSSpec*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBMakeFSSpecSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $701B, $A260, $3E80;
	(*$END*)
PROCEDURE PBMakeFSSpecAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $701B, $A660, $3E80;
	(*$END*)
PROCEDURE FInitQueue*;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $A016;
	(*$END*)
PROCEDURE GetFSQHdr*(): OSUtils.QHdrPtr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2EBC, $0000, $0360;
	(*$END*)
PROCEDURE GetDrvQHdr*(): OSUtils.QHdrPtr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2EBC, $0000, $0308;
	(*$END*)
PROCEDURE GetVCBQHdr*(): OSUtils.QHdrPtr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2EBC, $0000, $0356;
	(*$END*)
PROCEDURE HGetVol*(volName: Types.StringPtr; VAR vRefNum: INTEGER; VAR dirID: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HOpen*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; permission: Types.ByteParameter; VAR refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HOpenDF*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; permission: Types.ByteParameter; VAR refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HOpenRF*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; permission: Types.ByteParameter; VAR refNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE AllocContig*(refNum: INTEGER; VAR count: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HCreate*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; creator: Types.OSType; fileType: Types.OSType): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE DirCreate*(vRefNum: INTEGER; parentDirID: LONGINT; directoryName: Types.ConstStr255Param; VAR createdDirID: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HDelete*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HGetFInfo*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; VAR fndrInfo: FInfo): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HSetFInfo*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; (*CONST*)VAR fndrInfo: FInfo): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HSetFLock*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HRstFLock*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE HRename*(vRefNum: INTEGER; dirID: LONGINT; oldName: Types.ConstStr255Param; newName: Types.ConstStr255Param): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE CatMove*(vRefNum: INTEGER; dirID: LONGINT; oldName: Types.ConstStr255Param; newDirID: LONGINT; newName: Types.ConstStr255Param): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE OpenWD*(vRefNum: INTEGER; dirID: LONGINT; procID: LONGINT; VAR wdRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE CloseWD*(wdRefNum: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE GetWDInfo*(wdRefNum: INTEGER; VAR vRefNum: INTEGER; VAR dirID: LONGINT; VAR procID: LONGINT): Types.OSErr;
	EXTERNAL PASCAL;
(*  shared environment  *)
PROCEDURE PBHGetVolParms*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHGetVolParmsSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7030, $A260, $3E80;
	(*$END*)
PROCEDURE PBHGetVolParmsAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7030, $A660, $3E80;
	(*$END*)
PROCEDURE PBHGetLogInInfo*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHGetLogInInfoSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7031, $A260, $3E80;
	(*$END*)
PROCEDURE PBHGetLogInInfoAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7031, $A660, $3E80;
	(*$END*)
PROCEDURE PBHGetDirAccess*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHGetDirAccessSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7032, $A260, $3E80;
	(*$END*)
PROCEDURE PBHGetDirAccessAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7032, $A660, $3E80;
	(*$END*)
PROCEDURE PBHSetDirAccess*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHSetDirAccessSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7033, $A260, $3E80;
	(*$END*)
PROCEDURE PBHSetDirAccessAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7033, $A660, $3E80;
	(*$END*)
PROCEDURE PBHMapID*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHMapIDSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7034, $A260, $3E80;
	(*$END*)
PROCEDURE PBHMapIDAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7034, $A660, $3E80;
	(*$END*)
PROCEDURE PBHMapName*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHMapNameSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7035, $A260, $3E80;
	(*$END*)
PROCEDURE PBHMapNameAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7035, $A660, $3E80;
	(*$END*)
PROCEDURE PBHCopyFile*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHCopyFileSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7036, $A260, $3E80;
	(*$END*)
PROCEDURE PBHCopyFileAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7036, $A660, $3E80;
	(*$END*)
PROCEDURE PBHMoveRename*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHMoveRenameSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7037, $A260, $3E80;
	(*$END*)
PROCEDURE PBHMoveRenameAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7037, $A660, $3E80;
	(*$END*)
PROCEDURE PBHOpenDeny*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHOpenDenySync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7038, $A260, $3E80;
	(*$END*)
PROCEDURE PBHOpenDenyAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7038, $A660, $3E80;
	(*$END*)
PROCEDURE PBHOpenRFDeny*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBHOpenRFDenySync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7039, $A260, $3E80;
	(*$END*)
PROCEDURE PBHOpenRFDenyAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7039, $A660, $3E80;
	(*$END*)
PROCEDURE PBExchangeFiles*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBExchangeFilesSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7017, $A260, $3E80;
	(*$END*)
PROCEDURE PBExchangeFilesAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7017, $A660, $3E80;
	(*$END*)
PROCEDURE PBCreateFileIDRef*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBCreateFileIDRefSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7014, $A260, $3E80;
	(*$END*)
PROCEDURE PBCreateFileIDRefAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7014, $A660, $3E80;
	(*$END*)
PROCEDURE PBResolveFileIDRef*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBResolveFileIDRefSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7016, $A260, $3E80;
	(*$END*)
PROCEDURE PBResolveFileIDRefAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7016, $A660, $3E80;
	(*$END*)
PROCEDURE PBDeleteFileIDRef*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDeleteFileIDRefSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7015, $A260, $3E80;
	(*$END*)
PROCEDURE PBDeleteFileIDRefAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7015, $A660, $3E80;
	(*$END*)
PROCEDURE PBGetForeignPrivs*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetForeignPrivsSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7060, $A260, $3E80;
	(*$END*)
PROCEDURE PBGetForeignPrivsAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7060, $A660, $3E80;
	(*$END*)
PROCEDURE PBSetForeignPrivs*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetForeignPrivsSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7061, $A260, $3E80;
	(*$END*)
PROCEDURE PBSetForeignPrivsAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7061, $A660, $3E80;
	(*$END*)
(*  Desktop Manager  *)
PROCEDURE PBDTGetPath*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7020, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTCloseDown*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7021, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTAddIcon*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTAddIconSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7022, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTAddIconAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7022, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTGetIcon*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTGetIconSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7023, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTGetIconAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7023, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTGetIconInfo*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTGetIconInfoSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7024, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTGetIconInfoAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7024, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTAddAPPL*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTAddAPPLSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7025, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTAddAPPLAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7025, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTRemoveAPPL*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTRemoveAPPLSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7026, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTRemoveAPPLAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7026, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTGetAPPL*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTGetAPPLSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7027, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTGetAPPLAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7027, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTSetComment*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTSetCommentSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7028, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTSetCommentAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7028, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTRemoveComment*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTRemoveCommentSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7029, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTRemoveCommentAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7029, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTGetComment*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTGetCommentSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702A, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTGetCommentAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702A, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTFlush*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTFlushSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702B, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTFlushAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702B, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTReset*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTResetSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702C, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTResetAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702C, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTGetInfo*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTGetInfoSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702D, $A260, $3E80;
	(*$END*)
PROCEDURE PBDTGetInfoAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702D, $A660, $3E80;
	(*$END*)
PROCEDURE PBDTOpenInform*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702E, $A060, $3E80;
	(*$END*)
PROCEDURE PBDTDelete*(paramBlock: DTPBPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBDTDeleteSync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702F, $A060, $3E80;
	(*$END*)
PROCEDURE PBDTDeleteAsync*(paramBlock: DTPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $702F, $A460, $3E80;
	(*$END*)
(*  VolumeMount traps  *)
PROCEDURE PBGetVolMountInfoSize*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $703F, $A260, $3E80;
	(*$END*)
PROCEDURE PBGetVolMountInfo*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7040, $A260, $3E80;
	(*$END*)
PROCEDURE PBVolumeMount*(paramBlock: ParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7041, $A260, $3E80;
	(*$END*)
(*  FSp traps  *)
PROCEDURE FSMakeFSSpec*(vRefNum: INTEGER; dirID: LONGINT; fileName: Types.ConstStr255Param; VAR spec: FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7001, $AA52;
	(*$END*)
PROCEDURE FSpOpenDF*((*CONST*)VAR spec: FSSpec; permission: Types.ByteParameter; VAR refNum: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7002, $AA52;
	(*$END*)
PROCEDURE FSpOpenRF*((*CONST*)VAR spec: FSSpec; permission: Types.ByteParameter; VAR refNum: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7003, $AA52;
	(*$END*)
PROCEDURE FSpCreate*((*CONST*)VAR spec: FSSpec; creator: Types.OSType; fileType: Types.OSType; scriptTag: Types.ScriptCode): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7004, $AA52;
	(*$END*)
PROCEDURE FSpDirCreate*((*CONST*)VAR spec: FSSpec; scriptTag: Types.ScriptCode; VAR createdDirID: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7005, $AA52;
	(*$END*)
PROCEDURE FSpDelete*((*CONST*)VAR spec: FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7006, $AA52;
	(*$END*)
PROCEDURE FSpGetFInfo*((*CONST*)VAR spec: FSSpec; VAR fndrInfo: FInfo): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7007, $AA52;
	(*$END*)
PROCEDURE FSpSetFInfo*((*CONST*)VAR spec: FSSpec; (*CONST*)VAR fndrInfo: FInfo): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7008, $AA52;
	(*$END*)
PROCEDURE FSpSetFLock*((*CONST*)VAR spec: FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7009, $AA52;
	(*$END*)
PROCEDURE FSpRstFLock*((*CONST*)VAR spec: FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700A, $AA52;
	(*$END*)
PROCEDURE FSpRename*((*CONST*)VAR spec: FSSpec; newName: Types.ConstStr255Param): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700B, $AA52;
	(*$END*)
PROCEDURE FSpCatMove*((*CONST*)VAR source: FSSpec; (*CONST*)VAR dest: FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700C, $AA52;
	(*$END*)
PROCEDURE FSpExchangeFiles*((*CONST*)VAR source: FSSpec; (*CONST*)VAR dest: FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $700F, $AA52;
	(*$END*)
(*
	PBGetAltAccess and PBSetAltAccess are obsolete and will not be supported 
	on PowerPC. Equivalent functionality is provided by the routines 
	PBGetForeignPrivs and PBSetForeignPrivs.
*)
(*$IF OLDROUTINENAMES AND NOT GENERATINGCFM *)
PROCEDURE PBGetAltAccess*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBGetAltAccessSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7060, $A060, $3E80;
	(*$END*)
PROCEDURE PBGetAltAccessAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7060, $A460, $3E80;
	(*$END*)
PROCEDURE PBSetAltAccess*(paramBlock: HParmBlkPtr; async: BOOLEAN): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE PBSetAltAccessSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7061, $A060, $3E80;
	(*$END*)
PROCEDURE PBSetAltAccessAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7061, $A460, $3E80;
	(*$END*)
(*$END*)
PROCEDURE PBShareSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7042, $A260, $3E80;
	(*$END*)
PROCEDURE PBShareAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7042, $A660, $3E80;
	(*$END*)
PROCEDURE PBUnshareSync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7043, $A260, $3E80;
	(*$END*)
PROCEDURE PBUnshareAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7043, $A660, $3E80;
	(*$END*)
PROCEDURE PBGetUGEntrySync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7044, $A260, $3E80;
	(*$END*)
PROCEDURE PBGetUGEntryAsync*(paramBlock: HParmBlkPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $7044, $A660, $3E80;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END Files.
