(*
 	File:		MediaHandlers.mod
 
 	Contains:	QuickTime Interfaces.
 
 	Version:	Technology:	QuickTime 2.0
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE MediaHandlers;

IMPORT SYSTEM, Types, Quickdraw, Components, ImageCompression, Movies;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	handlerHasSpatial*			= ASH(1,0);
	handlerCanClip*				= ASH(1,1);
	handlerCanMatte*				= ASH(1,2);
	handlerCanTransferMode*		= ASH(1,3);
	handlerNeedsBuffer*			= ASH(1,4);
	handlerNoIdle*				= ASH(1,5);
	handlerNoScheduler*			= ASH(1,6);
	handlerWantsTime*			= ASH(1,7);
	handlerCGrafPortOnly*		= ASH(1,8);

(* media task flags *)
	mMustDraw*					= ASH(1,3);
	mAtEnd*						= ASH(1,4);
	mPreflightDraw*				= ASH(1,5);
	mSyncDrawing*				= ASH(1,6);

(* media task result flags *)
	mDidDraw*					= ASH(1,0);
	mNeedsToDraw*				= ASH(1,2);
	mDrawAgain*					= ASH(1,3);
	mPartialDraw*				= ASH(1,4);

	forceUpdateRedraw*			= ASH(1,0);
	forceUpdateNewBuffer*		= ASH(1,1);


TYPE
	GetMovieCompleteParams* = RECORD
		version*:				INTEGER;
		theMovie*:				Movies.Movie;
		theTrack*:				Movies.Track;
		theMedia*:				Movies.Media;
		movieScale*:				Movies.TimeScale;
		mediaScale*:				Movies.TimeScale;
		movieDuration*:			Movies.TimeValue;
		trackDuration*:			Movies.TimeValue;
		mediaDuration*:			Movies.TimeValue;
		effectiveRate*:			Types.Fixed;
		timeBase*:				Movies.TimeBase;
		volume*:					INTEGER;
		width*:					Types.Fixed;
		height*:					Types.Fixed;
		trackMovieMatrix*:		ImageCompression.MatrixRecord;
		moviePort*:				Quickdraw.CGrafPtr;
		movieGD*:				Quickdraw.GDHandle;
		trackMatte*:				Quickdraw.PixMapHandle;
	END;


PROCEDURE MediaInitialize*(mh: Movies.MediaHandler; VAR gmc: GetMovieCompleteParams): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $501, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetHandlerCapabilities*(mh: Movies.MediaHandler; flags: LONGINT; flagsMask: LONGINT): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $502, $7000, $A82A;
	(*$END*)
PROCEDURE MediaIdle*(mh: Movies.MediaHandler; atMediaTime: Movies.TimeValue; flagsIn: LONGINT; VAR flagsOut: LONGINT; (*CONST*)VAR movieTime: Movies.TimeRecord): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $10, $503, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetMediaInfo*(mh: Movies.MediaHandler; h: Types.Handle): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $504, $7000, $A82A;
	(*$END*)
PROCEDURE MediaPutMediaInfo*(mh: Movies.MediaHandler; h: Types.Handle): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $505, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetActive*(mh: Movies.MediaHandler; enableMedia: BOOLEAN): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $2, $506, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetRate*(mh: Movies.MediaHandler; rate: Types.Fixed): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $507, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGGetStatus*(mh: Movies.MediaHandler; VAR statusErr: Components.ComponentResult): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $508, $7000, $A82A;
	(*$END*)
PROCEDURE MediaTrackEdited*(mh: Movies.MediaHandler): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 0, $509, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetMediaTimeScale*(mh: Movies.MediaHandler; newTimeScale: Movies.TimeScale): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $50A, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetMovieTimeScale*(mh: Movies.MediaHandler; newTimeScale: Movies.TimeScale): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $50B, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetGWorld*(mh: Movies.MediaHandler; aPort: Quickdraw.CGrafPtr; aGD: Quickdraw.GDHandle): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $50C, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetDimensions*(mh: Movies.MediaHandler; width: Types.Fixed; height: Types.Fixed): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $50D, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetClip*(mh: Movies.MediaHandler; theClip: Quickdraw.RgnHandle): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $50E, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetMatrix*(mh: Movies.MediaHandler; VAR trackMovieMatrix: ImageCompression.MatrixRecord): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $50F, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetTrackOpaque*(mh: Movies.MediaHandler; VAR trackIsOpaque: BOOLEAN): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $510, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetGraphicsMode*(mh: Movies.MediaHandler; mode: LONGINT; (*CONST*)VAR opColor: Quickdraw.RGBColor): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $511, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetGraphicsMode*(mh: Movies.MediaHandler; VAR mode: LONGINT; VAR opColor: Quickdraw.RGBColor): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $512, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGSetVolume*(mh: Movies.MediaHandler; volume: INTEGER): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $2, $513, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetSoundBalance*(mh: Movies.MediaHandler; balance: INTEGER): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $2, $514, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetSoundBalance*(mh: Movies.MediaHandler; VAR balance: INTEGER): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $515, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetNextBoundsChange*(mh: Movies.MediaHandler; VAR when: Movies.TimeValue): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $516, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetSrcRgn*(mh: Movies.MediaHandler; rgn: Quickdraw.RgnHandle; atMediaTime: Movies.TimeValue): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $517, $7000, $A82A;
	(*$END*)
PROCEDURE MediaPreroll*(mh: Movies.MediaHandler; time: Movies.TimeValue; rate: Types.Fixed): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $518, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSampleDescriptionChanged*(mh: Movies.MediaHandler; index: LONGINT): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $519, $7000, $A82A;
	(*$END*)
PROCEDURE MediaHasCharacteristic*(mh: Movies.MediaHandler; characteristic: Types.OSType; VAR hasIt: BOOLEAN): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8, $51A, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetOffscreenBufferSize*(mh: Movies.MediaHandler; VAR bounds: Types.Rect; depth: INTEGER; ctab: Quickdraw.CTabHandle): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $A, $51B, $7000, $A82A;
	(*$END*)
PROCEDURE MediaSetHints*(mh: Movies.MediaHandler; hints: LONGINT): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $51C, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetName*(mh: Movies.MediaHandler; VAR name: Types.Str255; requestedLanguage: LONGINT; VAR actualLanguage: LONGINT): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $C, $51D, $7000, $A82A;
	(*$END*)
PROCEDURE MediaForceUpdate*(mh: Movies.MediaHandler; forceUpdateFlags: LONGINT): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $51E, $7000, $A82A;
	(*$END*)
PROCEDURE MediaGetDrawingRgn*(mh: Movies.MediaHandler; VAR partialRgn: Quickdraw.RgnHandle): Components.ComponentResult;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $4, $521, $7000, $A82A;
	(*$END*)

CONST
	kMediaInitializeSelect*		= $501;
	kMediaSetHandlerCapabilitiesSelect* = $502;
	kMediaIdleSelect*			= $503;
	kMediaGetMediaInfoSelect*	= $504;
	kMediaPutMediaInfoSelect*	= $505;
	kMediaSetActiveSelect*		= $506;
	kMediaSetRateSelect*			= $507;
	kMediaGGetStatusSelect*		= $508;
	kMediaTrackEditedSelect*		= $509;
	kMediaSetMediaTimeScaleSelect* = $50A;
	kMediaSetMovieTimeScaleSelect* = $50B;
	kMediaSetGWorldSelect*		= $50C;
	kMediaSetDimensionsSelect*	= $50D;
	kMediaSetClipSelect*			= $50E;
	kMediaSetMatrixSelect*		= $50F;
	kMediaGetTrackOpaqueSelect*	= $510;
	kMediaSetGraphicsModeSelect*	= $511;
	kMediaGetGraphicsModeSelect*	= $512;
	kMediaGSetVolumeSelect*		= $513;
	kMediaSetSoundBalanceSelect*	= $514;
	kMediaGetSoundBalanceSelect*	= $515;
	kMediaGetNextBoundsChangeSelect* = $516;
	kMediaGetSrcRgnSelect*		= $517;
	kMediaPrerollSelect*			= $518;
	kMediaSampleDescriptionChangedSelect* = $519;
	kMediaHasCharacteristicSelect* = $51A;
	kMediaGetOffscreenBufferSizeSelect* = $51B;
	kMediaSetHintsSelect*		= $51C;
	kMediaGetNameSelect*			= $51D;
	kMediaForceUpdateSelect*		= $51E;
	kMediaGetDrawingRgnSelect*	= $521;


(* $ALIGN RESET*)
(* $POP*)

 END MediaHandlers.
