(*
 	File:		OCEStandardMail.mod
 
 	Contains:	Apple Open Collaboration Environment Standard Mail Interfaces.
 
 	Version:	Technology:	AOCE Toolbox 1.02
 				Package:	Universal Interfaces 2.11 in MPW Prerelease on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE OCEStandardMail;

IMPORT SYSTEM, Types, Memory, Quickdraw, Events, TextEdit, Dialogs, Files, OCE, OCEAuthDir, OCEMessaging, OCEMail;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	kSMPVersion*					= 1;
	gestaltSMPMailerVersion*		= LONG("malr");
	gestaltSMPSPSendLetterVersion* = LONG("spsl");
	kSMPNativeFormatName*		= LONG("natv");


TYPE
	LetterSpec* = RECORD
		spec*:					ARRAY 3 (*[0..2]*) OF LONGINT;
	END;


CONST
	typeLetterSpec*				= LONG("lttr");

(*	Wildcard used for filtering letter types. *)
	FilterAnyLetter*				= LONG("ltr*");
	FilterAppleLetterContent*	= LONG("ltc*");
	FilterImageContent*			= LONG("lti*");


TYPE
	LetterDescriptor* = RECORD
		onDisk*:					BOOLEAN;
		filler1*:				BOOLEAN;
		(*CASE INTEGER OF
		0: ( *)
	END;
	LetterDescriptorFile* = RECORD(LetterDescriptor)
			fileSpec*:					Files.FSSpec;
		   (* );
		1: *)
	END;
	LetterDescriptorMailbox* = RECORD(LetterDescriptor)
			mailboxSpec*:				LetterSpec;
		   (* );*)
	END;

(*
SMPPSendAs values.  You may add the following values together to determine how the
file is sent, but you may not set both kSMPSendAsEnclosureMask and kSMPSendFileOnlyMask.  This
will allow you to send the letter as an image so that it will work with fax gateways
and send as an enclosure as well.
*)

CONST
	kSMPSendAsEnclosureBit*		= 0;							(* Appears as letter with enclosures *)
	kSMPSendFileOnlyBit*			= 1;							(* Appears as a file in mailbox. *)
	kSMPSendAsImageBit*			= 2;							(* Content imaged in letter *)

(* Values of SMPPSendAs *)
	kSMPSendAsEnclosureMask*		= ASH(1,kSMPSendAsEnclosureBit);
	kSMPSendFileOnlyMask*		= ASH(1,kSMPSendFileOnlyBit);
	kSMPSendAsImageMask*			= ASH(1,kSMPSendAsImageBit);

	
TYPE
	SMPPSendAs* = Types.SignedByte;

	SMPDrawImageProcPtr* = (*Types.ProcPtr;*) PROCEDURE (refcon: LONGINT; inColor: BOOLEAN);
	SMPDrawImageUPP* = Types.UniversalProcPtr;

CONST
	uppSMPDrawImageProcInfo* = $000001C0; (* PROCEDURE (4 byte param, 1 byte param); *)

PROCEDURE NewSMPDrawImageProc*(userRoutine: SMPDrawImageProcPtr): SMPDrawImageUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallSMPDrawImageProc*(refcon: LONGINT; inColor: BOOLEAN; userRoutine: SMPDrawImageUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

TYPE
	SMPRecipientDescriptorPtr* = POINTER TO SMPRecipientDescriptor;

	SMPRecipientDescriptor* = RECORD
		next*:					SMPRecipientDescriptorPtr (* POINTER TO SMPRecipientDescriptor*);				(*  Q-Link. *)
		result*:					Types.OSErr;									(*  result code when using the object. *)
		recipient*:				POINTER TO OCEMessaging.OCEPackedRecipient;					(*  Pointer to a Packed Address. *)
		size*:					LONGINT;								(*  length of recipient in bytes. *)
		theAddress*:				OCEMail.MailRecipient;							(*  structure points into recipient and theRID. *)
		theRID*:					OCE.RecordID;								(*  structure points into recipient. *)
	END;

	SMPEnclosureDescriptorPtr* = POINTER TO SMPEnclosureDescriptor;

	SMPEnclosureDescriptor* = RECORD
		next*:					SMPEnclosureDescriptorPtr (*POINTER TO SMPEnclosureDescriptor*);
		result*:					Types.OSErr;
		fileSpec*:				Files.FSSpec;
		fileCreator*:			Types.OSType;									(*  Creator of this enclosure. *)
		fileType*:				Types.OSType;									(*  File Type of this enclosure. *)
	END;

	SMPLetterPB* = RECORD
		result*:					Types.OSErr;									(* result of operation *)
		subject*:				OCE.RStringPtr;								(* RString *)
		senderIdentity*:			OCEAuthDir.AuthIdentity;							(* Letter is sent from this Identity *)
		toList*:					SMPRecipientDescriptorPtr;				(* Pointer to linked list *)
		ccList*:					SMPRecipientDescriptorPtr;				(* Pointer to linked list *)
		bccList*:				SMPRecipientDescriptorPtr;				(* Pointer to linked list *)
		script*:					Types.ScriptCode;								(* Identifier for language *)
		textSize*:				Memory.Size;									(* length of body data *)
		textBuffer*:				Types.Ptr;									(* body of the letter *)
		sendAs*:					SMPPSendAs;								(* Send as Letter,Enclosure,Image *)
		padByte*:				Types.SInt8; (* Types.Byte *)
		enclosures*:				SMPEnclosureDescriptorPtr;				(* files to be enclosed *)
		drawImageProc*:			SMPDrawImageUPP;						(* For imaging *)
		imageRefCon*:			LONGINT;								(* For imaging *)
		supportsColor*:			BOOLEAN;								(* For imaging - set to true if you application supports color imaging *)
		filler1*:				BOOLEAN;
	END;

	SMPLetterPBPtr* = POINTER TO SMPLetterPB;


CONST
	kSMPAppMustHandleEventBit*	= 0;
	kSMPAppShouldIgnoreEventBit*	= 1;
	kSMPContractedBit*			= 2;
	kSMPExpandedBit*				= 3;
	kSMPMailerBecomesTargetBit*	= 4;
	kSMPAppBecomesTargetBit*		= 5;
	kSMPCursorOverMailerBit*		= 6;
	kSMPCreateCopyWindowBit*		= 7;
	kSMPDisposeCopyWindowBit*	= 8;

(* Values of SMPMailerResult *)
	kSMPAppMustHandleEventMask*	= ASH(1,kSMPAppMustHandleEventBit);
	kSMPAppShouldIgnoreEventMask* = ASH(1,kSMPAppShouldIgnoreEventBit);
	kSMPContractedMask*			= ASH(1,kSMPContractedBit);
	kSMPExpandedMask*			= ASH(1,kSMPExpandedBit);
	kSMPMailerBecomesTargetMask*	= ASH(1,kSMPMailerBecomesTargetBit);
	kSMPAppBecomesTargetMask*	= ASH(1,kSMPAppBecomesTargetBit);
	kSMPCursorOverMailerMask*	= ASH(1,kSMPCursorOverMailerBit);
	kSMPCreateCopyWindowMask*	= ASH(1,kSMPCreateCopyWindowBit);
	kSMPDisposeCopyWindowMask*	= ASH(1,kSMPDisposeCopyWindowBit);

	
TYPE
	SMPMailerResult* = LONGINT;

(* Values of SMPMailerComponent*)

CONST
	kSMPOther*					= -1;
	kSMPFrom*					= 32;
	kSMPTo*						= 20;
	kSMPRegarding*				= 22;
	kSMPSendDateTime*			= 29;
	kSMPAttachments*				= 26;
	kSMPAddressOMatic*			= 16;

	
TYPE
	SMPMailerComponent* = LONGINT;


CONST
	kSMPToAddress*				= OCEMail.kMailToBit;
	kSMPCCAddress*				= OCEMail.kMailCcBit;
	kSMPBCCAddress*				= OCEMail.kMailBccBit;

	
TYPE
	SMPAddressType* = OCEMail.MailAttributeID;


CONST
	kSMPUndoCommand*				= 0;
	kSMPCutCommand*				= 1;
	kSMPCopyCommand*				= 2;
	kSMPPasteCommand*			= 3;
	kSMPClearCommand*			= 4;
	kSMPSelectAllCommand*		= 5;

	
TYPE
	SMPEditCommand* = INTEGER;


CONST
	kSMPUndoDisabled*			= 0;
	kSMPAppMayUndo*				= 1;
	kSMPMailerUndo*				= 2;

	
TYPE
	SMPUndoState* = INTEGER;

(*
SMPSendFormatMask:

Bitfield indicating which combinations of formats are included in,
should be included or, or can be included in a letter.
*)

CONST
	kSMPNativeBit*				= 0;
	kSMPImageBit*				= 1;
	kSMPStandardInterchangeBit*	= 2;

(* Values of SMPSendFormatMask *)
	kSMPNativeMask*				= ASH(1,kSMPNativeBit);
	kSMPImageMask*				= ASH(1,kSMPImageBit);
	kSMPStandardInterchangeMask*	= ASH(1,kSMPStandardInterchangeBit);

	
TYPE
	SMPSendFormatMask* = LONGINT;

(*
	Pseudo-events passed to the clients filter proc for initialization and cleanup.
*)

CONST
	kSMPSendOptionsStart*		= -1;
	kSMPSendOptionsEnd*			= -2;

(*
SMPSendFormatMask:

Structure describing the format of a letter.  If kSMPNativeMask bit is set, the whichNativeFormat field indicates which of the client-defined formats to use.
*)

TYPE
	SMPSendFormat* = RECORD
		whichFormats*:			SMPSendFormatMask;
		whichNativeFormat*:		INTEGER;								(* 0 based *)
	END;

	SMPLetterInfo* = RECORD
		letterCreator*:			Types.OSType;
		letterType*:				Types.OSType;
		subject*:				OCE.RString32;
		sender*:					OCE.RString32;
	END;


CONST
	kSMPSave*					= 0;
	kSMPSaveAs*					= 1;
	kSMPSaveACopy*				= 2;

	
TYPE
	SMPSaveType* = INTEGER;

	FrontWindowProcPtr* = (*Types.ProcPtr;*) PROCEDURE (clientData: LONGINT): Quickdraw.WindowPtr;
	PrepareMailerForDrawingProcPtr* = (*Types.ProcPtr;*) PROCEDURE (window: Quickdraw.WindowPtr; clientData: LONGINT);
	SendOptionsFilterProcPtr* = (*Types.ProcPtr;*) PROCEDURE (theDialog: Dialogs.DialogPtr; VAR theEvent: Events.EventRecord; itemHit: INTEGER; clientData: LONGINT): BOOLEAN;
	FrontWindowUPP* = Types.UniversalProcPtr;
	PrepareMailerForDrawingUPP* = Types.UniversalProcPtr;
	SendOptionsFilterUPP* = Types.UniversalProcPtr;

CONST
	uppFrontWindowProcInfo* = $000000F0; (* PROCEDURE (4 byte param): 4 byte result; *)
	uppPrepareMailerForDrawingProcInfo* = $000003C0; (* PROCEDURE (4 byte param, 4 byte param); *)
	uppSendOptionsFilterProcInfo* = $00003BD0; (* PROCEDURE (4 byte param, 4 byte param, 2 byte param, 4 byte param): 1 byte result; *)

PROCEDURE NewFrontWindowProc*(userRoutine: FrontWindowProcPtr): FrontWindowUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewPrepareMailerForDrawingProc*(userRoutine: PrepareMailerForDrawingProcPtr): PrepareMailerForDrawingUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewSendOptionsFilterProc*(userRoutine: SendOptionsFilterProcPtr): SendOptionsFilterUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallFrontWindowProc*(clientData: LONGINT; userRoutine: FrontWindowUPP): Quickdraw.WindowPtr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallPrepareMailerForDrawingProc*(window: Quickdraw.WindowPtr; clientData: LONGINT; userRoutine: PrepareMailerForDrawingUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallSendOptionsFilterProc*(theDialog: Dialogs.DialogPtr; VAR theEvent: Events.EventRecord; itemHit: INTEGER; clientData: LONGINT; userRoutine: SendOptionsFilterUPP): BOOLEAN;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

CONST
	kSMPGetDimensions*			= 4700;
	kSMPNewMailer*				= 4701;
	kSMPDisposeMailer*			= 4702;
	kSMPMailerEvent*				= 4703;
	kSMPMailerEditCommand*		= 4704;
	kSMPMailerForward*			= 4705;
	kSMPMailerReply*				= 4706;
	kSMPGetMailerState*			= 4707;
	kSMPPrepareCoverPages*		= 4708;
	kSMPDrawNthCoverPage*		= 4709;
	kSMPBeginSave*				= 4710;
	kSMPBeginSend*				= 4711;
	kSMPOpenLetter*				= 4712;
	kSMPDrawMailer*				= 4713;
	kSMPMoveMailer*				= 4714;
	kSMPSetSubject*				= 4715;
	kSMPSetFromIdentity*			= 4716;
	kSMPAddAddress*				= 4717;
	kSMPAddAttachment*			= 4718;
	kSMPContentChanged*			= 4719;
	kSMPEndSave*					= 4720;
	kSMPEndSend*					= 4721;
	kSMPExpandOrContract*		= 4722;
	kSMPBecomeTarget*			= 4723;
	kSMPGetTabInfo*				= 4724;
	kSMPClearUndo*				= 4725;
	kSMPAttachDialog*			= 4726;
	kSMPGetComponentSize*		= 4727;
	kSMPGetComponentInfo*		= 4728;
	kSMPGetListItemInfo*			= 4729;
	kSMPAddContent*				= 4730;
	kSMPReadContent*				= 4731;
	kSMPGetFontNameFromLetter*	= 4732;
	kSMPAddMainEnclosure*		= 4733;
	kSMPGetMainEnclosureFSSpec*	= 4734;
	kSMPAddBlock*				= 4735;
	kSMPReadBlock*				= 4736;
	kSMPEnumerateBlocks*			= 4737;
	kSMPImage*					= 4738;
	kSMPInitMailer*				= 4741;
	kSMPGetNextLetter*			= 4742;
	kSMPPrepareToClose*			= 4743;
	kSMPCloseOptionsDialog*		= 4744;
	kSMPPrepareToChange*			= 4745;
	kSMPGetLetterInfo*			= 4746;
	kSMPTagDialog*				= 4747;
	kSMPSendOptionsDialog*		= 5000;


TYPE
	SMPMailerState* = RECORD
		mailerCount*:			INTEGER;
		currentMailer*:			INTEGER;
		upperLeft*:				Types.Point;
		hasBeenReceived*:		BOOLEAN;
		isTarget*:				BOOLEAN;
		isExpanded*:				BOOLEAN;
		canMoveToTrash*:			BOOLEAN;
		canTag*:					BOOLEAN;
		padByte2*:				Types.SInt8; (* Types.Byte *)
		changeCount*:			LONGINT;
		targetComponent*:		SMPMailerComponent;
		canCut*:					BOOLEAN;
		canCopy*:				BOOLEAN;
		canPaste*:				BOOLEAN;
		canClear*:				BOOLEAN;
		canSelectAll*:			BOOLEAN;
		padByte3*:				Types.SInt8; (* Types.Byte *)
		undoState*:				SMPUndoState;
		undoWhat*:				Types.Str63;
	END;

	SMPSendOptions* = RECORD
		signWhenSent*:			BOOLEAN;
		priority*:				OCEMessaging.IPMPriority;
	END;

	SMPSendOptionsPtr* = POINTER TO SMPSendOptions;
	SMPSendOptionsHandle* = HANDLE TO SMPSendOptions (*POINTER TO SMPSendOptionsPtr*);

	SMPCloseOptions* = RECORD
		moveToTrash*:			BOOLEAN;
		addTag*:					BOOLEAN;
		tag*:					OCE.RString32;
	END;

	SMPCloseOptionsPtr* = POINTER TO SMPCloseOptions;

(*----------------------------------------------------------------------------------------
	Send Package Routines
----------------------------------------------------------------------------------------*)

CONST
	kSMPSendLetter*				= 500;
	kSMPResolveToRecipient*		= 1100;
	kSMPNewPage*					= 2100;
	kSMPImageErr*				= 2101;


PROCEDURE SMPSendLetter*(theLetter: SMPLetterPBPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 500, $AA5D;
	(*$END*)
PROCEDURE SMPNewPage*(VAR newHeader: Quickdraw.OpenCPicParams): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 2100, $AA5D;
	(*$END*)
PROCEDURE SMPImageErr*(): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 0, 2101, $AA5D;
	(*$END*)
PROCEDURE SMPResolveToRecipient*(dsSpec: OCE.PackedDSSpecPtr; VAR recipientList: SMPRecipientDescriptorPtr; identity: OCEAuthDir.AuthIdentity): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 6, 1100, $AA5D;
	(*$END*)
PROCEDURE SMPInitMailer*(mailerVersion: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4741, $AA5D;
	(*$END*)
PROCEDURE SMPGetDimensions*(VAR width: INTEGER; VAR contractedHeight: INTEGER; VAR expandedHeight: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 6, 4700, $AA5D;
	(*$END*)
PROCEDURE SMPGetTabInfo*(VAR firstTab: SMPMailerComponent; VAR lastTab: SMPMailerComponent): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4724, $AA5D;
	(*$END*)
PROCEDURE SMPNewMailer*(window: Quickdraw.WindowPtr; upperLeft: Types.Point; canContract: BOOLEAN; initiallyExpanded: BOOLEAN; identity: OCEAuthDir.AuthIdentity; prepareMailerForDrawingCB: PrepareMailerForDrawingUPP; clientData: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 12, 4701, $AA5D;
	(*$END*)
PROCEDURE SMPPrepareToClose*(window: Quickdraw.WindowPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4743, $AA5D;
	(*$END*)
PROCEDURE SMPCloseOptionsDialog*(window: Quickdraw.WindowPtr; closeOptions: SMPCloseOptionsPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4744, $AA5D;
	(*$END*)
PROCEDURE SMPTagDialog*(window: Quickdraw.WindowPtr; VAR theTag: OCE.RString32): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4747, $AA5D;
	(*$END*)
PROCEDURE SMPDisposeMailer*(window: Quickdraw.WindowPtr; closeOptions: SMPCloseOptionsPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4702, $AA5D;
	(*$END*)
PROCEDURE SMPMailerEvent*((*CONST*)VAR event: Events.EventRecord; VAR whatHappened: SMPMailerResult; frontWindowCB: FrontWindowUPP; clientData: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 8, 4703, $AA5D;
	(*$END*)
PROCEDURE SMPClearUndo*(window: Quickdraw.WindowPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4725, $AA5D;
	(*$END*)
PROCEDURE SMPMailerEditCommand*(window: Quickdraw.WindowPtr; command: SMPEditCommand; VAR whatHappened: SMPMailerResult): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 5, 4704, $AA5D;
	(*$END*)
PROCEDURE SMPMailerForward*(window: Quickdraw.WindowPtr; from: OCEAuthDir.AuthIdentity): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4705, $AA5D;
	(*$END*)
PROCEDURE SMPMailerReply*(originalLetter: Quickdraw.WindowPtr; newLetter: Quickdraw.WindowPtr; replyToAll: BOOLEAN; upperLeft: Types.Point; canContract: BOOLEAN; initiallyExpanded: BOOLEAN; identity: OCEAuthDir.AuthIdentity; prepareMailerForDrawingCB: PrepareMailerForDrawingUPP; clientData: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 15, 4706, $AA5D;
	(*$END*)
PROCEDURE SMPGetMailerState*(window: Quickdraw.WindowPtr; VAR itsState: SMPMailerState): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4707, $AA5D;
	(*$END*)
PROCEDURE SMPSendOptionsDialog*(window: Quickdraw.WindowPtr; VAR documentName: Types.Str255; VAR nativeFormatNames: Types.StringPtr; nameCount: INTEGER; canSend: SMPSendFormatMask; VAR currentFormat: SMPSendFormat; filterProc: SendOptionsFilterUPP; clientData: LONGINT; VAR shouldSend: SMPSendFormat; sendOptions: SMPSendOptionsPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 19, 5000, $AA5D;
	(*$END*)
PROCEDURE SMPPrepareCoverPages*(window: Quickdraw.WindowPtr; VAR pageCount: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4708, $AA5D;
	(*$END*)
PROCEDURE SMPDrawNthCoverPage*(window: Quickdraw.WindowPtr; pageNumber: INTEGER; doneDrawingCoverPages: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4709, $AA5D;
	(*$END*)
PROCEDURE SMPPrepareToChange*(window: Quickdraw.WindowPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4745, $AA5D;
	(*$END*)
PROCEDURE SMPContentChanged*(window: Quickdraw.WindowPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4719, $AA5D;
	(*$END*)
PROCEDURE SMPBeginSave*(window: Quickdraw.WindowPtr; (*CONST*)VAR diskLetter: Files.FSSpec; creator: Types.OSType; fileType: Types.OSType; saveType: SMPSaveType; VAR mustAddContent: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 11, 4710, $AA5D;
	(*$END*)
PROCEDURE SMPEndSave*(window: Quickdraw.WindowPtr; okToSave: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 3, 4720, $AA5D;
	(*$END*)
PROCEDURE SMPBeginSend*(window: Quickdraw.WindowPtr; creator: Types.OSType; fileType: Types.OSType; sendOptions: SMPSendOptionsPtr; VAR mustAddContent: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 10, 4711, $AA5D;
	(*$END*)
PROCEDURE SMPEndSend*(window: Quickdraw.WindowPtr; okToSend: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 3, 4721, $AA5D;
	(*$END*)
PROCEDURE SMPOpenLetter*((*CONST*)VAR letter: LetterDescriptor; window: Quickdraw.WindowPtr; upperLeft: Types.Point; canContract: BOOLEAN; initiallyExpanded: BOOLEAN; prepareMailerForDrawingCB: PrepareMailerForDrawingUPP; clientData: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 12, 4712, $AA5D;
	(*$END*)
PROCEDURE SMPAddMainEnclosure*(window: Quickdraw.WindowPtr; (*CONST*)VAR enclosure: Files.FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4733, $AA5D;
	(*$END*)
PROCEDURE SMPGetMainEnclosureFSSpec*(window: Quickdraw.WindowPtr; VAR enclosureDir: Files.FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4734, $AA5D;
	(*$END*)
PROCEDURE SMPAddContent*(window: Quickdraw.WindowPtr; segmentType: OCEMail.MailSegmentType; appendFlag: BOOLEAN; buffer: (*UNIV*) Types.Ptr; bufferSize: LONGINT; VAR textScrap: TextEdit.StScrpRec; startNewScript: BOOLEAN; script: Types.ScriptCode): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 12, 4730, $AA5D;
	(*$END*)
PROCEDURE SMPReadContent*(window: Quickdraw.WindowPtr; segmentTypeMask: OCEMail.MailSegmentMask; buffer: (*UNIV*) Types.Ptr; bufferSize: LONGINT; VAR dataSize: LONGINT; VAR textScrap: TextEdit.StScrpRec; VAR script: Types.ScriptCode; VAR segmentType: OCEMail.MailSegmentType; VAR endOfScript: BOOLEAN; VAR endOfSegment: BOOLEAN; VAR endOfContent: BOOLEAN; VAR segmentLength: LONGINT; VAR segmentID: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 25, 4731, $AA5D;
	(*$END*)
PROCEDURE SMPGetFontNameFromLetter*(window: Quickdraw.WindowPtr; fontNum: INTEGER; VAR fontName: Types.Str255; doneWithFontTable: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 6, 4732, $AA5D;
	(*$END*)
PROCEDURE SMPAddBlock*(window: Quickdraw.WindowPtr; (*CONST*)VAR blockType: OCEMessaging.OCECreatorType; append: BOOLEAN; buffer: (*UNIV*) Types.Ptr; bufferSize: LONGINT; mode: OCEMail.MailBlockMode; offset: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 12, 4735, $AA5D;
	(*$END*)
PROCEDURE SMPReadBlock*(window: Quickdraw.WindowPtr; (*CONST*)VAR blockType: OCEMessaging.OCECreatorType; blockIndex: INTEGER; buffer: (*UNIV*) Types.Ptr; bufferSize: LONGINT; dataOffset: LONGINT; VAR dataSize: LONGINT; VAR endOfBlock: BOOLEAN; VAR remaining: LONGINT): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 17, 4736, $AA5D;
	(*$END*)
PROCEDURE SMPEnumerateBlocks*(window: Quickdraw.WindowPtr; startIndex: INTEGER; buffer: (*UNIV*) Types.Ptr; bufferSize: LONGINT; VAR dataSize: LONGINT; VAR nextIndex: INTEGER; VAR more: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 13, 4737, $AA5D;
	(*$END*)
PROCEDURE SMPDrawMailer*(window: Quickdraw.WindowPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4713, $AA5D;
	(*$END*)
PROCEDURE SMPSetSubject*(window: Quickdraw.WindowPtr; (*CONST*)VAR text: OCE.RString): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4715, $AA5D;
	(*$END*)
PROCEDURE SMPSetFromIdentity*(window: Quickdraw.WindowPtr; from: OCEAuthDir.AuthIdentity): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4716, $AA5D;
	(*$END*)
PROCEDURE SMPAddAddress*(window: Quickdraw.WindowPtr; addrType: SMPAddressType; VAR address: OCEMessaging.OCEPackedRecipient): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 5, 4717, $AA5D;
	(*$END*)
PROCEDURE SMPAddAttachment*(window: Quickdraw.WindowPtr; (*CONST*)VAR attachment: Files.FSSpec): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4718, $AA5D;
	(*$END*)
PROCEDURE SMPAttachDialog*(window: Quickdraw.WindowPtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 2, 4726, $AA5D;
	(*$END*)
PROCEDURE SMPExpandOrContract*(window: Quickdraw.WindowPtr; expand: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 3, 4722, $AA5D;
	(*$END*)
PROCEDURE SMPMoveMailer*(window: Quickdraw.WindowPtr; dh: INTEGER; dv: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4714, $AA5D;
	(*$END*)
PROCEDURE SMPBecomeTarget*(window: Quickdraw.WindowPtr; becomeTarget: BOOLEAN; whichField: SMPMailerComponent): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 5, 4723, $AA5D;
	(*$END*)
PROCEDURE SMPGetComponentSize*(window: Quickdraw.WindowPtr; whichMailer: INTEGER; whichField: SMPMailerComponent; VAR size: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 7, 4727, $AA5D;
	(*$END*)
PROCEDURE SMPGetComponentInfo*(window: Quickdraw.WindowPtr; whichMailer: INTEGER; whichField: SMPMailerComponent; buffer: (*UNIV*) Types.Ptr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 7, 4728, $AA5D;
	(*$END*)
PROCEDURE SMPGetListItemInfo*(window: Quickdraw.WindowPtr; whichMailer: INTEGER; whichField: SMPMailerComponent; buffer: (*UNIV*) Types.Ptr; bufferLength: LONGINT; startItem: INTEGER; VAR itemCount: INTEGER; VAR nextItem: INTEGER; VAR more: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 16, 4729, $AA5D;
	(*$END*)
PROCEDURE SMPImage*(window: Quickdraw.WindowPtr; drawImageProc: SMPDrawImageUPP; imageRefCon: LONGINT; supportsColor: BOOLEAN): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 7, 4738, $AA5D;
	(*$END*)
PROCEDURE SMPGetNextLetter*(VAR typesList: Types.OSType; numTypes: INTEGER; VAR adjacentLetter: LetterDescriptor): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 5, 4742, $AA5D;
	(*$END*)
PROCEDURE SMPGetLetterInfo*(VAR mailboxSpec: LetterSpec; VAR info: SMPLetterInfo): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $203C, 4, 4746, $AA5D;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END OCEStandardMail.
