(*
 	File:		OSAGeneric.mod
 
 	Contains:	AppleScript Generic Components.Component Interfaces.
 
 	Version:	Technology:	AppleScript 1.1
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE OSAGeneric;

IMPORT SYSTEM, Types, AppleEvents, Components, OSA;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)
(* 	NOTE*:	This interface defines a "generic scripting component."
			The Generic Scripting Component allows automatic dispatch to a
			specific scripting component that conforms to the OSA interface.
			This component supports OSA, by calling AppleScript or some other 
			scripting component.  Additionally it provides access to the default
			and the user-prefered scripting component.
*)

CONST
(* Component version this header file describes *)
	kGenericComponentVersion*	= $0100;

	kGSSSelectGetDefaultScriptingComponent* = $1001;
	kGSSSelectSetDefaultScriptingComponent* = $1002;
	kGSSSelectGetScriptingComponent* = $1003;
	kGSSSelectGetScriptingComponentFromStored* = $1004;
	kGSSSelectGenericToRealID*	= $1005;
	kGSSSelectRealToGenericID*	= $1006;
	kGSSSelectOutOfRange*		= $1007;

	
TYPE
	ScriptingComponentSelector* = Types.OSType;

	GenericID* = OSA.OSAID;

(* get and set the default scripting component *)

PROCEDURE OSAGetDefaultScriptingComponent*(genericScriptingComponent: Components.ComponentInstance; VAR scriptingSubType: ScriptingComponentSelector): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 4, $1001, $7000, $A82A;
	(*$END*)
PROCEDURE OSASetDefaultScriptingComponent*(genericScriptingComponent: Components.ComponentInstance; scriptingSubType: ScriptingComponentSelector): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 4, $1002, $7000, $A82A;
	(*$END*)
(* get a scripting component instance from its subtype code *)
PROCEDURE OSAGetScriptingComponent*(genericScriptingComponent: Components.ComponentInstance; scriptingSubType: ScriptingComponentSelector; VAR scriptingInstance: Components.ComponentInstance): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 8, $1003, $7000, $A82A;
	(*$END*)
(* get a scripting component selector (subType) from a stored script *)
PROCEDURE OSAGetScriptingComponentFromStored*(genericScriptingComponent: Components.ComponentInstance; (*CONST*)VAR scriptData: AppleEvents.AEDesc; VAR scriptingSubType: ScriptingComponentSelector): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 8, $1004, $7000, $A82A;
	(*$END*)
(* get a real component instance and script id from a generic id *)
PROCEDURE OSAGenericToRealID*(genericScriptingComponent: Components.ComponentInstance; VAR theScriptID: OSA.OSAID; VAR theExactComponent: Components.ComponentInstance): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 8, $1005, $7000, $A82A;
	(*$END*)
(* get a generic id from a real component instance and script id *)
PROCEDURE OSARealToGenericID*(genericScriptingComponent: Components.ComponentInstance; VAR theScriptID: OSA.OSAID; theExactComponent: Components.ComponentInstance): OSA.OSAError;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, 8, $1006, $7000, $A82A;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END OSAGeneric.
