(*
 	File:		Palettes.mod
 
 	Contains:	Palette Manager Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE Palettes;

IMPORT SYSTEM, Types, Quickdraw;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	pmCourteous*					= 0;							(*Record use of color on each device touched.*)
	pmTolerant*					= $0002;						(*render ciRGB if ciTolerance is exceeded by best match.*)
	pmAnimated*					= $0004;						(*reserve an index on each device touched and render ciRGB.*)
	pmExplicit*					= $0008;						(*no reserve, no render, no record; stuff index into port.*)
	pmWhite*						= $0010;
	pmBlack*						= $0020;
	pmInhibitG2*					= $0100;
	pmInhibitC2*					= $0200;
	pmInhibitG4*					= $0400;
	pmInhibitC4*					= $0800;
	pmInhibitG8*					= $1000;
	pmInhibitC8*					= $2000;
(* NSetPalette Update Constants *)
	pmNoUpdates*					= $8000;						(*no updates*)
	pmBkUpdates*					= $A000;						(*background updates only*)
	pmFgUpdates*					= $C000;						(*foreground updates only*)
	pmAllUpdates*				= $E000;						(*all updates*)


TYPE
	ColorInfo* = RECORD
		ciRGB*:					Quickdraw.RGBColor;								(*true RGB values*)
		ciUsage*:				INTEGER;								(*color usage*)
		ciTolerance*:			INTEGER;								(*tolerance value*)
		ciDataFields*:			ARRAY 3 (*[0..2]*) OF INTEGER;				(*private fields*)
	END;

	Palette* = RECORD
		pmEntries*:				INTEGER;								(*entries in pmTable*)
		pmDataFields*:			ARRAY 7 (*[0..6]*) OF INTEGER;				(*private fields*)
		pmInfo*:					ARRAY 1 (*[0..0]*) OF ColorInfo;
	END;

	PalettePtr* = POINTER TO Palette;
	PaletteHandle* = HANDLE TO Palette (* POINTER TO PalettePtr*);


PROCEDURE InitPalettes*;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA90;
	(*$END*)
PROCEDURE NewPalette*(entries: INTEGER; srcColors: Quickdraw.CTabHandle; srcUsage: INTEGER; srcTolerance: INTEGER): PaletteHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA91;
	(*$END*)
PROCEDURE GetNewPalette*(PaletteID: INTEGER): PaletteHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA92;
	(*$END*)
PROCEDURE DisposePalette*(srcPalette: PaletteHandle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA93;
	(*$END*)
PROCEDURE ActivatePalette*(srcWindow: Quickdraw.WindowPtr);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA94;
	(*$END*)
PROCEDURE SetPalette*(dstWindow: Quickdraw.WindowPtr; srcPalette: PaletteHandle; cUpdates: BOOLEAN);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA95;
	(*$END*)
PROCEDURE NSetPalette*(dstWindow: Quickdraw.WindowPtr; srcPalette: PaletteHandle; nCUpdates: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA95;
	(*$END*)
PROCEDURE GetPalette*(srcWindow: Quickdraw.WindowPtr): PaletteHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA96;
	(*$END*)
PROCEDURE CopyPalette*(srcPalette: PaletteHandle; dstPalette: PaletteHandle; srcEntry: INTEGER; dstEntry: INTEGER; dstLength: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AAA1;
	(*$END*)
PROCEDURE PmForeColor*(dstEntry: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA97;
	(*$END*)
PROCEDURE PmBackColor*(dstEntry: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA98;
	(*$END*)
PROCEDURE AnimateEntry*(dstWindow: Quickdraw.WindowPtr; dstEntry: INTEGER; (*CONST*)VAR srcRGB: Quickdraw.RGBColor);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA99;
	(*$END*)
PROCEDURE AnimatePalette*(dstWindow: Quickdraw.WindowPtr; srcCTab: Quickdraw.CTabHandle; srcIndex: INTEGER; dstEntry: INTEGER; dstLength: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA9A;
	(*$END*)
PROCEDURE GetEntryColor*(srcPalette: PaletteHandle; srcEntry: INTEGER; VAR dstRGB: Quickdraw.RGBColor);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA9B;
	(*$END*)
PROCEDURE SetEntryColor*(dstPalette: PaletteHandle; dstEntry: INTEGER; (*CONST*)VAR srcRGB: Quickdraw.RGBColor);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA9C;
	(*$END*)
PROCEDURE GetEntryUsage*(srcPalette: PaletteHandle; srcEntry: INTEGER; VAR dstUsage: INTEGER; VAR dstTolerance: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA9D;
	(*$END*)
PROCEDURE SetEntryUsage*(dstPalette: PaletteHandle; dstEntry: INTEGER; srcUsage: INTEGER; srcTolerance: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA9E;
	(*$END*)
PROCEDURE CTab2Palette*(srcCTab: Quickdraw.CTabHandle; dstPalette: PaletteHandle; srcUsage: INTEGER; srcTolerance: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AA9F;
	(*$END*)
PROCEDURE Palette2CTab*(srcPalette: PaletteHandle; dstCTab: Quickdraw.CTabHandle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $AAA0;
	(*$END*)
PROCEDURE Entry2Index*(entry: INTEGER): LONGINT;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7000, $AAA2;
	(*$END*)
PROCEDURE RestoreDeviceClut*(gd: Quickdraw.GDHandle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7002, $AAA2;
	(*$END*)
PROCEDURE ResizePalette*(p: PaletteHandle; size: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7003, $AAA2;
	(*$END*)
PROCEDURE SaveFore*(VAR c: Quickdraw.ColorSpec);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $040D, $AAA2;
	(*$END*)
PROCEDURE SaveBack*(VAR c: Quickdraw.ColorSpec);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $040E, $AAA2;
	(*$END*)
PROCEDURE RestoreFore*((*CONST*)VAR c: Quickdraw.ColorSpec);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $040F, $AAA2;
	(*$END*)
PROCEDURE RestoreBack*((*CONST*)VAR c: Quickdraw.ColorSpec);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0410, $AAA2;
	(*$END*)
PROCEDURE SetDepth*(gd: Quickdraw.GDHandle; depth: INTEGER; whichFlags: INTEGER; flags: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A13, $AAA2;
	(*$END*)
PROCEDURE HasDepth*(gd: Quickdraw.GDHandle; depth: INTEGER; whichFlags: INTEGER; flags: INTEGER): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0A14, $AAA2;
	(*$END*)
PROCEDURE PMgrVersion*(): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $7015, $AAA2;
	(*$END*)
PROCEDURE SetPaletteUpdates*(p: PaletteHandle; updates: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0616, $AAA2;
	(*$END*)
PROCEDURE GetPaletteUpdates*(p: PaletteHandle): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0417, $AAA2;
	(*$END*)
PROCEDURE GetGray*(device: Quickdraw.GDHandle; (*CONST*)VAR backGround: Quickdraw.RGBColor; VAR foreGround: Quickdraw.RGBColor): BOOLEAN;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0C19, $AAA2;
	(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END Palettes.
