(*
 	File:		PictUtils.mod
 
 	Contains:	Quickdraw.Picture Utilities Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$IF UNDEFINED OLDROUTINENAMES*)
(*$SET OLDROUTINENAMES FALSE*)
(*$END*)
(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE PictUtils;

IMPORT SYSTEM, Types, Quickdraw, Palettes;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
	returnColorTable*			= $0001;
	returnPalette*				= $0002;
	recordComments*				= $0004;
	recordFontInfo*				= $0008;
	suppressBlackAndWhite*		= $0010;

(* color pick methods *)
	systemMethod*				= 0;							(* system color pick method *)
	popularMethod*				= 1;							(* method that chooses the most popular set of colors *)
	medianMethod*				= 2;							(* method that chooses a good average mix of colors *)
(* color bank types *)
	ColorBankIsCustom*			= -1;
	ColorBankIsExactAnd555*		= 0;
	ColorBankIs555*				= 1;

	
TYPE
	PictInfoID* = LONGINT;

	CommentSpec* = RECORD
		count*:					INTEGER;								(* number of occurrances of this comment AIFF.ID *)
		ID*:						INTEGER;								(* AIFF.ID for the comment in the picture *)
	END;

	CommentSpecPtr* = POINTER TO CommentSpec;
	CommentSpecHandle* = HANDLE TO CommentSpec (* POINTER TO CommentSpecPtr*);

	FontSpec* = RECORD
		pictFontID*:				INTEGER;								(* AIFF.ID of the font in the picture *)
		sysFontID*:				INTEGER;								(* AIFF.ID of the same font in the current system file *)
		size*:					ARRAY 4 (*[0..3]*) OF LONGINT;				(* bit array of all the sizes found (1..127) (bit 0 means > 127) *)
		style*:					INTEGER;								(* combined style of all occurrances of the font *)
		nameOffset*:				LONGINT;								(* offset into the fontNamesHdl handle for the fonts name *)
	END;

	FontSpecPtr* = POINTER TO FontSpec;
	FontSpecHandle* = HANDLE TO FontSpec(* POINTER TO FontSpecPtr*);

	PictInfo* = RECORD
		version*:				INTEGER;								(* this is always zero, for now *)
		uniqueColors*:			LONGINT;								(* the number of actual colors in the picture(s)/pixmap(s) *)
		thePalette*:				Palettes.PaletteHandle;							(* handle to the palette information *)
		theColorTable*:			Quickdraw.CTabHandle;								(* handle to the color table *)
		hRes*:					Types.Fixed;									(* maximum horizontal resolution for all the pixmaps *)
		vRes*:					Types.Fixed;									(* maximum vertical resolution for all the pixmaps *)
		depth*:					INTEGER;								(* maximum depth for all the pixmaps (in the picture) *)
		sourceRect*:				Types.Rect;									(* the picture frame rectangle (this contains the entire picture) *)
		textCount*:				LONGINT;								(* total number of text strings in the picture *)
		lineCount*:				LONGINT;								(* total number of lines in the picture *)
		rectCount*:				LONGINT;								(* total number of rectangles in the picture *)
		rRectCount*:				LONGINT;								(* total number of round rectangles in the picture *)
		ovalCount*:				LONGINT;								(* total number of ovals in the picture *)
		arcCount*:				LONGINT;								(* total number of arcs in the picture *)
		polyCount*:				LONGINT;								(* total number of polygons in the picture *)
		regionCount*:			LONGINT;								(* total number of regions in the picture *)
		bitMapCount*:			LONGINT;								(* total number of bitmaps in the picture *)
		pixMapCount*:			LONGINT;								(* total number of pixmaps in the picture *)
		commentCount*:			LONGINT;								(* total number of comments in the picture *)
		uniqueComments*:			LONGINT;								(* the number of unique comments in the picture *)
		commentHandle*:			CommentSpecHandle;						(* handle to all the comment information *)
		uniqueFonts*:			LONGINT;								(* the number of unique fonts in the picture *)
		fontHandle*:				FontSpecHandle;							(* handle to the FontSpec information *)
		fontNamesHandle*:		Types.Handle;									(* handle to the font names *)
		reserved1*:				LONGINT;
		reserved2*:				LONGINT;
	END;

	PictInfoPtr* = POINTER TO PictInfo;
	PictInfoHandle* = HANDLE TO PictInfo (*k POINTER TO PictInfoPtr*);


PROCEDURE GetPictInfo*(thePictHandle: Quickdraw.PicHandle; VAR thePictInfo: PictInfo; verb: INTEGER; colorsRequested: INTEGER; colorPickMethod: INTEGER; version: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0800, $A831;
	(*$END*)
PROCEDURE GetPixMapInfo*(thePixMapHandle: Quickdraw.PixMapHandle; VAR thePictInfo: PictInfo; verb: INTEGER; colorsRequested: INTEGER; colorPickMethod: INTEGER; version: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0801, $A831;
	(*$END*)
PROCEDURE NewPictInfo*(VAR thePictInfoID: PictInfoID; verb: INTEGER; colorsRequested: INTEGER; colorPickMethod: INTEGER; version: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0602, $A831;
	(*$END*)
PROCEDURE RecordPictInfo*(thePictInfoID: PictInfoID; thePictHandle: Quickdraw.PicHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0403, $A831;
	(*$END*)
PROCEDURE RecordPixMapInfo*(thePictInfoID: PictInfoID; thePixMapHandle: Quickdraw.PixMapHandle): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0404, $A831;
	(*$END*)
PROCEDURE RetrievePictInfo*(thePictInfoID: PictInfoID; VAR thePictInfo: PictInfo; colorsRequested: INTEGER): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0505, $A831;
	(*$END*)
PROCEDURE DisposePictInfo*(thePictInfoID: PictInfoID): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0206, $A831;
	(*$END*)
(*$IF OLDROUTINENAMES *)
PROCEDURE DisposPictInfo*(thePictInfoID: PictInfoID): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $303C, $0206, $A831;
	(*$END*)
(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END PictUtils.
