(*
 	File:		Terminals.mod
 
 	Contains:	Communications Toolbox Terminal tool Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE Terminals;

IMPORT SYSTEM, Types, Quickdraw, Events, Dialogs, Connections;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)

CONST
(* current Terminal Manager version 	*)
	curTMVersion*				= 2;
(* current Terminal Manager Environment Record version 	*)
	curTermEnvRecVers*			= 0;
(* error codes    *)
	tmGenericError*				= -1;
	tmNoErr*						= 0;
	tmNotSent*					= 1;
	tmEnvironsChanged*			= 2;
	tmNotSupported*				= 7;
	tmNoTools*					= 8;

	
TYPE
	TMErr* = Types.OSErr;


CONST
	tmInvisible*					= ASH(1,0);
	tmSaveBeforeClear*			= ASH(1,1);
	tmNoMenus*					= ASH(1,2);
	tmAutoScroll*				= ASH(1,3);
	tmConfigChanged*				= ASH(1,4);

	
TYPE
	TMFlags* = LONGINT;


CONST
	selTextNormal*				= ASH(1,0);
	selTextBoxed*				= ASH(1,1);
	selGraphicsMarquee*			= ASH(1,2);
	selGraphicsLasso*			= ASH(1,3);
	tmSearchNoDiacrit*			= ASH(1,8);
	tmSearchNoCase*				= ASH(1,9);

	
TYPE
	TMSearchTypes* = INTEGER;

	TMSelTypes* = INTEGER;


CONST
	cursorText*					= 1;
	cursorGraphics*				= 2;

	
TYPE
	TMCursorTypes* = INTEGER;


CONST
	tmTextTerminal*				= ASH(1,0);
	tmGraphicsTerminal*			= ASH(1,1);

	
TYPE
	TMTermTypes* = INTEGER;

	TermDataBlock* = RECORD
		flags*:					TMTermTypes;
		theData*:				Types.Handle;
		auxData*:				Types.Handle;
		reserved*:				LONGINT;
	END;

	TermDataBlockPtr* = POINTER TO TermDataBlock;
	TermDataBlockH* = HANDLE TO TermDataBlock (* POINTER TO TermDataBlockPtr*);
	TermDataBlockHandle* = HANDLE TO TermDataBlock (* POINTER TO TermDataBlockPtr*);

	TermEnvironRec* = RECORD
		version*:				INTEGER;
		termType*:				TMTermTypes;
		textRows*:				INTEGER;
		textCols*:				INTEGER;
		cellSize*:				Types.Point;
		graphicSize*:			Types.Rect;
		slop*:					Types.Point;
		auxSpace*:				Types.Rect;
	END;

	TermEnvironPtr* = POINTER TO TermEnvironRec;

	TMSelection* = RECORD
		(* CASE INTEGER OF
		0: ( *)
	END;
	TMSelectionRect* = RECORD(TMSelection)
			selRect*:					Types.Rect;
		   (* );
		1: ( *)
	END;
	TMSelectionRgn* = RECORD(TMSelection)
			selRgnHandle*:				Quickdraw.RgnHandle;
		   (* );*)
	END;

	TermPtr* = POINTER TO TermRecord;
	TermHandle* = HANDLE TO TermRecord (* POINTER TO TermPtr*);

	TerminalSendProcPtr* = (*Types.ProcPtr;*) PROCEDURE (thePtr: Types.Ptr; theSize: LONGINT; refCon: LONGINT; flags: Connections.CMFlags): LONGINT;
	TerminalBreakProcPtr* = (*Types.ProcPtr;*) PROCEDURE (duration: LONGINT; refCon: LONGINT);
	TerminalCacheProcPtr* = (*Types.ProcPtr;*) PROCEDURE (refCon: LONGINT; theTermData: TermDataBlockPtr): LONGINT;
	TerminalSearchCallBackProcPtr* = (*Types.ProcPtr;*) PROCEDURE (hTerm: TermHandle; refNum: INTEGER; VAR foundRect: Types.Rect);
	TerminalClikLoopProcPtr* = (*Types.ProcPtr;*) PROCEDURE (refCon: LONGINT): BOOLEAN;
	TerminalEnvironsProcPtr* = (*Types.ProcPtr;*) PROCEDURE (refCon: LONGINT; VAR theEnvirons: TermEnvironRec): Connections.CMErr;
	TerminalChooseIdleProcPtr* = (*Types.ProcPtr;*) PROCEDURE;
	TerminalToolDefProcPtr* = (*Types.ProcPtr;*) PROCEDURE (hTerm: TermHandle; msg: INTEGER; p1: LONGINT; p2: LONGINT; p3: LONGINT): LONGINT;
	TerminalSendUPP* = Types.UniversalProcPtr;
	TerminalBreakUPP* = Types.UniversalProcPtr;
	TerminalCacheUPP* = Types.UniversalProcPtr;
	TerminalSearchCallBackUPP* = Types.UniversalProcPtr;
	TerminalClikLoopUPP* = Types.UniversalProcPtr;
	TerminalEnvironsUPP* = Types.UniversalProcPtr;
	TerminalChooseIdleUPP* = Types.UniversalProcPtr;
	TerminalToolDefUPP* = Types.UniversalProcPtr;

	TermRecord* = RECORD
		procID*:					INTEGER;
		flags*:					TMFlags;
		errCode*:				TMErr;
		refCon*:					LONGINT;
		userData*:				LONGINT;
		defProc*:				TerminalToolDefUPP;
		config*:					Types.Ptr;
		oldConfig*:				Types.Ptr;
		environsProc*:			TerminalEnvironsUPP;
		reserved1*:				LONGINT;
		reserved2*:				LONGINT;
		tmPrivate*:				Types.Ptr;
		sendProc*:				TerminalSendUPP;
		breakProc*:				TerminalBreakUPP;
		cacheProc*:				TerminalCacheUPP;
		clikLoop*:				TerminalClikLoopUPP;
		owner*:					Quickdraw.WindowPtr;
		termRect*:				Types.Rect;
		viewRect*:				Types.Rect;
		visRect*:				Types.Rect;
		lastIdle*:				LONGINT;
		selection*:				TMSelection;
		selType*:				TMSelTypes;
		mluField*:				LONGINT;
	END;

CONST
	uppTerminalSendProcInfo* = $00002FF0; (* PROCEDURE (4 byte param, 4 byte param, 4 byte param, 2 byte param): 4 byte result; *)
	uppTerminalBreakProcInfo* = $000003C0; (* PROCEDURE (4 byte param, 4 byte param); *)
	uppTerminalCacheProcInfo* = $000003F0; (* PROCEDURE (4 byte param, 4 byte param): 4 byte result; *)
	uppTerminalSearchCallBackProcInfo* = $00000EC0; (* PROCEDURE (4 byte param, 2 byte param, 4 byte param); *)
	uppTerminalClikLoopProcInfo* = $000000D0; (* PROCEDURE (4 byte param): 1 byte result; *)
	uppTerminalEnvironsProcInfo* = $000003E0; (* PROCEDURE (4 byte param, 4 byte param): 2 byte result; *)
	uppTerminalChooseIdleProcInfo* = $00000000; (* PROCEDURE ; *)
	uppTerminalToolDefProcInfo* = $0000FEF0; (* PROCEDURE (4 byte param, 2 byte param, 4 byte param, 4 byte param, 4 byte param): 4 byte result; *)

PROCEDURE NewTerminalSendProc*(userRoutine: TerminalSendProcPtr): TerminalSendUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalBreakProc*(userRoutine: TerminalBreakProcPtr): TerminalBreakUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalCacheProc*(userRoutine: TerminalCacheProcPtr): TerminalCacheUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalSearchCallBackProc*(userRoutine: TerminalSearchCallBackProcPtr): TerminalSearchCallBackUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalClikLoopProc*(userRoutine: TerminalClikLoopProcPtr): TerminalClikLoopUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalEnvironsProc*(userRoutine: TerminalEnvironsProcPtr): TerminalEnvironsUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalChooseIdleProc*(userRoutine: TerminalChooseIdleProcPtr): TerminalChooseIdleUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE NewTerminalToolDefProc*(userRoutine: TerminalToolDefProcPtr): TerminalToolDefUPP;
	(*$IF NOT GENERATINGCFM *)
	INLINE PASCAL $2E9F;
	(*$END*)

PROCEDURE CallTerminalSendProc*(thePtr: Types.Ptr; theSize: LONGINT; refCon: LONGINT; flags: Connections.CMFlags; userRoutine: TerminalSendUPP): LONGINT;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalBreakProc*(duration: LONGINT; refCon: LONGINT; userRoutine: TerminalBreakUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalCacheProc*(refCon: LONGINT; theTermData: TermDataBlockPtr; userRoutine: TerminalCacheUPP): LONGINT;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalSearchCallBackProc*(hTerm: TermHandle; refNum: INTEGER; VAR foundRect: Types.Rect; userRoutine: TerminalSearchCallBackUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalClikLoopProc*(refCon: LONGINT; userRoutine: TerminalClikLoopUPP): BOOLEAN;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalEnvironsProc*(refCon: LONGINT; VAR theEnvirons: TermEnvironRec; userRoutine: TerminalEnvironsUPP): Connections.CMErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalChooseIdleProc*(userRoutine: TerminalChooseIdleUPP);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE CallTerminalToolDefProc*(hTerm: TermHandle; msg: INTEGER; p1: LONGINT; p2: LONGINT; p3: LONGINT; userRoutine: TerminalToolDefUPP): LONGINT;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $205F, $4E90;
	(*$END*)

PROCEDURE InitTM*(): TMErr;
	EXTERNAL PASCAL;
PROCEDURE TMGetVersion*(hTerm: TermHandle): Types.Handle;
	EXTERNAL PASCAL;
PROCEDURE TMGetTMVersion*(): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE TMNew*((*CONST*)VAR termRect: Types.Rect; (*CONST*)VAR viewRect: Types.Rect; flags: TMFlags; procID: INTEGER; owner: Quickdraw.WindowPtr; sendProc: TerminalSendUPP; cacheProc: TerminalCacheUPP; breakProc: TerminalBreakUPP; clikLoop: TerminalClikLoopUPP; environsProc: TerminalEnvironsUPP; refCon: LONGINT; userData: LONGINT): TermHandle;
	EXTERNAL PASCAL;
PROCEDURE TMDispose*(hTerm: TermHandle);
	EXTERNAL PASCAL;
PROCEDURE TMKey*(hTerm: TermHandle; (*CONST*)VAR theEvent: Events.EventRecord);
	EXTERNAL PASCAL;
PROCEDURE TMUpdate*(hTerm: TermHandle; visRgn: Quickdraw.RgnHandle);
	EXTERNAL PASCAL;
PROCEDURE TMPaint*(hTerm: TermHandle; (*CONST*)VAR theTermData: TermDataBlock; (*CONST*)VAR theRect: Types.Rect);
	EXTERNAL PASCAL;
PROCEDURE TMActivate*(hTerm: TermHandle; activate: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE TMResume*(hTerm: TermHandle; resume: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE TMClick*(hTerm: TermHandle; (*CONST*)VAR theEvent: Events.EventRecord);
	EXTERNAL PASCAL;
PROCEDURE TMIdle*(hTerm: TermHandle);
	EXTERNAL PASCAL;
PROCEDURE TMStream*(hTerm: TermHandle; theBuffer: (*UNIV*) Types.Ptr; theLength: LONGINT; flags: Connections.CMFlags): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE TMMenu*(hTerm: TermHandle; menuID: INTEGER; item: INTEGER): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE TMReset*(hTerm: TermHandle);
	EXTERNAL PASCAL;
PROCEDURE TMClear*(hTerm: TermHandle);
	EXTERNAL PASCAL;
PROCEDURE TMResize*(hTerm: TermHandle; (*CONST*)VAR newViewRect: Types.Rect);
	EXTERNAL PASCAL;
PROCEDURE TMGetSelect*(hTerm: TermHandle; theData: Types.Handle; VAR theType: Types.ResType): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE TMGetLine*(hTerm: TermHandle; lineNo: INTEGER; VAR theTermData: TermDataBlock);
	EXTERNAL PASCAL;
PROCEDURE TMSetSelection*(hTerm: TermHandle; (*CONST*)VAR theSelection: TMSelection; selType: TMSelTypes);
	EXTERNAL PASCAL;
PROCEDURE TMScroll*(hTerm: TermHandle; dh: INTEGER; dv: INTEGER);
	EXTERNAL PASCAL;
PROCEDURE TMValidate*(hTerm: TermHandle): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE TMDefault*(VAR theConfig: Types.Ptr; procID: INTEGER; allocate: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE TMSetupPreflight*(procID: INTEGER; VAR magicCookie: LONGINT): Types.Handle;
	EXTERNAL PASCAL;
PROCEDURE TMSetupSetup*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; VAR magicCookie: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE TMSetupFilter*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; VAR theEvent: Events.EventRecord; VAR theItem: INTEGER; VAR magicCookie: LONGINT): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE TMSetupItem*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; VAR theItem: INTEGER; VAR magicCookie: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE TMSetupXCleanup*(procID: INTEGER; theConfig: (*UNIV*) Types.Ptr; count: INTEGER; theDialog: Dialogs.DialogPtr; OKed: BOOLEAN; VAR magicCookie: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE TMSetupPostflight*(procID: INTEGER);
	EXTERNAL PASCAL;
PROCEDURE TMGetConfig*(hTerm: TermHandle): Types.Ptr;
	EXTERNAL PASCAL;
PROCEDURE TMSetConfig*(hTerm: TermHandle; thePtr: (*UNIV*) Types.Ptr): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE TMIntlToEnglish*(hTerm: TermHandle; inputPtr: (*UNIV*) Types.Ptr; VAR outputPtr: Types.Ptr; language: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE TMEnglishToIntl*(hTerm: TermHandle; inputPtr: (*UNIV*) Types.Ptr; VAR outputPtr: Types.Ptr; language: INTEGER): Types.OSErr;
	EXTERNAL PASCAL;
PROCEDURE TMGetToolName*(id: INTEGER; VAR name: Types.Str255);
	EXTERNAL PASCAL;
PROCEDURE TMGetProcID*(name: Types.ConstStr255Param): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE TMSetRefCon*(hTerm: TermHandle; refCon: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE TMGetRefCon*(hTerm: TermHandle): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE TMSetUserData*(hTerm: TermHandle; userData: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE TMGetUserData*(hTerm: TermHandle): LONGINT;
	EXTERNAL PASCAL;
PROCEDURE TMAddSearch*(hTerm: TermHandle; theString: Types.ConstStr255Param; (*CONST*)VAR where: Types.Rect; searchType: TMSearchTypes; callBack: TerminalSearchCallBackUPP): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE TMRemoveSearch*(hTerm: TermHandle; refnum: INTEGER);
	EXTERNAL PASCAL;
PROCEDURE TMClearSearch*(hTerm: TermHandle);
	EXTERNAL PASCAL;
PROCEDURE TMGetCursor*(hTerm: TermHandle; cursType: TMCursorTypes): LONGINT (* Types.Point*);
	EXTERNAL PASCAL;
PROCEDURE TMGetTermEnvirons*(hTerm: TermHandle; VAR theEnvirons: TermEnvironRec): TMErr;
	EXTERNAL PASCAL;
PROCEDURE TMChoose*(VAR hTerm: TermHandle; where: Types.Point; idleProc: TerminalChooseIdleUPP): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE TMEvent*(hTerm: TermHandle; (*CONST*)VAR theEvent: Events.EventRecord);
	EXTERNAL PASCAL;
PROCEDURE TMDoTermKey*(hTerm: TermHandle; theKey: Types.ConstStr255Param): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE TMCountTermKeys*(hTerm: TermHandle): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE TMGetIndTermKey*(hTerm: TermHandle; id: INTEGER; VAR theKey: Types.Str255);
	EXTERNAL PASCAL;
PROCEDURE TMGetErrorString*(hTerm: TermHandle; id: INTEGER; VAR errMsg: Types.Str255);
	EXTERNAL PASCAL;

(* $ALIGN RESET*)
(* $POP*)

 END Terminals.
