(*
 	File:		TextUtils.mod
 
 	Contains:	Text Utilities Interfaces.
 
 	Version:	Technology:	System 7.5
 				Package:	Universal Interfaces 2.0 in MPW Latest on ETO #17
 
 	Copyright:	 1984-1995 by Apple Computer, Inc.
 				All rights reserved.
 
 	Bugs?:		If you find a problem with this file, use the Apple Bug Reporter
 				stack.  Include the file and version information (from above)
 				in the problem description and send to:
 					Internet:	apple.bugs.applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*)

(*$IF UNDEFINED OLDROUTINELOCATIONS*)
(*$SET OLDROUTINELOCATIONS FALSE*)
(*$END*)
(*$TAGS-*)
(*$CALLING PASCAL*)
MODULE TextUtils;

IMPORT SYSTEM, Types, QuickdrawText, IntlResources, OSUtils;

(* $PUSH*)
(* $ALIGN MAC68K*)
(* $LibExport+*)
(*

	Here are the current routine names and the translations to the older forms.
	Please use the newer forms in all new code and migrate the older names out of existing
	code as maintainance permits.
	
	New Name					Old Name(s)
	
	CompareString				IUCompPString IUMagString IUMagPString IUCompString 
	CompareText
	DateString					IUDatePString IUDateString 
	EqualString							
	ExtendedToString			FormatX2Str
	FindScriptRun
	FindWordBreaks				NFindWord FindWord
	FormatRecToString			Format2Str
	GetIndString			
	GetString
	IdenticalString				IUMagIDString IUMagIDPString IUEqualString IUEqualPString
	IdenticalText
	InitDateCache
	LanguageOrder				IULangOrder
	LongDateString				IULDateString
	LongTimeString				IULTimeString
	LowercaseText				LwrText LowerText
	Munger
	NewString				
	NumToString				
	RelString				
	ReplaceText
	ScriptOrder					IUScriptOrder
	SetString				
	StringOrder					IUStringOrder
	StringToDate				String2Date
	StringToExtended			FormatStr2X
	StringToFormatRec			Str2Format
	StringToNum				
	StringToTime								
	StripDiacritics				StripText
	StyledLineBreak
	TextOrder
	TimeString					IUTimeString IUTimePString
	TruncString
	TruncText
	UpperString					UprString
	UppercaseStripDiacritics	StripUpperText
	UppercaseText				UprText UprText
*)
(* New constants for System 7.0: *)

CONST
(* Constants for truncWhere argument in TruncString and TruncText *)
	truncEnd*					= 0;							(* Truncate at end *)
	truncMiddle*					= $4000;						(* Truncate in middle *)
	smTruncEnd*					= 0;							(* Truncate at end - obsolete *)
	smTruncMiddle*				= $4000;						(* Truncate in middle - obsolete *)
(* Constants for TruncString and TruncText results *)
	notTruncated*				= 0;							(* No truncation was necessary *)
	truncated*					= 1;							(* Truncation performed *)
	truncErr*					= -1;							(* General error *)
	smNotTruncated*				= 0;							(* No truncation was necessary - obsolete *)
	smTruncated*					= 1;							(* Truncation performed	- obsolete *)
	smTruncErr*					= -1;							(* General error - obsolete *)

	fVNumber*					= 0;							(* first version of NumFormatString *)
(* Special language code values for Language Order *)
	systemCurLang*				= -2;							(* current (itlbLang) lang for system script *)
	systemDefLang*				= -3;							(* default (table) lang for system script *)
	currentCurLang*				= -4;							(* current (itlbLang) lang for current script *)
	currentDefLang*				= -5;							(* default lang for current script *)
	scriptCurLang*				= -6;							(* current (itlbLang) lang for specified script *)
	scriptDefLang*				= -7;							(* default language for a specified script *)

	iuSystemCurLang*				= -2;							(* <obsolete> current (itlbLang) lang for system script *)
	iuSystemDefLang*				= -3;							(* <obsolete> default (table) lang for system script *)
	iuCurrentCurLang*			= -4;							(* <obsolete> current (itlbLang) lang for current script *)
	iuCurrentDefLang*			= -5;							(* <obsolete> default lang for current script *)
	iuScriptCurLang*				= -6;							(* <obsolete> current (itlbLang) lang for specified script *)

(* <obsolete> default language for a specified script *)
	iuScriptDefLang*				= -7;

	
TYPE
	StyledLineBreakCode* = Types.SInt8;


CONST
	smBreakWord*					= 0;
	smBreakChar*					= 1;
	smBreakOverflow*				= 2;

	
TYPE
	FormatClass* = Types.SInt8;


CONST
	fPositive*					= 0;
	fNegative*					= 1;
	fZero*						= 2;

	
TYPE
	FormatResultType* = Types.SInt8;


CONST
	fFormatOK*					= 0;
	fBestGuess*					= 1;
	fOutOfSynch*					= 2;
	fSpuriousChars*				= 3;
	fMissingDelimiter*			= 4;
	fExtraDecimal*				= 5;
	fMissingLiteral*				= 6;
	fExtraExp*					= 7;
	fFormatOverflow*				= 8;
	fFormStrIsNAN*				= 9;
	fBadPartsTable*				= 10;
	fExtraPercent*				= 11;
	fExtraSeparator*				= 12;
	fEmptyFormatString*			= 13;


TYPE
	NumFormatString* = (*PACKED*) RECORD
		fLength*:				Types.UInt8;
		fVersion*:				Types.UInt8;
		data*:					(*PACKED*) ARRAY 254 (*[0..253]*) OF CHAR;			(* private data *)
	END;

	NumFormatStringRec* = NumFormatString;

	FVector* = RECORD
		start*:					INTEGER;
		length*:					INTEGER;
	END;

(* index by [fPositive..fZero] *)
	TripleInt* = ARRAY 3 (*[0..2]*) OF FVector;

	ScriptRunStatus* = RECORD
		script*:					Types.SInt8;
		runVariant*:				Types.SInt8;
	END;

(* New types for System 7.0: *)
(* Type for truncWhere parameter in new TruncString, TruncText *)
	TruncCode* = INTEGER;


CONST
	shortDate*					= 0;
	longDate*					= 1;
	abbrevDate*					= 2;

	
TYPE
	DateForm* = Types.SInt8;


CONST
(* StringToDate status values *)
	fatalDateTime*				= $8000;						(* StringToDate and String2Time mask to a fatal error *)
	longDateFound*				= 1;							(* StringToDate mask to long date found *)
	leftOverChars*				= 2;							(* StringToDate & Sound.Time mask to warn of left over characters *)
	sepNotIntlSep*				= 4;							(* StringToDate & Sound.Time mask to warn of non-standard separators *)
	fieldOrderNotIntl*			= 8;							(* StringToDate & Sound.Time mask to warn of non-standard field order *)
	extraneousStrings*			= 16;							(* StringToDate & Sound.Time mask to warn of unparsable strings in text *)
	tooManySeps*					= 32;							(* StringToDate & Sound.Time mask to warn of too many separators *)
	sepNotConsistent*			= 64;							(* StringToDate & Sound.Time mask to warn of inconsistent separators *)
	tokenErr*					= $8100;						(* StringToDate & Sound.Time mask for 'tokenizer err encountered' *)
	cantReadUtilities*			= $8200;
	dateTimeNotFound*			= $8400;
	dateTimeInvalid*				= $8800;

	
TYPE
	StringToDateStatus* = INTEGER;

	String2DateStatus* = INTEGER;

	DateCacheRecord* = (*PACKED*) RECORD
		hidden*:					ARRAY 256 (*[0..255]*) OF INTEGER;				(* only for temporary use *)
	END;

	DateCachePtr* = POINTER TO DateCacheRecord;

	BreakTable* = RECORD
		charTypes*:				(*PACKED*) ARRAY 256 (*[0..255]*) OF CHAR;
		tripleLength*:			INTEGER;
		triples*:				ARRAY 1 (*[0..0]*) OF INTEGER;
	END;

	BreakTablePtr* = POINTER TO BreakTable;

(* New NBreakTable for System 7.0: *)
	NBreakTable* = RECORD
		flags1*:					Types.SInt8;
		flags2*:					Types.SInt8;
		version*:				INTEGER;
		classTableOff*:			INTEGER;
		auxCTableOff*:			INTEGER;
		backwdTableOff*:			INTEGER;
		forwdTableOff*:			INTEGER;
		doBackup*:				INTEGER;
		length*:					INTEGER;								(* length of NBreakTable *)
		charTypes*:				(*PACKED*) ARRAY 256 (*[0..255]*) OF CHAR;
		tables*:					ARRAY 1 (*[0..0]*) OF INTEGER;
	END;

	NBreakTablePtr* = POINTER TO NBreakTable;

(*
	The following functions are new names that work on 68k and PowerPC
*)

PROCEDURE InitDateCache*(theCache: DateCachePtr): Types.OSErr;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8204, $FFF8, $A8B5;
	(*$END*)
PROCEDURE Munger*(h: Types.Handle; offset: LONGINT; ptr1: (*UNIV*) Types.Ptr; len1: LONGINT; ptr2: (*UNIV*) Types.Ptr; len2: LONGINT): LONGINT;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $A9E0;
	(*$END*)
PROCEDURE NewString*(theString: Types.ConstStr255Param): Types.StringHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $A906;
	(*$END*)
PROCEDURE SetString*(theString: Types.StringHandle; strNew: Types.ConstStr255Param);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $A907;
	(*$END*)
PROCEDURE GetString*(stringID: INTEGER): Types.StringHandle;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $A9BA;
	(*$END*)
PROCEDURE GetIndString*(VAR theString: Types.Str255; strListID: INTEGER; index: INTEGER);
	EXTERNAL PASCAL;
PROCEDURE ScriptOrder*(script1: Types.ScriptCode; script2: Types.ScriptCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $001E, $A9ED;
	(*$END*)
PROCEDURE StyledLineBreak*(textPtr: Types.Ptr; textLen: LONGINT; textStart: LONGINT; textEnd: LONGINT; flags: LONGINT; VAR textWidth: Types.Fixed; VAR textOffset: LONGINT): StyledLineBreakCode;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $821C, $FFFE, $A8B5;
	(*$END*)
PROCEDURE TruncString*(width: INTEGER; VAR theString: Types.Str255; truncWhere: TruncCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8208, $FFE0, $A8B5;
	(*$END*)
PROCEDURE TruncText*(width: INTEGER; textPtr: Types.Ptr; VAR length: INTEGER; truncWhere: TruncCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $820C, $FFDE, $A8B5;
	(*$END*)
PROCEDURE ReplaceText*(baseText: Types.Handle; substitutionText: Types.Handle; VAR key: Types.Str15): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $820C, $FFDC, $A8B5;
	(*$END*)
PROCEDURE FindWordBreaks*(textPtr: Types.Ptr; textLength: INTEGER; offset: INTEGER; leadingEdge: BOOLEAN; breaks: BreakTablePtr; VAR offsets: QuickdrawText.OffsetTable; script: Types.ScriptCode);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $C012, $001A, $A8B5;
	(*$END*)
PROCEDURE LowercaseText*(textPtr: Types.Ptr; len: INTEGER; script: Types.ScriptCode);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0000, $2F3C, $800A, $FFB6, $A8B5;
	(*$END*)
PROCEDURE UppercaseText*(textPtr: Types.Ptr; len: INTEGER; script: Types.ScriptCode);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0400, $2F3C, $800A, $FFB6, $A8B5;
	(*$END*)
PROCEDURE StripDiacritics*(textPtr: Types.Ptr; len: INTEGER; script: Types.ScriptCode);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0200, $2F3C, $800A, $FFB6, $A8B5;
	(*$END*)
PROCEDURE UppercaseStripDiacritics*(textPtr: Types.Ptr; len: INTEGER; script: Types.ScriptCode);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0600, $2F3C, $800A, $FFB6, $A8B5;
	(*$END*)
PROCEDURE FindScriptRun*(textPtr: Types.Ptr; textLen: LONGINT; VAR lenUsed: LONGINT): INTEGER (* ScriptRunStatus*);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $820C, $0026, $A8B5;
	(*$END*)
PROCEDURE EqualString*(str1: Types.ConstStr255Param; str2: Types.ConstStr255Param; caseSensitive: BOOLEAN; diacSensitive: BOOLEAN): BOOLEAN;
	EXTERNAL PASCAL;
PROCEDURE UpperString*(VAR theString: Types.Str255; diacSensitive: BOOLEAN);
	EXTERNAL PASCAL;
PROCEDURE StringToNum*(theString: Types.ConstStr255Param; VAR theNum: LONGINT);
	EXTERNAL PASCAL;
PROCEDURE NumToString*(theNum: LONGINT; VAR theString: Types.Str255);
	EXTERNAL PASCAL;
PROCEDURE RelString*(str1: Types.ConstStr255Param; str2: Types.ConstStr255Param; caseSensitive: BOOLEAN; diacSensitive: BOOLEAN): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE StringToDate*(textPtr: Types.Ptr; textLen: LONGINT; theCache: DateCachePtr; VAR lengthUsed: LONGINT; VAR dateTime: OSUtils.LongDateRec): StringToDateStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8214, $FFF6, $A8B5;
	(*$END*)
PROCEDURE StringToTime*(textPtr: Types.Ptr; textLen: LONGINT; theCache: DateCachePtr; VAR lengthUsed: LONGINT; VAR dateTime: OSUtils.LongDateRec): StringToDateStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8214, $FFF4, $A8B5;
	(*$END*)
(*PROCEDURE ExtendedToString*(VAR x: Types.Extended80; (*CONST*)VAR myCanonical: NumFormatString; (*CONST*)VAR partsTable: IntlResources.NumberParts; VAR outString: Types.Str255): QuickdrawText.FormatStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8210, $FFE8, $A8B5;
	(*$END*)*)
(*PROCEDURE StringToExtended*(source: Types.ConstStr255Param; (*CONST*)VAR myCanonical: NumFormatString; (*CONST*)VAR partsTable: IntlResources.NumberParts; VAR x: Types.Extended80): QuickdrawText.FormatStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8210, $FFE6, $A8B5;
	(*$END*)*)
PROCEDURE StringToFormatRec*(inString: Types.ConstStr255Param; (*CONST*)VAR partsTable: IntlResources.NumberParts; VAR outString: NumFormatString): QuickdrawText.FormatStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $820C, $FFEC, $A8B5;
	(*$END*)
PROCEDURE FormatRecToString*((*CONST*)VAR myCanonical: NumFormatString; (*CONST*)VAR partsTable: IntlResources.NumberParts; VAR outString: Types.Str255; VAR positions: TripleInt): QuickdrawText.FormatStatus;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8210, $FFEA, $A8B5;
	(*$END*)
(*
	The following functions are old names, but are required for PowerPC builds
	becuase InterfaceLib exports these names, instead of the new ones.
*)
PROCEDURE IUMagString*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $000A, $A9ED;
	(*$END*)
PROCEDURE IUMagIDString*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $000C, $A9ED;
	(*$END*)
PROCEDURE IUMagPString*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER; itl2Handle: Types.Handle): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $001A, $A9ED;
	(*$END*)
PROCEDURE IUMagIDPString*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER; itl2Handle: Types.Handle): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $001C, $A9ED;
	(*$END*)
PROCEDURE IUDateString*(dateTime: LONGINT; longFlag: Types.ByteParameter; VAR result: Types.Str255);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $4267, $A9ED;
	(*$END*)
PROCEDURE IUTimeString*(dateTime: LONGINT; wantSeconds: BOOLEAN; VAR result: Types.Str255);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0002, $A9ED;
	(*$END*)
PROCEDURE IUDatePString*(dateTime: LONGINT; longFlag: Types.ByteParameter; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $000E, $A9ED;
	(*$END*)
PROCEDURE IUTimePString*(dateTime: LONGINT; wantSeconds: BOOLEAN; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0010, $A9ED;
	(*$END*)
PROCEDURE IULDateString*(VAR dateTime: OSUtils.LongDateTime; longFlag: Types.ByteParameter; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0014, $A9ED;
	(*$END*)
PROCEDURE IULTimeString*(VAR dateTime: OSUtils.LongDateTime; wantSeconds: BOOLEAN; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0016, $A9ED;
	(*$END*)
PROCEDURE IUScriptOrder*(script1: Types.ScriptCode; script2: Types.ScriptCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $001E, $A9ED;
	(*$END*)
PROCEDURE IULangOrder*(language1: Types.LangCode; language2: Types.LangCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0020, $A9ED;
	(*$END*)
PROCEDURE IUTextOrder*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER; aScript: Types.ScriptCode; bScript: Types.ScriptCode; aLang: Types.LangCode; bLang: Types.LangCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0022, $A9ED;
	(*$END*)
PROCEDURE FindWord*(textPtr: Types.Ptr; textLength: INTEGER; offset: INTEGER; leadingEdge: BOOLEAN; breaks: BreakTablePtr; VAR offsets: QuickdrawText.OffsetTable);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8012, $001A, $A8B5;
	(*$END*)
PROCEDURE NFindWord*(textPtr: Types.Ptr; textLength: INTEGER; offset: INTEGER; leadingEdge: BOOLEAN; nbreaks: NBreakTablePtr; VAR offsets: QuickdrawText.OffsetTable);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $2F3C, $8012, $FFE2, $A8B5;
	(*$END*)
PROCEDURE UprText*(textPtr: Types.Ptr; len: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $301F, $205F, $A054;
	(*$END*)
PROCEDURE LwrText*(textPtr: Types.Ptr; len: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $301F, $205F, $A056;
	(*$END*)
PROCEDURE LowerText*(textPtr: Types.Ptr; len: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $301F, $205F, $A056;
	(*$END*)
PROCEDURE StripText*(textPtr: Types.Ptr; len: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $301F, $205F, $A256;
	(*$END*)
PROCEDURE UpperText*(textPtr: Types.Ptr; len: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $301F, $205F, $A456;
	(*$END*)
PROCEDURE StripUpperText*(textPtr: Types.Ptr; len: INTEGER);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $301F, $205F, $A656;
	(*$END*)
PROCEDURE IUCompPString*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param; itl2Handle: Types.Handle): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE IUEqualPString*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param; itl2Handle: Types.Handle): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE IUStringOrder*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param; aScript: Types.ScriptCode; bScript: Types.ScriptCode; aLang: Types.LangCode; bLang: Types.LangCode): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE IUCompString*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE IUEqualString*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param): INTEGER;
	EXTERNAL PASCAL;
(*
	The following provide direct function prototypes for new names for 68k
*)
PROCEDURE DateString*(dateTime: LONGINT; longFlag: Types.ByteParameter; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $000E, $A9ED;
	(*$END*)
PROCEDURE TimeString*(dateTime: LONGINT; wantSeconds: BOOLEAN; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0010, $A9ED;
	(*$END*)
PROCEDURE LongDateString*(VAR dateTime: OSUtils.LongDateTime; longFlag: Types.ByteParameter; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0014, $A9ED;
	(*$END*)
PROCEDURE LongTimeString*(VAR dateTime: OSUtils.LongDateTime; wantSeconds: BOOLEAN; VAR result: Types.Str255; intlHandle: Types.Handle);
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0016, $A9ED;
	(*$END*)
PROCEDURE CompareString*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param; itl2Handle: Types.Handle): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE IdenticalString*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param; itl2Handle: Types.Handle): INTEGER;
	EXTERNAL PASCAL;
PROCEDURE CompareText*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER; itl2Handle: Types.Handle): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $001A, $A9ED;
	(*$END*)
PROCEDURE IdenticalText*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER; itl2Handle: Types.Handle): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $001C, $A9ED;
	(*$END*)
PROCEDURE LanguageOrder*(language1: Types.LangCode; language2: Types.LangCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0020, $A9ED;
	(*$END*)
PROCEDURE TextOrder*(aPtr: (*UNIV*) Types.Ptr; bPtr: (*UNIV*) Types.Ptr; aLen: INTEGER; bLen: INTEGER; aScript: Types.ScriptCode; bScript: Types.ScriptCode; aLang: Types.LangCode; bLang: Types.LangCode): INTEGER;
	(*$IF NOT GENERATINGCFM*)
	INLINE PASCAL $3F3C, $0022, $A9ED;
	(*$END*)
PROCEDURE StringOrder*(aStr: Types.ConstStr255Param; bStr: Types.ConstStr255Param; aScript: Types.ScriptCode; bScript: Types.ScriptCode; aLang: Types.LangCode; bLang: Types.LangCode): INTEGER;
	EXTERNAL PASCAL;
(*$IF NOT OLDROUTINELOCATIONS *)
PROCEDURE C2PStrProc*(aStr: (*UNIV*) Types.Ptr);
	EXTERNAL PASCAL;
PROCEDURE C2PStr*(cString: (*UNIV*) Types.Ptr): Types.StringPtr;
	EXTERNAL PASCAL;
PROCEDURE P2CStrProc*(aStr: Types.StringPtr);
	EXTERNAL PASCAL;
PROCEDURE P2CStr*(pString: Types.StringPtr): Types.Ptr;
	EXTERNAL PASCAL;
(*$END*)

(* $ALIGN RESET*)
(* $POP*)

 END TextUtils.
